;-----------------------------------------------------------------------
FUNCTION dfdt,t,f
;
; The Lorenz system of ODEs
;
    df=fltarr(3,/nozero)
    df(0) = 10.*(f(1)-f(0))
    df(1) = -f(0)*f(2) + 28.*f(0) - f(1)
    df(2) = f(0)*f(1) - (8./3.)*f(2)
    return,df
END
;-----------------------------------------------------------------------
FUNCTION lorenz,n,f0=f0,f1=f1,dt=dt,t=t
;
; Return a solution of the Lorenz system
;
  if n_elements(n ) eq 0 then n=1000                    ; default 1000 pts
  if n_elements(dt) eq 0 then dt=0.01                   ; default dt
  if n_elements(f0) eq 0 then f0=[10.011,10.,10.]       ; default initial pt

  t=0.0

  f=fltarr(3,n)                                         ; array for result
  f[*,0]=f0
  ff=f0

  for it=1,n-1 do begin
    rk4,t,dt,ff                                         ; RK 4th order
    f[*,it]=ff                                          ; save result
  end
  f1 = ff

  t = dt*indgen(n)
  return,f
END
