; $Id: play.pro,v 1.4 2009/05/25 00:59:17 aake Exp $
;-----------------------------------------------------------------------
PRO type, event                                                         ; handle type setting
  COMMON types, type, show_boxes                                        ; global type values
  if not event.select then return                                       ; igore button unset
  widget_control, event.id, get_value=value                             ; get button name
  CASE value OF                                                         ; case
  'boxes'  : show_boxes=1                                               ; show coordinate boxes
  'noboxes': show_boxes=0                                               ; or don't
  ELSE: type=value                                                      ; set type
  ENDCASE
  print,'show_boxes=',show_boxes
  go                                                                    ; show visualization
END
;-----------------------------------------------------------------------
PRO slider, ev                                                          ; handle slider events
  COMMON angles, ax, ay, az
  widget_control, ev.id, get_uvalue=slider                              ; get slider name
  CASE slider OF                                                        ; set corresponding value
  'ax': ax=ev.value                                                     ; x-axis rotation
  'ay': ay=ev.value                                                     ; y-axis rotation
  'az': az=ev.value                                                     ; z-axis rotation
  ENDCASE
  go                                                                    ; show resulting viz
END
;-----------------------------------------------------------------------
PRO go, event                                                           ; show visualization
  COMMON types, type, show_boxes                                        ; global type values
  COMMON angles, ax, ay, az                                             ; global angles
  ;f = transpose(lorenz())                                              ; get a solution
  f = lorenz()                                                          ; get a solution
  tr = setup(ax=ax,ay=ay,az=az,persp=5)                                 ; setup perspectives
  if show_boxes gt 0 then boxes, tr, col=255                            ; show coordinates or not
  CASE type OF
  'plain'  : show     , f, tr                                           ; simple track
  'dots'   : showdots , f, tr                                           ; dots along track
  'light'  : showlight, f, tr                                           ; light keying
  'color'  : showcolor, f, tr                                           ; color keying
  'animate': showtail , f, tr                                           ; moving dot with tail
  END
END
;-----------------------------------------------------------------------
PRO quit, ev                                                            ; handle quit
  widget_control, ev.top, /destroy                                      ; delete widgets
END
;-----------------------------------------------------------------------
PRO play                                                                ; main procedure
  COMMON types, type, show_boxes                                        ; global type values
  COMMON angles, ax, ay, az                                             ; global angle values
  ax=40 & ay=40 & az=40 & type='plain' & show_boxes=0                   ; defaults

  choice = ['plain white track, ', $
;            'use lights,        ', $
            'use colors,        ', $
            'use dots,          ', $
            'or show animation  ']
  base    = widget_base   (title= 'Lorenz Attractor', /column)          ; main base
  widgets = widget_base   (base, /row, /align_center)                   ; top base
  texts   = widget_base   (widgets, /col, /align_center)                ; text base
  id      = widget_text   (texts, value='Show outline of coordinate boxes or not?', xsize=21, ysize=2, /wrap)
  radio   = widget_base   (widgets, /col, /align_center, /exclusive)    ; radio button base
  id      = widget_button (radio, event_pro='type', value='boxes')      ; radio button
  id      = widget_button (radio, event_pro='type', value='noboxes') & widget_control, id, /set_button
  texts   = widget_base   (widgets, /col, /align_center)                ; text base
  id      = widget_text   (texts, value=choice, xsize=15, ysize=5,/wrap)
  radio   = widget_base   (widgets, /col, /exclusive, /align_center)    ; radio button base
  id      = widget_button (radio, event_pro='type', value='plain')   & widget_control, id, /set_button
;  id      = widget_button (radio, event_pro='type', value='light')      ; radio button
  id      = widget_button (radio, event_pro='type', value='color')      ; radio button
  id      = widget_button (radio, event_pro='type', value='dots')       ; radio button
  id      = widget_button (radio, event_pro='type', value='animate')    ; radio button
  texts   = widget_base   (widgets, /col, /align_center)                ; text base
  id      = widget_text   (texts, value='Set coordinate system rotation', xsize=12, ysize=2, /wrap)
  params  = widget_base   (widgets, /col, /align_center)                ; slider base
  id      = widget_slider (params, event_pro='slider', uvalue='ax', title='x-angle', min=-20, max=80, value=ax)
  id      = widget_slider (params, event_pro='slider', uvalue='az', title='z-angle', min=-20, max=80, value=az)
  texts   = widget_base   (widgets, /col, /align_center)                ; text base
  id      = widget_text   (texts, value='Press GO, or QUIT', xsize=9, ysize=2, /wrap)
  buttons = widget_base   (widgets, /col, /align_center)                ; buttons base
  id      = widget_button (buttons, event_pro='go'  , value='GO')       ; show the visualization
  id      = widget_button (buttons, event_pro='quit', value='QUIT')     ; quit, closing the widgets
  window  = widget_draw   (base, xsize=1000, ysize=500, colors=8)       ; graphics window
  widget_control, base, /realize                                        ; make all widgets
  widget_control, get_value=w1,  window                                 ; get window nr
  wset, w1                                                              ; select window
  go                                                                    ; initial visualization
  xmanager, 'play', base, /no_block                                     ; over to event handler
END
