; $Id: viz3d_live.pro,v 1.3 2007/03/07 07:17:04 aake Exp $

PRO viz3d_live, state

n = 2                                             ; steps for tracer
dt = 0.02                                         ; step size
ntot = 1000                                       ; total steps
sz = 800                                          ; display size

;f0 = [4,5,6]                                      ; initial values can be set here
g = lorenz(ntot,f0=f0,dt=dt)                      ; full path

if n_elements(state) eq 0 then begin
  m = obj_new('IDLgrModel')                       ; a container for 3D graphics
  o = obj_new('IDLgrPolyLine',data=g)             ; a 3D graphics polyline object
  m->Add, o                                       ; add the path to the model

  gsz = size(g)                                   ; size of g
  offset = total(g,2)/gsz[2]                      ; average of the [x,y,z] coordinates
  boxsize = 30.                                   ; boxsize
  b = bbox(offset,boxsize)                        ; bounding box
  m->Add, b                                       ; add the bounding box
  
  boxsize = 1.                                    ; boxsize                             *TILFØJET
  b1 = bbox([0,0,0],boxsize)                      ; bounding box                        *TILFØJET
  m->Add, b1                                      ; add the bounding box                *TILFØJET
  boxsize = 1.                                    ; boxsize                             *TILFØJET
  b2 = bbox([8.485,8.485,27],boxsize)             ; bounding box                        *TILFØJET
  m->Add, b2                                      ; add the bounding box                *TILFØJET

  o->SetProperty, color=[100,100,100]             ; set path to dark grey
  b->SetProperty, color=[150,150,150]             ; set bbox to light grey

  f = lorenz(n,f0=f0,f1=f1,dt=dt)                 ; a short solution
  q = obj_new('IDLgrPolyLine',data=f,thick=3)     ; its 3D graphics polyline object
  q->SetProperty, color=[250,250,150]             ; set to thick bright yellow
  m->Add, q                                       ; add to model
  xobjview, m, background=[50,50,50], tlb=tlb, $  ; show against a dark grey background
            xsize=sz, ysize=sz

end else begin                                    ; continuing previous case
  tlb = state.tlb                                 ; look back object
  m   = state.m                                   ; model
  q   = state.q                                   ; bright tracer
  o   = state.o                                   ; the long path
  xobjview, m, refresh=tlb                        ; refresh
end

k = n                                             ; reset step counter
for i=0,ntot/n-1 do begin                         ; loop over steps
  f = lorenz(n,f0=f0,f1=f1,dt=dt)                 ; short solution, f0=previous, f1=next
  q->SetProperty, data=f                          ; set polyline location
  o->SetProperty, data=g[*,0:k-1]                 ; set long path location
  k = k + (n-1)                                   ; update step counter
  xobjview, m, refresh=tlb                        ; refresh the view
  f0 = f1                                         ; new starting point
;  wait,.01                                        ; reduce the speed
end

state = {tlb:tlb, m:m, o:o, q:q}                  ; return the saved state
END
