(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    285115,       5936]
NotebookOptionsPosition[    274540,       5557]
NotebookOutlinePosition[    275832,       5604]
CellTagsIndexPosition[    275789,       5601]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["10.4 How Strange is the Lorenz Attractor?", "Subtitle",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["", "Text",
 Evaluatable->False,
 CellChangeTimes->{3.420922226625*^9},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Definitions", "Section",
 Evaluatable->False,
 PageBreakAbove->True,
 AspectRatioFixed->True],

Cell["The Lorenz system of equations is", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Ux", ":=", 
   RowBox[{"\[Sigma]", " ", 
    RowBox[{"(", 
     RowBox[{"y", "-", "x"}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Uy", ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "x"}], " ", "z"}], "+", 
    RowBox[{"r", " ", "x"}], "-", "y"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Uz", ":=", 
   RowBox[{
    RowBox[{"x", " ", "y"}], "-", 
    RowBox[{"b", " ", "z"}]}]}], ";"}]}], "Input",
 AspectRatioFixed->True],

Cell["Here is a function definition for it:", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.420922240265625*^9, 3.420922243484375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]", " ", 
      RowBox[{"(", 
       RowBox[{"y", "-", "x"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "x"}], " ", "z"}], "+", 
      RowBox[{"r", " ", "x"}], "-", "y"}], ",", 
     RowBox[{
      RowBox[{"x", " ", "y"}], "-", 
      RowBox[{"b", " ", "z"}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 AspectRatioFixed->True],

Cell["The most commonly used values of the parameters are ", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.420922263515625*^9, 3.420922274328125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Sigma]", "=", "10"}], ";", 
  RowBox[{"r", "=", "100"}], ";", 
  RowBox[{"b", "=", 
   FractionBox["8", "3"]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4838484425692825`*^9, 3.4838484432902827`*^9}},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Zero points", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Solve for the zero points (Solve returns a list of substitutions):\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.420922300453125*^9, 3.4209223105625*^9}},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p", "=", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], ";"}], "\n", 
 RowBox[{"s", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "p", "]"}], "==", "0"}], ",", "p"}], "]"}]}]}], "Input",\

 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", "\[Rule]", "0"}], ",", 
     RowBox[{"y", "\[Rule]", "0"}], ",", 
     RowBox[{"x", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", "\[Rule]", "99"}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SqrtBox["66"]}]}], ",", 
     RowBox[{"x", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SqrtBox["66"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", "\[Rule]", "99"}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"2", " ", 
       SqrtBox["66"]}]}], ",", 
     RowBox[{"x", "\[Rule]", 
      RowBox[{"2", " ", 
       SqrtBox["66"]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.483842287578125*^9, 3.483847820443283*^9, 
  3.483848453788283*^9}]
}, Open  ]],

Cell["\<\
The /. symbol stands for \"substitute\" - useful for getting lists of values \
from lists of substitutions:\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.420922365234375*^9, 3.42092239875*^9}},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zp", "=", 
  RowBox[{"p", "/.", "s"}]}]], "Input",
 PageBreakAbove->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SqrtBox["66"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SqrtBox["66"]}], ",", "99"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      SqrtBox["66"]}], ",", 
     RowBox[{"2", " ", 
      SqrtBox["66"]}], ",", "99"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.483842287640625*^9, 3.483847822719283*^9, 
  3.483848455367283*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Eigenvalues and eigenvectors of the derivative matrix", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["The partial derivative matrix  is", "Text",
 Evaluatable->False,
 PageBreakBelow->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DuDp", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "x"], 
     RowBox[{"U", "[", "p", "]"}]}], ",", 
    RowBox[{
     SubscriptBox["\[PartialD]", "y"], 
     RowBox[{"U", "[", "p", "]"}]}], ",", 
    RowBox[{
     SubscriptBox["\[PartialD]", "z"], 
     RowBox[{"U", "[", "p", "]"}]}]}], "}"}]}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10"}], ",", 
     RowBox[{"100", "-", "z"}], ",", "y"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", 
     RowBox[{"-", "1"}], ",", "x"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "x"}], ",", 
     RowBox[{"-", 
      FractionBox["8", "3"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4838422876875*^9, 3.483848389217283*^9, 
  3.483848456898283*^9}]
}, Open  ]],

Cell["\<\
Solve for the eigenvalues and eigenvectors at the centers of the two leafs: \
\>", "Text",
 Evaluatable->False,
 PageBreakAbove->False,
 CellChangeTimes->{{3.42092247421875*^9, 3.42092247775*^9}},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"eval2", ",", "evec2"}], "}"}], "=", 
  RowBox[{"Eigensystem", "[", 
   RowBox[{"N", "[", 
    RowBox[{"DuDp", "/.", 
     RowBox[{"s", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
    "]"}], "]"}]}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1.1581116082128466`", "\[InvisibleSpace]", "+", 
      RowBox[{"18.13868935312168`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.1581116082128466`", "\[InvisibleSpace]", "-", 
      RowBox[{"18.13868935312168`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"-", "15.982889883092351`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3432377310027125`"}], "-", 
        RowBox[{"0.2831149654811755`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.6734808881013324`"}], "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.12179474597121981`"}], "+", 
        RowBox[{"0.5776013413702817`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3432377310027125`"}], "+", 
        RowBox[{"0.2831149654811755`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.6734808881013324`"}], "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.12179474597121981`"}], "-", 
        RowBox[{"0.5776013413702817`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.910819157018282`"}], ",", "0.2616670002354517`", ",", 
       RowBox[{"-", "0.3192786309734592`"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.483842287828125*^9, 3.4838483925692825`*^9, 
  3.483848461664283*^9}]
}, Open  ]],

Cell["\<\
Note the use of N[], which often speeds up numerical calculations by \
substituting numerical values for things like Sqrt[2]\
\>", "Text",
 CellChangeTimes->{3.420922488703125*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"eval3", ",", "evec3"}], "}"}], "=", 
  RowBox[{"Eigensystem", "[", 
   RowBox[{"N", "[", 
    RowBox[{"DuDp", "/.", 
     RowBox[{"s", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
    "]"}], "]"}]}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1.1581116082128466`", "\[InvisibleSpace]", "+", 
      RowBox[{"18.13868935312168`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.1581116082128466`", "\[InvisibleSpace]", "-", 
      RowBox[{"18.13868935312168`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"-", "15.982889883092351`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3432377310027125`"}], "-", 
        RowBox[{"0.2831149654811755`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.6734808881013324`"}], "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.12179474597121981`", "\[InvisibleSpace]", "-", 
        RowBox[{"0.5776013413702817`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3432377310027125`"}], "+", 
        RowBox[{"0.2831149654811755`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "0.6734808881013324`"}], "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
       RowBox[{"0.12179474597121981`", "\[InvisibleSpace]", "+", 
        RowBox[{"0.5776013413702817`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.910819157018282`"}], ",", "0.2616670002354517`", ",", 
       "0.3192786309734592`"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.48384228790625*^9, 3.483848394863283*^9, 
  3.4838484630072827`*^9}]
}, Open  ]],

Cell["\<\
The first eigenvalue is real and negative; it corresponds to the \
\"exponential attraction\"\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.42092251896875*^9, 3.42092253984375*^9}},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RealEval", "=", 
  RowBox[{
  "eval3", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]], "Input",\

 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"1.1581116082128466`", "\[InvisibleSpace]", "+", 
  RowBox[{"18.13868935312168`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{3.483842287953125*^9, 3.4838484045142827`*^9, 
  3.483848464335283*^9}]
}, Open  ]],

Cell["\<\
The real part of the conjugate pair corresponds to the exponential repulsion \
in the plane of each leaf.\
\>", "Text",
 Evaluatable->False,
 PageBreakBelow->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"LeafCenter", "=", 
   RowBox[{"zp", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"ComplEvec", "=", 
   RowBox[{"evec3", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"ComplEval", "=", 
   RowBox[{"eval3", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
  ";"}], "\n", 
 RowBox[{"Re", "[", "ComplEval", "]"}]}], "Input",
 AspectRatioFixed->True],

Cell[BoxData["1.1581116082128466`"], "Output",
 CellChangeTimes->{3.483842288015625*^9, 3.483848408117283*^9, 
  3.4838484654512825`*^9}]
}, Open  ]],

Cell["\<\
The imaginary part of the conjugate pair corresponds to the circular motion \
in the plane of each leaf.\
\>", "Text",
 Evaluatable->False,
 PageBreakAbove->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Im", "[", "ComplEval", "]"}]], "Input",
 PageBreakAbove->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"-", "18.13868935312168`"}]], "Output",
 CellChangeTimes->{3.483842288078125*^9, 3.4838484128192825`*^9, 
  3.4838484706282825`*^9}]
}, Open  ]],

Cell["\<\
The ratio of the real to the imaginary part of the complex eigenvalue \
determines the exponential growth of the spiral.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"growth", "=", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"N", "[", "\[Pi]", "]"}], " ", 
    RowBox[{"Re", "[", "ComplEval", "]"}]}], 
   RowBox[{"Abs", "[", 
    RowBox[{"Im", "[", "ComplEval", "]"}], "]"}]]}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData["0.40116624190075595`"], "Output",
 CellChangeTimes->{3.483842288140625*^9, 3.4838484178902826`*^9, 
  3.483848471933283*^9}]
}, Open  ]],

Cell["\<\
Thus, for the canonical values of the parameters the radius of a path grows \
by 5.8% each turn around the leaf.\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.420922592734375*^9, 3.42092260028125*^9}},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Procedure for zero points and eigensystem", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Here is a compact procedure for reevaluating the zero points and eigensystem. \
 This is just a summary of the steps taken earlier:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Rayleigh", "[", "Ra_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"r", "=", "Ra"}], ";", 
      RowBox[{"p", "=", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], ";", 
      RowBox[{"s", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"U", "[", "p", "]"}], "==", "0"}], ",", "p"}], "]"}], 
        "]"}]}], ";", 
      RowBox[{"zp", "=", 
       RowBox[{"p", "/.", "s"}]}], ";", 
      RowBox[{"DuDp", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", "x"], 
          RowBox[{"U", "[", "p", "]"}]}], ",", 
         RowBox[{
          SubscriptBox["\[PartialD]", "y"], 
          RowBox[{"U", "[", "p", "]"}]}], ",", 
         RowBox[{
          SubscriptBox["\[PartialD]", "z"], 
          RowBox[{"U", "[", "p", "]"}]}]}], "}"}]}], ";", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eval2", ",", "evec2"}], "}"}], "=", 
       RowBox[{"Eigensystem", "[", 
        RowBox[{"N", "[", 
         RowBox[{"DuDp", "/.", 
          RowBox[{
          "s", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         "]"}], "]"}]}], ";", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eval3", ",", "evec3"}], "}"}], "=", 
       RowBox[{"Eigensystem", "[", 
        RowBox[{"N", "[", 
         RowBox[{"DuDp", "/.", 
          RowBox[{
          "s", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
         "]"}], "]"}]}], ";", 
      RowBox[{"LeafCenter", "=", 
       RowBox[{"zp", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}],
       ";", 
      RowBox[{"ComplEvec", "=", 
       RowBox[{"-", 
        RowBox[{
        "evec3", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}]}], 
      ";", 
      RowBox[{"ComplEval", "=", 
       RowBox[{
       "eval3", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ";", 
      RowBox[{"growth", "=", 
       RowBox[{"2", " ", 
        RowBox[{"N", "[", "\[Pi]", "]"}], " ", 
        RowBox[{"Abs", "[", 
         FractionBox[
          RowBox[{"Re", "[", 
           RowBox[{
           "eval3", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
           "]"}], 
          RowBox[{"Im", "[", 
           RowBox[{
           "eval3", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
           "]"}]], "]"}]}]}], ";"}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.452203949595606*^9},
 AspectRatioFixed->True],

Cell["\<\
So, we can now set standard parameters with the procedure call\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Rayleigh", "[", "28", "]"}]], "Input",
 PageBreakAbove->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell["\<\
The coordinates of the third zero point (the center of the right hand side \
leaf) is\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zp", "\[LeftDoubleBracket]", "3", 
  "\[RightDoubleBracket]"}]], "Input",
 PageBreakAbove->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"6", " ", 
    SqrtBox["2"]}], ",", 
   RowBox[{"6", " ", 
    SqrtBox["2"]}], ",", "27"}], "}"}]], "Output",
 CellChangeTimes->{{3.483842287203125*^9, 3.483842288234375*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Graphics definitions", "Section",
 Evaluatable->False,
 PageBreakAbove->True,
 AspectRatioFixed->True],

Cell["\<\
Because we use names which are similar to built-in names, we turn off the \
warnings otherwise issued.\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.420922644828125*^9, 3.42092264596875*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "\"\<spell1\>\""}], "]"}], ";"}]], "Input",
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[TextData[{
 "Definitions of points and lines (the ",
 StyleBox["Map[]",
  FontWeight->"Bold"],
 " function applies its first argument to each element of the list in the \
second argument; here this turns a list of paths into a list of 3D line \
objects):"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{
  3.420922670140625*^9, 3.42092273475*^9, {3.420922831046875*^9, 
   3.42092284915625*^9}},
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"point", "[", "x_", "]"}], ":=", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Thickness", "[", "0.005`", "]"}], ",", 
     RowBox[{"Point", "[", "x", "]"}]}], "}"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"line", "[", "x_", "]"}], ":=", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Thickness", "[", "0.001`", "]"}], ",", 
     RowBox[{"Line", "[", "x", "]"}]}], "}"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"lines", "[", "x_", "]"}], ":=", 
   RowBox[{"Map", "[", 
    RowBox[{"line", ",", "x"}], "]"}]}], ";"}]}], "Input",
 PageBreakAbove->False,
 InitializationCell->True,
 CellChangeTimes->{{3.42092270940625*^9, 3.420922723046875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The ",
 StyleBox["polygons[]",
  FontWeight->"Bold"],
 " function turns a 2D matrix of points into a list of polygons:"
}], "Text",
 Evaluatable->False,
 PageBreakWithin->False,
 CellChangeTimes->{{3.4209228060625*^9, 3.420922811125*^9}, {
  3.42092285903125*^9, 3.420922859703125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"polygons", "[", "vl_List", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"vl1", "=", 
       RowBox[{"RotateLeft", "/@", "vl"}]}], ",", "mesh"}], "}"}], ",", 
    RowBox[{
     RowBox[{"mesh", "=", 
      RowBox[{"{", 
       RowBox[{"vl", ",", 
        RowBox[{"RotateLeft", "[", "vl", "]"}], ",", 
        RowBox[{"RotateLeft", "[", "vl1", "]"}], ",", "vl1"}], "}"}]}], ";", 
     RowBox[{"mesh", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{"#1", ",", 
           RowBox[{"-", "1"}]}], "]"}], "&"}], ",", "mesh", ",", 
        RowBox[{"{", "1", "}"}]}], "]"}]}], ";", 
     RowBox[{"mesh", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{"#1", ",", 
           RowBox[{"-", "1"}]}], "]"}], "&"}], ",", "mesh", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{"Polygon", "/@", 
       RowBox[{"Transpose", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"#1", ",", "1"}], "]"}], "&"}], ")"}], "/@", "mesh"}], 
        "]"}]}], "]"}]}]}], "]"}]}]], "Input",
 PageBreakAbove->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell["\<\
A plane spanned by two vectors is shown as a circle by this function:\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.420922898921875*^9, 3.420922899296875*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plane", "[", 
    RowBox[{"r_", ",", "re_", ",", "im_"}], "]"}], ":=", 
   RowBox[{"polygons", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"r", "+", 
       RowBox[{"radius", " ", 
        RowBox[{"N", "[", 
         RowBox[{
          RowBox[{"re", " ", 
           RowBox[{"Cos", "[", "phi", "]"}]}], "+", 
          RowBox[{"im", " ", 
           RowBox[{"Sin", "[", "phi", "]"}]}]}], "]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"phi", ",", "0", ",", 
        RowBox[{"2", " ", "\[Pi]"}], ",", 
        FractionBox["\[Pi]", "6"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"radius", ",", "0", ",", "1.0", ",", "0.5"}], "}"}]}], "]"}], 
    "]"}]}], ";"}]], "Input",
 PageBreakAbove->False,
 InitializationCell->True,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Illustrations of the nulls and eigenvectors", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
The eigenvectors and the planes spanned by the conjugate pairs of complex \
eigenvectors are shown as lines and circles:\
\>", "Text",
 Evaluatable->False,
 PageBreakAbove->False,
 CellChangeTimes->{3.420922927875*^9},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"l", "=", 
   RowBox[{"Abs", "[", 
    RowBox[{"eval2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"point", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], "]"}], ",", 
     RowBox[{"line", "[", 
      RowBox[{"N", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
          "zp", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "-", 
          RowBox[{"l", " ", 
           RowBox[{
           "evec2", "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}]}]}], ",", 
         RowBox[{
          RowBox[{
          "zp", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "+", 
          RowBox[{"l", " ", 
           RowBox[{
           "evec2", "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}]}]}]}], "}"}], "]"}], "]"}], ",", 
     RowBox[{"plane", "[", 
      RowBox[{
       RowBox[{"zp", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       ",", 
       RowBox[{"l", " ", 
        RowBox[{"Re", "[", 
         RowBox[{
         "evec2", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "]"}]}], ",", 
       RowBox[{"N", "[", 
        RowBox[{"l", " ", 
         RowBox[{"Im", "[", 
          RowBox[{
          "evec2", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
          "]"}]}], "]"}]}], "]"}], ",", 
     RowBox[{"line", "[", 
      RowBox[{"N", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
          "zp", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "-", 
          RowBox[{"l", " ", 
           RowBox[{
           "evec3", "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}]}]}], ",", 
         RowBox[{
          RowBox[{
          "zp", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "+", 
          RowBox[{"l", " ", 
           RowBox[{
           "evec3", "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}]}]}]}], "}"}], "]"}], "]"}], ",", 
     RowBox[{"plane", "[", 
      RowBox[{
       RowBox[{"zp", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
       ",", 
       RowBox[{"l", " ", 
        RowBox[{"Re", "[", 
         RowBox[{
         "evec3", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "]"}]}], ",", 
       RowBox[{"N", "[", 
        RowBox[{"l", " ", 
         RowBox[{"Im", "[", 
          RowBox[{
          "evec3", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
          "]"}]}], "]"}]}], "]"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"g", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}], ",", 
   
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 PageBreakAbove->False,
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[{
   {Thickness[0.005], Point3DBox[{0, 0, 0}]}, 
   {Thickness[0.001], 
    Line3DBox[{{3.1276390582099545`, -14.505428039581908`, 
     31.5658780479758}, {-20.098201806687097`, -2.465134708895234, 
     22.4341219520242}}]}, {
    Polygon3DBox[{{-8.485281374238571, -8.485281374238571, 
     27.}, {-8.485281374238571, -8.485281374238571, 
     27.}, {-6.301615542118805, -4.085026769061717, 
     25.95394806813964}, {-7.024085554742539, -3.404305012635076, 
     28.066976465440423`}}], 
    Polygon3DBox[{{-7.024085554742539, -3.404305012635076, 
     28.066976465440423`}, {-6.301615542118805, -4.085026769061717, 
     25.95394806813964}, {-4.117949709999038, 0.31522783611513816`, 
     24.90789613627928}, {-5.562889735246508, 1.6766713489684193`, 
     29.13395293088085}}], 
    Polygon3DBox[{{-8.485281374238571, -8.485281374238571, 
     27.}, {-8.485281374238571, -8.485281374238571, 
     27.}, {-6.164257025750996, -5.944793193436824, 
     24.121208441221857`}, {-6.301615542118805, -4.085026769061717, 
     25.95394806813964}}], 
    Polygon3DBox[{{-6.301615542118805, -4.085026769061717, 
     25.95394806813964}, {-6.164257025750996, -5.944793193436824, 
     24.121208441221857`}, {-3.843232677263421, -3.404305012635076, 
     21.242416882443713`}, {-4.117949709999038, 0.31522783611513816`, 
     24.90789613627928}}], 
    Polygon3DBox[{{-8.485281374238571, -8.485281374238571, 
     27.}, {-8.485281374238571, -8.485281374238571, 
     27.}, {-6.648815109173406, -8.485281374238571, 
     23.059838687656207`}, {-6.164257025750996, -5.944793193436824, 
     24.121208441221857`}}], 
    Polygon3DBox[{{-6.164257025750996, -5.944793193436824, 
     24.121208441221857`}, {-6.648815109173406, -8.485281374238571, 
     23.059838687656207`}, {-4.812348844108241, -8.485281374238571, 
     19.119677375312413`}, {-3.843232677263421, -3.404305012635076, 
     21.242416882443713`}}], 
    Polygon3DBox[{{-8.485281374238571, -8.485281374238571, 
     27.}, {-8.485281374238571, -8.485281374238571, 
     27.}, {-7.625452845247027, -11.02576955504032, 
     23.05423197578143}, {-6.648815109173406, -8.485281374238571, 
     23.059838687656207`}}], 
    Polygon3DBox[{{-6.648815109173406, -8.485281374238571, 
     23.059838687656207`}, {-7.625452845247027, -11.02576955504032, 
     23.05423197578143}, {-6.765624316255484, -13.566257735842067`, 
     19.10846395156286}, {-4.812348844108241, -8.485281374238571, 
     19.119677375312413`}}], 
    Polygon3DBox[{{-8.485281374238571, -8.485281374238571, 
     27.}, {-8.485281374238571, -8.485281374238571, 
     27.}, {-8.832480941293174, -12.885535979415426`, 
     24.10589061951657}, {-7.625452845247027, -11.02576955504032, 
     23.05423197578143}}], 
    Polygon3DBox[{{-7.625452845247027, -11.02576955504032, 
     23.05423197578143}, {-8.832480941293174, -12.885535979415426`, 
     24.10589061951657}, {-9.179680508347776, -17.28579058459228, 
     21.211781239033137`}, {-6.765624316255484, -13.566257735842067`, 
     19.10846395156286}}], 
    Polygon3DBox[{{-8.485281374238571, -8.485281374238571, 
     27.}, {-8.485281374238571, -8.485281374238571, 
     27.}, {-9.946477193734603, -13.566257735842067`, 
     25.933023534559577`}, {-8.832480941293174, -12.885535979415426`, 
     24.10589061951657}}], 
    Polygon3DBox[{{-8.832480941293174, -12.885535979415426`, 
     24.10589061951657}, {-9.946477193734603, -13.566257735842067`, 
     25.933023534559577`}, {-11.407673013230635`, -18.647234097445562`, 
     24.86604706911915}, {-9.179680508347776, -17.28579058459228, 
     21.211781239033137`}}], 
    Polygon3DBox[{{-8.485281374238571, -8.485281374238571, 
     27.}, {-8.485281374238571, -8.485281374238571, 
     27.}, {-10.668947206358338`, -12.885535979415426`, 
     28.04605193186036}, {-9.946477193734603, -13.566257735842067`, 
     25.933023534559577`}}], 
    Polygon3DBox[{{-9.946477193734603, -13.566257735842067`, 
     25.933023534559577`}, {-10.668947206358338`, -12.885535979415426`, 
     28.04605193186036}, {-12.852613038478104`, -17.28579058459228, 
     29.09210386372072}, {-11.407673013230635`, -18.647234097445562`, 
     24.86604706911915}}], 
    Polygon3DBox[{{-8.485281374238571, -8.485281374238571, 
     27.}, {-8.485281374238571, -8.485281374238571, 
     27.}, {-10.806305722726147`, -11.02576955504032, 
     29.878791558778143`}, {-10.668947206358338`, -12.885535979415426`, 
     28.04605193186036}}], 
    Polygon3DBox[{{-10.668947206358338`, -12.885535979415426`, 
     28.04605193186036}, {-10.806305722726147`, -11.02576955504032, 
     29.878791558778143`}, {-13.127330071213722`, -13.566257735842067`, 
     32.75758311755629}, {-12.852613038478104`, -17.28579058459228, 
     29.09210386372072}}], 
    Polygon3DBox[{{-8.485281374238571, -8.485281374238571, 
     27.}, {-8.485281374238571, -8.485281374238571, 
     27.}, {-10.321747639303737`, -8.485281374238571, 
     30.940161312343793`}, {-10.806305722726147`, -11.02576955504032, 
     29.878791558778143`}}], 
    Polygon3DBox[{{-10.806305722726147`, -11.02576955504032, 
     29.878791558778143`}, {-10.321747639303737`, -8.485281374238571, 
     30.940161312343793`}, {-12.158213904368901`, -8.485281374238571, 
     34.88032262468759}, {-13.127330071213722`, -13.566257735842067`, 
     32.75758311755629}}], 
    Polygon3DBox[{{-8.485281374238571, -8.485281374238571, 
     27.}, {-8.485281374238571, -8.485281374238571, 
     27.}, {-9.345109903230115, -5.944793193436824, 
     30.94576802421857}, {-10.321747639303737`, -8.485281374238571, 
     30.940161312343793`}}], 
    Polygon3DBox[{{-10.321747639303737`, -8.485281374238571, 
     30.940161312343793`}, {-9.345109903230115, -5.944793193436824, 
     30.94576802421857}, {-10.20493843222166, -3.404305012635076, 
     34.89153604843714}, {-12.158213904368901`, -8.485281374238571, 
     34.88032262468759}}], 
    Polygon3DBox[{{-8.485281374238571, -8.485281374238571, 
     27.}, {-8.485281374238571, -8.485281374238571, 
     27.}, {-8.13808180718397, -4.085026769061717, 
     29.89410938048343}, {-9.345109903230115, -5.944793193436824, 
     30.94576802421857}}], 
    Polygon3DBox[{{-9.345109903230115, -5.944793193436824, 
     30.94576802421857}, {-8.13808180718397, -4.085026769061717, 
     29.89410938048343}, {-7.790882240129368, 0.31522783611513816`, 
     32.78821876096686}, {-10.20493843222166, -3.404305012635076, 
     34.89153604843714}}], 
    Polygon3DBox[{{-8.485281374238571, -8.485281374238571, 
     27.}, {-8.485281374238571, -8.485281374238571, 
     27.}, {-7.024085554742539, -3.404305012635076, 
     28.066976465440423`}, {-8.13808180718397, -4.085026769061717, 
     29.89410938048343}}], 
    Polygon3DBox[{{-8.13808180718397, -4.085026769061717, 
     29.89410938048343}, {-7.024085554742539, -3.404305012635076, 
     28.066976465440423`}, {-5.562889735246508, 1.6766713489684193`, 
     29.13395293088085}, {-7.790882240129368, 0.31522783611513816`, 
     32.78821876096686}}]}, 
   {Thickness[0.001], 
    Line3DBox[{{20.098201806687097`, 2.465134708895234, 
     22.4341219520242}, {-3.1276390582099545`, 14.505428039581908`, 
     31.5658780479758}}]}, {
    Polygon3DBox[{{8.485281374238571, 8.485281374238571, 27.}, {
     8.485281374238571, 8.485281374238571, 27.}, {10.668947206358338`, 
     12.885535979415426`, 28.04605193186036}, {9.946477193734603, 
     13.566257735842067`, 25.933023534559577`}}], 
    Polygon3DBox[{{9.946477193734603, 13.566257735842067`, 
     25.933023534559577`}, {10.668947206358338`, 12.885535979415426`, 
     28.04605193186036}, {12.852613038478104`, 17.28579058459228, 
     29.09210386372072}, {11.407673013230635`, 18.647234097445562`, 
     24.86604706911915}}], 
    Polygon3DBox[{{8.485281374238571, 8.485281374238571, 27.}, {
     8.485281374238571, 8.485281374238571, 27.}, {10.806305722726147`, 
     11.02576955504032, 29.878791558778143`}, {10.668947206358338`, 
     12.885535979415426`, 28.04605193186036}}], 
    Polygon3DBox[{{10.668947206358338`, 12.885535979415426`, 
     28.04605193186036}, {10.806305722726147`, 11.02576955504032, 
     29.878791558778143`}, {13.127330071213722`, 13.566257735842067`, 
     32.75758311755629}, {12.852613038478104`, 17.28579058459228, 
     29.09210386372072}}], 
    Polygon3DBox[{{8.485281374238571, 8.485281374238571, 27.}, {
     8.485281374238571, 8.485281374238571, 27.}, {10.321747639303737`, 
     8.485281374238571, 30.940161312343793`}, {10.806305722726147`, 
     11.02576955504032, 29.878791558778143`}}], 
    Polygon3DBox[{{10.806305722726147`, 11.02576955504032, 
     29.878791558778143`}, {10.321747639303737`, 8.485281374238571, 
     30.940161312343793`}, {12.158213904368901`, 8.485281374238571, 
     34.88032262468759}, {13.127330071213722`, 13.566257735842067`, 
     32.75758311755629}}], 
    Polygon3DBox[{{8.485281374238571, 8.485281374238571, 27.}, {
     8.485281374238571, 8.485281374238571, 27.}, {9.345109903230115, 
     5.944793193436824, 30.94576802421857}, {10.321747639303737`, 
     8.485281374238571, 30.940161312343793`}}], 
    Polygon3DBox[{{10.321747639303737`, 8.485281374238571, 
     30.940161312343793`}, {9.345109903230115, 5.944793193436824, 
     30.94576802421857}, {10.20493843222166, 3.404305012635076, 
     34.89153604843714}, {12.158213904368901`, 8.485281374238571, 
     34.88032262468759}}], 
    Polygon3DBox[{{8.485281374238571, 8.485281374238571, 27.}, {
     8.485281374238571, 8.485281374238571, 27.}, {8.13808180718397, 
     4.085026769061717, 29.89410938048343}, {9.345109903230115, 
     5.944793193436824, 30.94576802421857}}], 
    Polygon3DBox[{{9.345109903230115, 5.944793193436824, 30.94576802421857}, {
     8.13808180718397, 4.085026769061717, 29.89410938048343}, {
     7.790882240129368, -0.31522783611513816`, 32.78821876096686}, {
     10.20493843222166, 3.404305012635076, 34.89153604843714}}], 
    Polygon3DBox[{{8.485281374238571, 8.485281374238571, 27.}, {
     8.485281374238571, 8.485281374238571, 27.}, {7.024085554742539, 
     3.404305012635076, 28.066976465440423`}, {8.13808180718397, 
     4.085026769061717, 29.89410938048343}}], 
    Polygon3DBox[{{8.13808180718397, 4.085026769061717, 29.89410938048343}, {
     7.024085554742539, 3.404305012635076, 28.066976465440423`}, {
     5.562889735246508, -1.6766713489684193`, 29.13395293088085}, {
     7.790882240129368, -0.31522783611513816`, 32.78821876096686}}], 
    Polygon3DBox[{{8.485281374238571, 8.485281374238571, 27.}, {
     8.485281374238571, 8.485281374238571, 27.}, {6.301615542118805, 
     4.085026769061717, 25.95394806813964}, {7.024085554742539, 
     3.404305012635076, 28.066976465440423`}}], 
    Polygon3DBox[{{7.024085554742539, 3.404305012635076, 
     28.066976465440423`}, {6.301615542118805, 4.085026769061717, 
     25.95394806813964}, {4.117949709999038, -0.31522783611513816`, 
     24.90789613627928}, {5.562889735246508, -1.6766713489684193`, 
     29.13395293088085}}], 
    Polygon3DBox[{{8.485281374238571, 8.485281374238571, 27.}, {
     8.485281374238571, 8.485281374238571, 27.}, {6.164257025750996, 
     5.944793193436824, 24.121208441221857`}, {6.301615542118805, 
     4.085026769061717, 25.95394806813964}}], 
    Polygon3DBox[{{6.301615542118805, 4.085026769061717, 25.95394806813964}, {
     6.164257025750996, 5.944793193436824, 24.121208441221857`}, {
     3.843232677263421, 3.404305012635076, 21.242416882443713`}, {
     4.117949709999038, -0.31522783611513816`, 24.90789613627928}}], 
    Polygon3DBox[{{8.485281374238571, 8.485281374238571, 27.}, {
     8.485281374238571, 8.485281374238571, 27.}, {6.648815109173406, 
     8.485281374238571, 23.059838687656207`}, {6.164257025750996, 
     5.944793193436824, 24.121208441221857`}}], 
    Polygon3DBox[{{6.164257025750996, 5.944793193436824, 
     24.121208441221857`}, {6.648815109173406, 8.485281374238571, 
     23.059838687656207`}, {4.812348844108241, 8.485281374238571, 
     19.119677375312413`}, {3.843232677263421, 3.404305012635076, 
     21.242416882443713`}}], 
    Polygon3DBox[{{8.485281374238571, 8.485281374238571, 27.}, {
     8.485281374238571, 8.485281374238571, 27.}, {7.625452845247027, 
     11.02576955504032, 23.05423197578143}, {6.648815109173406, 
     8.485281374238571, 23.059838687656207`}}], 
    Polygon3DBox[{{6.648815109173406, 8.485281374238571, 
     23.059838687656207`}, {7.625452845247027, 11.02576955504032, 
     23.05423197578143}, {6.765624316255484, 13.566257735842067`, 
     19.10846395156286}, {4.812348844108241, 8.485281374238571, 
     19.119677375312413`}}], 
    Polygon3DBox[{{8.485281374238571, 8.485281374238571, 27.}, {
     8.485281374238571, 8.485281374238571, 27.}, {8.832480941293174, 
     12.885535979415426`, 24.10589061951657}, {7.625452845247027, 
     11.02576955504032, 23.05423197578143}}], 
    Polygon3DBox[{{7.625452845247027, 11.02576955504032, 23.05423197578143}, {
     8.832480941293174, 12.885535979415426`, 24.10589061951657}, {
     9.179680508347776, 17.28579058459228, 21.211781239033137`}, {
     6.765624316255484, 13.566257735842067`, 19.10846395156286}}], 
    Polygon3DBox[{{8.485281374238571, 8.485281374238571, 27.}, {
     8.485281374238571, 8.485281374238571, 27.}, {9.946477193734603, 
     13.566257735842067`, 25.933023534559577`}, {8.832480941293174, 
     12.885535979415426`, 24.10589061951657}}], 
    Polygon3DBox[{{8.832480941293174, 12.885535979415426`, 
     24.10589061951657}, {9.946477193734603, 13.566257735842067`, 
     25.933023534559577`}, {11.407673013230635`, 18.647234097445562`, 
     24.86604706911915}, {9.179680508347776, 17.28579058459228, 
     21.211781239033137`}}]}},
  AxesLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"y\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  PlotRange->All]], "Output",
 CellChangeTimes->{3.483842288953125*^9}]
}, Open  ]],

Cell[TextData[StyleBox["PB 1400c: 5s",
 FontFamily->"Times",
 FontSize->9]], "Text",
 Evaluatable->False,
 TextAlignment->Right,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integration procedures", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Lorenz' method", "Subsubsection",
 Evaluatable->False,
 PageBreakAbove->False,
 AspectRatioFixed->True],

Cell["\<\
This is Lorenz original \"double approximation\" method; a type of second \
order Runge-Kutta method:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"trace2", "[", 
   RowBox[{"f_", ",", "p0_", ",", "d_", ",", "nt_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"f0", ",", 
      RowBox[{"dt", "=", 
       RowBox[{"N", "[", "d", "]"}]}], ",", 
      RowBox[{"p", "=", 
       RowBox[{"N", "[", "p0", "]"}]}], ",", "pn", ",", "po", ",", "pt", ",", 
      "i"}], "}"}], ",", 
    RowBox[{
     RowBox[{"pt", "=", 
      RowBox[{"{", "p", "}"}]}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"f0", "=", 
         RowBox[{"N", "[", 
          RowBox[{"f", "[", "p", "]"}], "]"}]}], ";", 
        RowBox[{"pn", "=", 
         RowBox[{"p", "+", 
          RowBox[{"dt", " ", "f0"}]}]}], ";", 
        RowBox[{"f1", "=", 
         RowBox[{"N", "[", 
          RowBox[{"f", "[", "pn", "]"}], "]"}]}], ";", 
        RowBox[{"p", "=", 
         RowBox[{"p", "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "dt", " ", 
           RowBox[{"(", 
            RowBox[{"f0", "+", "f1"}], ")"}]}]}]}], ";", 
        RowBox[{"pt", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"pt", ",", "p"}], "]"}]}], ";", 
        RowBox[{"p", "=", "pn"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "nt"}], "}"}]}], "]"}], ";", 
     RowBox[{"pe", "=", "p"}], ";", "pt"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The classical 4th order Runge-Kutta", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"trace4", "[", 
   RowBox[{"f_", ",", "p0_", ",", "d_", ",", "nt_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"f0", ",", 
      RowBox[{"dt", "=", 
       RowBox[{"N", "[", "d", "]"}]}], ",", 
      RowBox[{"p", "=", 
       RowBox[{"N", "[", "p0", "]"}]}], ",", "pn", ",", "pt", ",", "i"}], 
     "}"}], ",", 
    RowBox[{
     RowBox[{"pt", "=", 
      RowBox[{"{", "p", "}"}]}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"f0", "=", 
         RowBox[{"N", "[", 
          RowBox[{"f", "[", "p", "]"}], "]"}]}], ";", 
        RowBox[{"pn", "=", 
         RowBox[{"p", "+", 
          RowBox[{"0.5", " ", "dt", " ", "f0"}]}]}], ";", 
        RowBox[{"f1", "=", 
         RowBox[{"N", "[", 
          RowBox[{"f", "[", "pn", "]"}], "]"}]}], ";", 
        RowBox[{"pn", "=", 
         RowBox[{"p", "+", 
          RowBox[{"0.5", " ", "dt", " ", "f1"}]}]}], ";", 
        RowBox[{"f2", "=", 
         RowBox[{"N", "[", 
          RowBox[{"f", "[", "pn", "]"}], "]"}]}], ";", 
        RowBox[{"pn", "=", 
         RowBox[{"p", "+", 
          RowBox[{"dt", " ", "f2"}]}]}], ";", 
        RowBox[{"f3", "=", 
         RowBox[{"N", "[", 
          RowBox[{"f", "[", "pn", "]"}], "]"}]}], ";", 
        RowBox[{"p", "=", 
         RowBox[{"p", "+", 
          RowBox[{
           FractionBox["1", "6"], " ", 
           RowBox[{"(", 
            RowBox[{"f0", "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"f1", "+", "f2"}], ")"}]}], "+", "f3"}], ")"}], " ", 
           "dt"}]}]}], ";", 
        RowBox[{"pt", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"pt", ",", "p"}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "nt"}], "}"}]}], "]"}], ";", 
     RowBox[{"pe", "=", "p"}], ";", "pt"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Position dependent time step", "Subsubsection",
 Evaluatable->False,
 PageBreakAbove->True,
 AspectRatioFixed->True],

Cell["\<\
In order to get a constant \"angular velocity\" on the leaves, we normalize \
the timestep to 1/dt steps per turn:\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.420923061203125*^9, 3.420923065703125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"norm3", "[", "v_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], " ", 
     RowBox[{"v", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
    "+", 
    RowBox[{
     RowBox[{"v", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], " ", 
     RowBox[{"v", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
    "+", 
    RowBox[{
     RowBox[{"v", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], " ", 
     RowBox[{
     "v", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"trace", "[", 
   RowBox[{"f_", ",", "p0_", ",", "d_", ",", "nt_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"f0", ",", 
      RowBox[{"dt1", "=", 
       RowBox[{"N", "[", "d", "]"}]}], ",", "dt2", ",", 
      RowBox[{"p", "=", 
       RowBox[{"N", "[", "p0", "]"}]}], ",", "pn", ",", "pt", ",", "pp1", ",",
       "pp2", ",", "i"}], "}"}], ",", 
    RowBox[{
     RowBox[{"pt", "=", 
      RowBox[{"{", "p", "}"}]}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"f0", "=", 
         RowBox[{"N", "[", 
          RowBox[{"f", "[", "p", "]"}], "]"}]}], ";", 
        RowBox[{"pp1", "=", 
         RowBox[{"norm3", "[", 
          RowBox[{"N", "[", 
           RowBox[{"p", "-", 
            RowBox[{
            "zp", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
           "]"}], "]"}]}], ";", 
        RowBox[{"pp2", "=", 
         RowBox[{"norm3", "[", 
          RowBox[{"N", "[", 
           RowBox[{"p", "-", 
            RowBox[{
            "zp", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
           "]"}], "]"}]}], ";", 
        RowBox[{"dt2", "=", 
         RowBox[{"dt1", " ", "2", " ", 
          RowBox[{"N", "[", "\[Pi]", "]"}], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"Min", "[", 
             RowBox[{"pp1", ",", "pp2"}], "]"}], 
            RowBox[{"norm3", "[", "f0", "]"}]]]}]}], ";", 
        RowBox[{"pn", "=", 
         RowBox[{"p", "+", 
          RowBox[{"0.5", " ", "dt2", " ", "f0"}]}]}], ";", 
        RowBox[{"f1", "=", 
         RowBox[{"N", "[", 
          RowBox[{"f", "[", "pn", "]"}], "]"}]}], ";", 
        RowBox[{"pn", "=", 
         RowBox[{"p", "+", 
          RowBox[{"0.5", " ", "dt2", " ", "f1"}]}]}], ";", 
        RowBox[{"f2", "=", 
         RowBox[{"N", "[", 
          RowBox[{"f", "[", "pn", "]"}], "]"}]}], ";", 
        RowBox[{"pn", "=", 
         RowBox[{"p", "+", 
          RowBox[{"dt2", " ", "f2"}]}]}], ";", 
        RowBox[{"f3", "=", 
         RowBox[{"N", "[", 
          RowBox[{"f", "[", "pn", "]"}], "]"}]}], ";", 
        RowBox[{"p", "=", 
         RowBox[{"p", "+", 
          RowBox[{
           FractionBox["1", "6"], " ", 
           RowBox[{"(", 
            RowBox[{"f0", "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"f1", "+", "f2"}], ")"}]}], "+", "f3"}], ")"}], " ", 
           "dt2"}]}]}], ";", 
        RowBox[{"pt", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"pt", ",", "p"}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "nt"}], "}"}]}], "]"}], ";", 
     RowBox[{"pe", "=", "p"}], ";", "pt"}]}], "]"}]}]}], "Input",
 InitializationCell->True,
 AspectRatioFixed->True],

Cell["\<\
Test it (note that the solution can be rotated interactively):\
\>", "Text",
 CellChangeTimes->{{3.420923085265625*^9, 3.420923133171875*^9}},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"line", "[", 
   RowBox[{"trace", "[", 
    RowBox[{"U", ",", 
     RowBox[{"LeafCenter", "+", 
      RowBox[{"Re", "[", "ComplEvec", "]"}]}], ",", "0.02`", ",", "50"}], 
    "]"}], "]"}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[
  {Thickness[0.001], Line3DBox[CompressedData["
1:eJwNlHtUjHkcxhNOzalWiozbzO/37m6qiS4i3tfqSTfLLpZoQlRCJBWRFadC
Sro40XYqaWSzg+2CilmdUtnIaJo6UlqTKOm2S0mMy7TvH88/z3n+eL6f7zkP
DQxbu11fT09vPq/xvDKTf9wYlUwwuD5O0j5OjDmKTPu9czio9M7qD+0jSFZJ
70d/FUHwQnbQyIxDkSLiYeAmgqqXU29oxkS4LE9I0nxmEWni3/nMg8CCy7/y
q0CM11EOS990sxhr//fjSUeCFZkbHD/OEGOlorZ9TQOLCY8W098pgUfoEoXD
AjFatD2rRWUsGi0tq34zJ3h402inxFeM64269yfPs5hh2vy0y5AgVVAbb5Qo
BqM97td6nEVCo/DUfH2C+nVj83Q1YiQtkcyND2HxYt01rxV6BHf7utJiJhIs
GGrJ5bxZvF5vaDIynqCjNGLSUnuCCm25smspC0u5xWCbCcEsY4P+HQEECcTq
wAVbFvWyqCBWRDCu0im0JZOgzjnWRyZi4Xqte1uJE0Fu/cHi6CaCK6+zOvqn
srB9UfCNcA3Bqb9SjpQYUdxz9Tj9yYxFrGjraMtegpBb+aTVjaLNdVfZRT4v
J//4eaURmN0uytBGUcyXqVJtZ7PwEdbmCksInswUrPx6maJD9U6/0IrFggzf
OH81gZuLR+dRNcUvAZaDrDOLR/UlI+lvCPYfTqo5NUIxlLMvZMpyFnP3yIt3
mFAUyWuOB5sz2O0QmluwkcXsROPBCmuK9j3S3si5DGz8XFaf2MuiYVGJe5o7
79sETjRwYxCWUzqwk+es3RXo2OVHYTs853SwN4OyE9GraBaLcIu6+OoDFPc1
lX+rAhjYRe2Xny1msX+0Kcg+maK8YFmGTwiD/p4dyUV1LAz6lLfmXaSwmFTa
ahDBwPPqjafBHSzmld1dXlJKIf6QdezhPgZeqkBRxSiLPxINhdl1PC/1sHV4
OIPV5W4TZJM4fLn+OKvyCYX+hhaL4l0MSncGbJxozWHZ+Le1T7spwo+uPfLd
Fgbp1f4r1cs43HT0FKW8pdiiyRvw+ZmBZZ6pb9NmDmoXz9TNWoriq5O/1ixk
oGqM7qg4yOfbzp0o1FF8q05C53QGDmekUnqGQ8DhDoVyjGLaioFcj1GKB4cU
vX5yDhFZzLmPnykSJrhPVykpvo+TjJyv5PDOMEdyephiRoOzb3M2BfR7vNub
ONQ66RRMF8VWwRRBYBCFu3u/9Vgnh62TnWY9b6BYJa26vMmG4mJMwXThAAf/
UGF8zE2KvtqXWMz/2VNYKst8w6H7zoNtXhkUeYWLjdPKCHJeFRjG/schrsL3
ZHEkxRMHq/fRMQQ143qTfHo5yOxHvc3WUVyqbozatIrA2SV09pCGAyqteqId
eJ6yL5VKhkCi3pJvp+awSJ0uyDel0Njtfn5PK8aiwqZ3mioOxhbC8uG3BEfb
L/k13BYjIywy+0Ihh6sf0iPlzQRHlNO2f4oTw6W6La8/i0OfYubtZ3w/Y7vh
xERv3v9pt3BaPIdWmzJdRja/G5qF5+/biXHIyz52cxiH2HjprOZY/h69oF6J
uRjm93RKjZRD5uNXd1KC+X71f5r66ERY+MOZtCJXDv8DbGoU/g==
    "]]}]], "Output",
 CellChangeTimes->{3.483842289140625*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Paths for various Rayleigh numbers", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Lorenz original parameters", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Starting in one of the planes, some distance from the zero point:\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.42092315284375*^9, 3.4209231625*^9}},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Rayleigh", "[", "28", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"p0", "=", 
   RowBox[{"LeafCenter", "+", 
    RowBox[{"7", " ", 
     RowBox[{"Re", "[", "ComplEvec", "]"}]}]}]}], ";", 
  RowBox[{"dt", "=", "0.02`"}], ";", 
  RowBox[{"nt", "=", "500"}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"line", "[", 
   RowBox[{"trace", "[", 
    RowBox[{"U", ",", "p0", ",", "dt", ",", "nt"}], "]"}], "]"}], 
  "]"}]}], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[
  {Thickness[0.001], Line3DBox[CompressedData["
1:eJwNl3c81W0Yh63smb0d6zjnGMfezvcYpSWlNCSyGshIWqgoyUq9RYWSykpa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    "]]}]], "Output",
 CellChangeTimes->{3.483842289484375*^9}]
}, Open  ]],

Cell[TextData[StyleBox["PB 1400c: 53s",
 FontFamily->"Times",
 FontSize->9]], "Text",
 Evaluatable->False,
 TextAlignment->Right,
 AspectRatioFixed->True],

Cell["\<\
The tight spiral is inconvenient when one wants to visualize the attractor.  \
Below we use a larger Rayleigh number, to open up the spiral:\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.420923186265625*^9, 3.42092319428125*^9}},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rayleight number = 60", "Subsubsection",
 Evaluatable->False,
 PageBreakAbove->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Rayleigh", "[", "60", "]"}], ";", "ComplEvec"}]], "Input",
 PageBreakAbove->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.2892161349290839`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.28412508009127924`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"0.6975306299695726`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.13503915100552036`"}], "+", 
    RowBox[{"0.575189024677771`", " ", "\[ImaginaryI]"}]}]}], "}"}]], "Output",\

 CellChangeTimes->{3.483842289515625*^9}]
}, Open  ]],

Cell["\<\
And now, a trace, starting from a point in one of the leaf planes:\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.42092325025*^9, 3.42092326915625*^9}},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dt", "=", "0.05`"}], ";", 
  RowBox[{"nt", "=", "80"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"p0", "=", 
   RowBox[{"LeafCenter", "+", 
    RowBox[{"7", " ", 
     RowBox[{"Re", "[", "ComplEvec", "]"}]}]}]}], ";"}], "\n", 
 RowBox[{"g", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"line", "[", 
    RowBox[{"trace", "[", 
     RowBox[{"U", ",", "p0", ",", "dt", ",", "nt"}], "]"}], "]"}], 
   "]"}]}]}], "Input",
 PageBreakAbove->False,
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[
  {Thickness[0.001], Line3DBox[CompressedData["
1:eJwNk1k4FAoDhm3RyRJZskyDYWhoMmOXypfdYBZLlFKSMrSgkSwhRZLsZc1W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    "]]}]], "Output",
 CellChangeTimes->{3.483842289609375*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\"Strips\" on the leaves", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Looking for a dividing line", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
So, the trace starting at 7.0 times the eigenvector falls off after three and \
a half turn.  Lets look for a narrower trace that makes it four and a half \
times around.   \
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p0", "=", 
   RowBox[{"LeafCenter", "+", 
    RowBox[{"6.5`", " ", 
     RowBox[{"Re", "[", "ComplEvec", "]"}]}]}]}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"line", "[", 
   RowBox[{"trace", "[", 
    RowBox[{"U", ",", "p0", ",", "dt", ",", "nt"}], "]"}], "]"}], 
  "]"}]}], "Input",
 PageBreakAbove->False,
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[
  {Thickness[0.001], Line3DBox[CompressedData["
1:eJwNk/0jE4gDhxlFLi/lNa9jm7fNbBa6qXyIaG22OULUt5RyKkSOK5W8VZLX
is5JDrdaoe7LlXRG+noJl7cU4kLeTolIIvn64fkLnucx9A9xDyBISUkJV5BZ
4XkYqf/WKxqKTSzf1KoycXi68q8iZR60918qrxNZwHv+98hQFSaKZB42yXfw
8OS868i0Kx0P7iy4ZpUw8DmZfvvfq27Qilvc9peIjnXHtrB7Gi3h8q0v2ZfP
R0GKqWJQIR2b1p3z19tlgZ1XTn9teM9HyVZB+yktOnK9JlSm1c3x2NPR4Kq5
AI2TrDyjSRq+DoWOfgkxRvHy418esASwfj/PdnGiwivfZrxJgwQVnWW1FkUB
TuYtUwIDzdD7oVW+JJuIbR0x7Wcv8tGtHC/m5ppgfZV/fwNZH3WJpxnh7W6Q
zWxWmJA2Rk+79X3vp7pIYhf84vCdG5LKhybl8sn43bOI09isi1hKi/xnOx6S
6stYC3EkdJcO9jeZ6iPeJLWy7BAXa4OeFmRIjPBZsTqsL5qIusGjBOWUnVDO
a5ndd8YI9m2XTaubjOBe4fgm4jEH3fWDiatXkUDzG+MHs41xIXNdaogKB7nP
ht71ppBRMD/Sya80R+nnpbBj9Tvgf+2Rz1iXMeJyeX+U7rKEE+Gpc5oqBwUB
V14RqWbw8ohsehHMxHhK7mlOKwfif0JvOtlQ4anKaaRcssLM5l1m76p3wqDo
5/uGUzT0UNf4BKizQNY8/HqqjgsZtdiYw3vo6GKbuFXosDAVzSnofcHDa69a
z+KTloh2KswJzLXCE1uNeO9hN7jXEt+/1magYuuIMTuVia7cD5L6MT6C7PUM
zlszYGjrVePRYolHig/t4g8KEB4d4B88YYn8WT+N4/+hIntc1YRwXwDTtKBl
3at0KJQrWH9wN4ZCzbi3fJ0ARrGzgzfO0pD3xCzMNsUQoRGJ/YE5AtwdELJ6
Zc1RPzDiufBEByoNSpTlLQLYFM+N6iWYQBKs19qnrQnGMbGfxwU+vo2htMeW
gj6zLyWJnWrYEmOolHXKDT0DFsdrWSTkJVC0A86pIbrb5sp7fx4OfEyOYJ83
xE/Ocm7to+pwsxTmPgEXZ6LDyMpcIsrOUxoXtDYgyTcsSVt9J04cPOEcHmoA
+WMa24PP6ON/aTrtj0Z24JT8qbhQGhFKr4Z67cJJ6ChXckKnK4h2gffk9Ixw
ZCQjffqsGSTLDrKlTFdsNIBMrw8F4qqG9jIWA8tiP82pI66IKCXUXnpsCuFX
h5DJr1YQeLWlcQN2QJTjR3IupuJ5Pa1FpXkjHqZWaeT9yUGdCVlJRKZDqH9V
563EGsLblvuiqVw8p2c3nNFkQHSIaUCZsob2jT/EeqUrfmtih3VHGHjYx+3s
3muNmFNhvkkb+fC9mcWkn2AiNDvl54lvLITfC62c8RAgtjR04exdJlaL7xml
1DLhq5H+o8q8ALSMou6448yVfnNsPaMsIFeW9W7miBD39mXWbhYzwIgj3fy4
8i8n/2679zUh2OukHd3K6fgaL4j6wjDA0oPR9YQgIRJLKwq69lMRFMLNXbdV
DZXBJyIVZgWISZ3Tqn5lgqnZFmaVhgJeVrdHTgoFcJM6+F/+T2TIsvc0NuYR
0HxZWrx2Ex99jVHtkkBDpB1qKTQvk0KmbPIB9Uoemp6XM0mZeshxpAzrusjA
PyvcgcXggkbx99wavgE6yspyH5bXoM/l+VhbOgeiI+EVOp80sJxuozleuR5R
hwZDinpd4SmM7ZvfoAl1BdG18QUdeGSk5xvqu0BwJUHD7JoOHrmuvS3Ko8BH
9cCq+T+dkfvt9D8zV4zQ6oO0cjsGtHP8JBrpzthvqy0pbjOBfe/EZoKcNXYm
vI017N0OUf1vaYQtNBy9Ez2aZ70Jjul/W61qcIVFT//syFtL8MnE64XSbFTV
6FKHZjh4xxAFsSKY2O08Obwlm42epvmlfWweFncYML6JrWDc8axrN4GNpWgb
47YEPtaMtZo9uMjCrDjL/gVzE+72m/ue6xOgcPaZ78V5FiYzJ+O2aVmjNXiP
/psuIVTCNTaRO1gYj9xIWtXMAMtiNqk0xR0DpL28c3NW6FxatB/+0QR7w5Y+
fT/gjsv2iztqfJhYO9KhFemvjWrpA8W9Fe6wLLzFe+pMR4Zssn57JgF9Nw+a
vCC7Yxjjr1SszZD8w68qTYNDkv7XJRn/ugoR5R7PsFMko7ZXSvx6ULpafX0x
tYErgGCNgYKVuz52HfKrP8ldXZ0vVLwVeskNY6JG9akodVw/6G5qlSNbfeP4
3k+yIVwk1v4aO9P0HV4WCEedS5YkxXsX5h6xOAjznFeVNpVCTI1+q4X5hIQY
oWb+Q4ULCpMrvT3ufLSf6k9YvL66zf5l+vR9TrcTJrS+55Wv+Wj/YLeugxVn
0f5hxP76oJMOaNbRoV7IWw0ZqU9Z/hItdGabfiqussM2qY8Wc9UkHCGMnKyZ
toHFb5UV1XObMXCfaNZ9gwYtpa3ays/s8fQosVBV3hHPitUcwla+EsvH/a2X
5Iieshg53sbt+D+7g1qK
    "]]}]], "Output",
 CellChangeTimes->{3.483842289671875*^9}]
}, Open  ]],

Cell["\<\
The new trace makes it.  Thus, there is a dividing line that passes through a \
point that lies somewhere between 6.5 and 7.0 times the vector \
{0.269976,0.706249,-0.139604} away from the LeafCenter.  By trial and error, \
we find\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p0", "=", 
   RowBox[{"LeafCenter", "+", 
    RowBox[{"6.66`", " ", 
     RowBox[{"Re", "[", "ComplEvec", "]"}]}]}]}], ";", 
  RowBox[{"dt", "=", "0.05`"}], ";", 
  RowBox[{"nt", "=", "77"}], ";"}], "\n", 
 RowBox[{"g", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"line", "[", 
    RowBox[{"trace", "[", 
     RowBox[{"U", ",", "p0", ",", "dt", ",", "nt"}], "]"}], "]"}], 
   "]"}]}]}], "Input",
 PageBreakAbove->False,
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[
  {Thickness[0.001], Line3DBox[CompressedData["
1:eJwNk2s8EwoDh6e5JRXSTTa2MZcxm1trKX+0YZhZJ0esOnThnDCXLm45UVKJ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    "]]}]], "Output",
 CellChangeTimes->{3.483842289734375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Delimiting a strip", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Now lets look for a path that starts almost exactly one revolution further \
out.  First we draw one turn of the previous path:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p0", "=", 
   RowBox[{"LeafCenter", "+", 
    RowBox[{"6.66`", " ", 
     RowBox[{"Re", "[", "ComplEvec", "]"}]}]}]}], ";", 
  RowBox[{"dt", "=", "0.05`"}], ";", 
  RowBox[{"nt", "=", "20"}], ";"}], "\n", 
 RowBox[{"g1", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"line", "[", 
     RowBox[{"tr1", "=", 
      RowBox[{"trace", "[", 
       RowBox[{"U", ",", "p0", ",", "dt", ",", "nt"}], "]"}]}], "]"}], ",", 
    RowBox[{"ViewPoint", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0", ",", "1.4`"}], "}"}]}]}], 
   "]"}]}]}], "Input",
 PageBreakAbove->False,
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[
  {Thickness[0.001], Line3DBox[CompressedData["
1:eJwBCQL2/SFib1JlAgAAABUAAAADAAAAMpFwK1rwLEC2JLYDVjAxQI72QL/h
DE1AYppW8CfELUDUCtce8SwxQK92cIkj1U1A09zT5PVoLkCjOuw0iMgwQC4b
aPXVnE5ANjGkRt3JLkBcKoTKPPMvQB17kbzCWk9AoKFo13HGLkAQkwSGf28t
QEUaNvLe/E9AWgGPiXU3LkAf7jgCyhoqQHw2MiY/M1BAL5dnkqkGLUCJkht6
h14mQPw8YcOBPFBATgTVx1xTK0CWna80OvEiQEc28/evFVBACvNiU1tsKUAj
l95aJmQgQGicQEXrlU9AWg9h5+2VJ0DigoAih6kdQB0yY5es2k5AWo4+LgPw
JUDuWMGD60AcQG8B9NDqDk5AbkRXndOFJECwtpw3HkkcQGf2LuTdOk1Asedj
JQZhI0CXzW+Rp6sdQFBzESGjYExAIHABi/WWIkCupMzCE0UgQEZFI/i7gktA
BNAUl1JTIkAiSiwldZ8iQOlOgRKjq0pAsQIQ+NbcIkDkFSGbHCEmQKefhgh1
+klAkgNLbzhxJECnfdxSB78qQArPgdGUrklAxp7IZ1jJJkB6aqGWFHsvQHOE
IpNZ/ElAKp9Jve0sKUCMr4S/no0xQMhtaLMMvkpAp0d4qdFEK0DrB/XD47Ey
QB8xBPAEtUtA6uDiFi4JLUBM5WJDHkAzQM7RW2frwUxA6YvWWg==
    "]]},
  ViewPoint->{-3, 0, 1.4}]], "Output",
 CellChangeTimes->{3.483842289765625*^9}]
}, Open  ]],

Cell["\<\
We can estimate, from the ratio of the real to imaginary parts of the \
eigenvalues, how much the spiral growths in one revolution (2 pi):\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"growth", "=", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"N", "[", "\[Pi]", "]"}], " ", 
    RowBox[{"Re", "[", "ComplEval", "]"}]}], 
   RowBox[{"Abs", "[", 
    RowBox[{"Im", "[", "ComplEval", "]"}], "]"}]]}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData["0.3129096085118981`"], "Output",
 CellChangeTimes->{3.483842289796875*^9}]
}, Open  ]],

Cell["\<\
So, we multiply by Exp[] of this, and the result is indeed pretty close: \
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dt", "=", "0.05`"}], ";", 
  RowBox[{"nt", "=", "20"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"p0", "=", 
   RowBox[{"LeafCenter", "+", 
    RowBox[{"6.66`", " ", 
     SuperscriptBox["\[ExponentialE]", "growth"], " ", 
     RowBox[{"Re", "[", "ComplEvec", "]"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"tr2", "=", 
   RowBox[{"trace", "[", 
    RowBox[{"U", ",", "p0", ",", "dt", ",", "nt"}], "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"polygons", "[", 
    RowBox[{"{", 
     RowBox[{"tr1", ",", "tr2"}], "}"}], "]"}], ",", 
   RowBox[{"ViewPoint", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3"}], ",", "0", ",", "1.4`"}], "}"}]}]}], "]"}]}], "Input",\

 PageBreakAbove->False,
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[{
   Polygon3DBox[{{14.469437940112218`, 17.188812477081875`, 
    58.10063925430323}, {15.177112275056714`, 18.895579372325013`, 
    57.77021598313016}, {15.726476536541279`, 18.878536605223815`, 
    59.91881459233977}, {14.883117209026015`, 17.175554206371842`, 
    59.66514699927699}}], 
   Polygon3DBox[{{14.883117209026015`, 17.175554206371842`, 
    59.66514699927699}, {15.726476536541279`, 18.878536605223815`, 
    59.91881459233977}, {16.153576117865306`, 18.330376959727555`, 
    62.05470408467169}, {15.205001021253713`, 16.78332834975539, 
    61.22527949889478}}], 
   Polygon3DBox[{{15.205001021253713`, 16.78332834975539, 
    61.22527949889478}, {16.153576117865306`, 18.330376959727555`, 
    62.05470408467169}, {16.403704430669073`, 17.203428734559065`, 
    64.07091622700948}, {15.394266326468465`, 15.975073174127083`, 
    62.709067889247514`}}], 
   Polygon3DBox[{{15.394266326468465`, 15.975073174127083`, 
    62.709067889247514`}, {16.403704430669073`, 17.203428734559065`, 
    64.07091622700948}, {16.394332449287333`, 15.463667353104793`, 
    65.76918095799554}, {15.387587291262037`, 14.717769802149206`, 
    63.975553776185315`}}], 
   Polygon3DBox[{{15.387587291262037`, 14.717769802149206`, 
    63.975553776185315`}, {16.394332449287333`, 15.463667353104793`, 
    65.76918095799554}, {16.027938404367514`, 13.184956905134099`, 
    66.8514205809698}, {15.108318613726329`, 13.0523224539275, 
    64.8007293215141}}], 
   Polygon3DBox[{{15.108318613726329`, 13.0523224539275, 64.8007293215141}, {
    16.027938404367514`, 13.184956905134099`, 66.8514205809698}, {
    15.248958809514917`, 10.657384794643745`, 67.01891528293727}, {
    14.513012480874378`, 11.1846273573549, 64.94542011733932}}], 
   Polygon3DBox[{{14.513012480874378`, 11.1846273573549, 64.94542011733932}, {
    15.248958809514917`, 10.657384794643745`, 67.01891528293727}, {
    14.127508199718502`, 8.35087867420484, 66.19794162217511}, {
    13.662817234757451`, 9.47114720004792, 64.33886526824163}}], 
   Polygon3DBox[{{13.662817234757451`, 9.47114720004792, 64.33886526824163}, {
    14.127508199718502`, 8.35087867420484, 66.19794162217511}, {
    12.850801049215258`, 6.634717858478011, 64.63834771879134}, {
    12.711634260014325`, 8.195605125114133, 63.17124238638718}}], 
   Polygon3DBox[{{12.711634260014325`, 8.195605125114133, 
    63.17124238638718}, {12.850801049215258`, 6.634717858478011, 
    64.63834771879134}, {11.594539848354607`, 5.587559060945774, 
    62.686677008436604`}, {11.792830687139645`, 7.41555456075068, 
    61.708392070231845`}}], 
   Polygon3DBox[{{11.792830687139645`, 7.41555456075068, 
    61.708392070231845`}, {11.594539848354607`, 5.587559060945774, 
    62.686677008436604`}, {10.451299727489946`, 5.116198759082458, 
    60.56456916672977}, {10.968774266372908`, 7.063398417163837, 
    60.11654102243744}}], 
   Polygon3DBox[{{10.968774266372908`, 7.063398417163837, 
    60.11654102243744}, {10.451299727489946`, 5.116198759082458, 
    60.56456916672977}, {9.458422481800794, 5.118629571296108, 
    58.355525616997056`}, {10.26138011636996, 7.071404332103768, 
    58.459896586352265`}}], 
   Polygon3DBox[{{10.26138011636996, 7.071404332103768, 
    58.459896586352265`}, {9.458422481800794, 5.118629571296108, 
    58.355525616997056`}, {8.645131398081217, 5.550682775558883, 
    56.070921970941946`}, {9.689500015683594, 7.417631409119529, 
    56.754978307266924`}}], 
   Polygon3DBox[{{9.689500015683594, 7.417631409119529, 
    56.754978307266924`}, {8.645131398081217, 5.550682775558883, 
    56.070921970941946`}, {8.069363538845932, 6.443357660862026, 
    53.71431585304282}, {9.294842094350372, 8.13491638897025, 
    55.021361367437336`}}], 
   Polygon3DBox[{{9.294842094350372, 8.13491638897025, 55.021361367437336`}, {
    8.069363538845932, 6.443357660862026, 53.71431585304282}, {
    7.85033003266866, 7.917413927478676, 51.35919918053814}, {
    9.162739487925144, 9.31144062200207, 53.34091407121543}}], 
   Polygon3DBox[{{9.162739487925144, 9.31144062200207, 53.34091407121543}, {
    7.85033003266866, 7.917413927478676, 51.35919918053814}, {
    8.193241794413632, 10.188912750236973`, 49.302423253337594`}, {
    9.431327583269509, 11.064671371258505`, 51.95669657300396}}], 
   Polygon3DBox[{{9.431327583269509, 11.064671371258505`, 
    51.95669657300396}, {8.193241794413632, 10.188912750236973`, 
    49.302423253337594`}, {9.307324726047865, 13.372503251774278`, 
    48.29055972487231}, {10.221133687884308`, 13.373102750220665`, 
    51.363916576750924`}}], 
   Polygon3DBox[{{10.221133687884308`, 13.373102750220665`, 
    51.363916576750924`}, {9.307324726047865, 13.372503251774278`, 
    48.29055972487231}, {10.988218699384806`, 16.787193604392822`, 
    49.07605987405909}, {11.393252604713222`, 15.74039145203027, 
    51.9714836042921}}], 
   Polygon3DBox[{{11.393252604713222`, 15.74039145203027, 51.9714836042921}, {
    10.988218699384806`, 16.787193604392822`, 49.07605987405909}, {
    12.654167712516966`, 19.40561424735592, 51.20607915640932}, {
    12.587751307713535`, 17.55320355405233, 53.484762598028794`}}], 
   Polygon3DBox[{{12.587751307713535`, 17.55320355405233, 
    53.484762598028794`}, {12.654167712516966`, 19.40561424735592, 
    51.20607915640932}, {14.083840310804, 21.05599068790617, 
    53.92052912796771}, {13.634412094051937`, 18.694881675073628`, 
    55.41421318249399}}], 
   Polygon3DBox[{{13.634412094051937`, 18.694881675073628`, 
    55.41421318249399}, {14.083840310804, 21.05599068790617, 
    53.92052912796771}, {15.280530333049533`, 21.869437652468807`, 
    56.87298445581161}, {14.517929759211672`, 19.250461780209022`, 
    57.51499645217301}}]},
  ViewPoint->{-3, 0, 1.4}]], "Output",
 CellChangeTimes->{3.483842289875*^9}]
}, Open  ]],

Cell["\<\
We now have one \"basic strip\".  All points further in belong to similar \
strips that map almost exactly on top of this one. \
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.420923341421875*^9, 3.42092334209375*^9}},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The strip continued", "Subsubsection",
 Evaluatable->False,
 CellChangeTimes->{3.420923483703125*^9},
 AspectRatioFixed->True],

Cell["\<\
We can trace from three starting points within one strip and continue until \
the strip almost has \"touched down\" on the other leaf.   For a better \
visual effect, we cut away 10% of the strip. \
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.42092336396875*^9, 3.420923371078125*^9}, 
   3.420923483703125*^9},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"cut", "=", "0.05`"}], ";", 
  RowBox[{"dt", "=", "0.02`"}], ";", 
  RowBox[{"nt", "=", "200"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"tr", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"zv", "=", 
       RowBox[{"6.66`", " ", 
        RowBox[{"Re", "[", "ComplEvec", "]"}]}]}], ";", 
      RowBox[{"p0", "=", 
       RowBox[{"LeafCenter", "+", 
        RowBox[{"zv", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"cut", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", " ", "cut"}]}], ")"}], " ", "i"}]}], ")"}], " ", 
           "growth"}]]}]}]}], ";", 
      RowBox[{"trace", "[", 
       RowBox[{"U", ",", "p0", ",", "dt", ",", "nt"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "1", ",", 
       FractionBox["1", "2"]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"lines", "[", "tr", "]"}], "]"}]}], "Input",
 PageBreakAbove->False,
 CellChangeTimes->{3.420923483703125*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[{
   {Thickness[0.001], Line3DBox[CompressedData["
1:eJwNl3k0FA4Qx92UI0eU+77X2l3rDt/k3LVr15mzUrmLXEW6qJArlNJBdNKB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     "]]}, 
   {Thickness[0.001], Line3DBox[CompressedData["
1:eJwNVmk8FG4XlbKTfV9n7Exmse+HhDHGzNhSlOVVSAsVipQWZPmXtCkplBQV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     "]]}, 
   {Thickness[0.001], Line3DBox[CompressedData["
1:eJwNl3c41X8Ux42MUCI7Gdce97rDXvdtj3uNa5ZkVCQRWmbRkKQkIUURRVEq
Ixnx1dDCL1E0FJW0jSQl+t0/zj/nOc/n8zznOef1fh/VdTFeYXw8PDwPuMHP
jTQeU9d2Bwq+uvMsF+yigzUaxys8ykaFEo3D30zBIlsHpYHndCRRFx0je7ph
niOlL6BlAE6k4jGNPjryA3T5drW6oc19+trOLAM07j2Wxmqk42iT0USyjjv+
DuwWeTBqAEPdt3xr0ulQmNn5KbPAHf6df2dFFKgIaM0so1nScb9jv1YPnwd8
jMSXCplTMeJud6vgBQ1t4VNf1KM9cMAnpzSeQ4WW8caBiGAa8pfu6FzS74Hw
89s33w6iwkFG9+DQAyokKg/e71HwRNbMf+fVQ6gI9VLXGZCnwneP8pFWJ0/M
5+hP3Pam4mNvmfepUgquOzrPx8R4QnDTtcAxEyqs/6M82fFGH1IsZnhEjif+
y+1pMBalYrju18zkrC7KSfFUrYueSC25tVnhlAGK/IRaq35ro8hg9Mi6G56w
GB2MyJijgBmenpY0qYk2s9ldzJue2JhcInLRigLpC7USjyfVEXEwlLSn0RPL
tXrXpoWR8bomzmatqBr8jhTOFlZ64mxK//jGRH0c3jBuOMxSRYrFODs72xPC
YnHuaml6KImTf3M8URlFLcnendGeKHnW1CCQpotZt6+Kip2KMH+hEn7b0RP7
hJlLI3brQESBt/VGqgKGf6ZoTXD707akcGl8qjbsf1+xOFQuh/WJvRf/PfPA
UcXCKdsDWiiwrbrZqCcLu7zKyjtbPaD1ql34R54mfv7MWm4rIYOURd1OWSIe
oNQF2Ate1oD8QogLy00aATdLLliWuON4kfHc8f/UYV5+w37suRQCL9Yph9Hc
oW9vUZ0xr4YO9u/7J2ql8Hndi1uuHW5QbfQxGjBRw0KJOzWvXwp+bUmlfB5u
UPGiGDekkrBzwzR5xloaX6Uy7ux/wca84qm5jmeqSPh67tPQlDSYjt3+xHo2
7o1Xn7JiqqImL2Ti5A8ZLOxXkK/9zEL4C99Zy1YVjPfQBp87ykF3vjkpLYYF
CcX3F0Y4KtC1EPvwaVoeXh95xMqmXPHmQ9yjowIquFDRdPGdsCKYmnzxUjtc
EWF7KketVRlOqSYn83OUoDmh5lw964K2OC1dvnvK+Dmb8fhutwpOfzOzSkpz
QXR5DlGspILONyc7BYtJEG9JqmNLuOAxPX3NvwIVXD8qoGZ8XR0kxeT+sWvO
aOmoudrtoYphywPGK2S04LsskZ4S6YzzqbunP9iRoJB6qIldqYPygPKFYltn
7CxMMecNU4OZ66Pd3531YT6nMOts7YzVZXPTaqXqiO93ipsboODzh7izGwKd
EdBjIqzxXgNZApKiM8VU7Pvg8HxZoTNygk55LtHQgnjDt7TJKzQUDX/iMfni
jOdGb/d9XKONqbxA1r+zdATF/L7o4OmC/N3kAMt0HVgrXF56dysDlalCxl23
XPCvSO5ecYkuKGlamQpqhhDaGByewHQFSyvFo6FKD9mq7zim9YagrC+SHL7t
CnLRG+XaCn1ENgiWOmkZQa4/k+PgzgLHbdOW0eNkJO+I6NDeZYTtBVFX1w2x
MLRRKfzoVgoa67Kl/a8bgW3c8waxbKSVmizcsDWAWE1i+NATI3gExvcsF3TD
Fp6jUWJ8VEy4jkT5cPOjIpI3FM+4weKbVeVCABUhzwXtPtUZIXBgUPKoiTsK
rU1Ki6up6F3v/XvzTiNkiOSO7Ox1x6/lv3IW/6DC8d9rowg5I7zI4T1bEsnl
j3DLiRVUGsrLzWVZhYbgNeH/cZPHE5EP7/b5h9IgI2y/7dQ0A+obriQIuXqC
RaTzTu+nISNOMM9Gn4FZ+mDut6OeqGx8ETBSSEOMlM3YT2s6lKYeWXx77IkC
Hk7Z6CkaVJN3+Fwj09Alp6JvL8qBpfCmhHsHaag6PGcUPWOAlO8BWvxWHPRI
GS3khNBgOJfYJLqajJgl71poGziwoF2+MKpCg/rhhxEGubo4tqfUe1EqBzcm
6o+u5XKzj9x7cE2DFp7y70pXOsyBW03/YBe3Py5DdVWU5+rYnjYS/eQQB431
9ap1NQaQmpj78F2KhJR2yZtOyRzoZQn8LdpPge6J+wieU4LfnWaxxCAOpnRu
OQUzyRj9sSNuyEkBYaZCGwWMOZjp3eydMKYH51TBPbXqMshc06n2gZ+Dur79
T8f262Kap6uprUgSFsm3eUgPPRFP+tRYqKSDkCD71l8B4hhvNI44dsgTvzZX
xis3a8FmRcbc/UoRPGzXbm7hcm/F8eqejjWamCYm2bkiQqhTTFYp+OcB92nr
JdWCGogdy7ClRy/CdqWVOUpcfUmqmi82uqmGA6GDsrzNfBB7N2cqOeCOUcmA
ZvM9JFQFDki/G+KFtAUva8LKHa/yk8xCfVTRsSlty94HvPBu47T1nnXD69/N
qZtMVbCVvnOSfysf3rrtxz4+Nzj2NL4dD1JCfrmYWFovP17uUnE8HcxGnLGE
Q0eCIvR40z6njQmgpqTep/gGC2+u9GWM31XAqodU6t0mYZCunFo7L8bCqjrZ
q/2e8pj0G7E/4iuGLp+lYRsCufs1fPW7nZYc7P/c8R2OWIZtUS0HBipcoH+A
7R22RhaVA17fJXWWY9XB/bVK35wxpK7hemCRLCRdfNJq02Ww0oV0PpTmDKPP
/rJrmLKQ23PtzFCZArpe5V5XT3BCQ0ftO0l9OUhvytt4pVoZfvE+Py89cMTQ
7pnJ/R/kIbr4zVVihARzw6MDFgxH+N9Ss8naroiBh8InBLZqYv+yPBWeTgds
/i19rq5WGV/NJQaz1uoieErC/32OAxrDG066XlbFuSCbxNIgCg5kzGavLnSA
Vp+0zOtcNaie0g4hFGgYlhcPuPDUAUqxvzUebdWA7IeaftJrOrR/5RumWzki
rdExnGmjBYGDH0nb4wzxM/3p5ZC7jrgsp9i8mqvTv/q9rOu5HNCWiq0QDXMC
w9Ij5MZJXXCUy74e4jOB1ee6B8dlnJGessErh6QP62KZlkw+U7zT0I1ueuoM
R57RuLo8MqSWksx8+03BCsl0iS1xwWuvkyfEJykY1pdvtU40w+kg6/O74lzh
d8lJ0FCRy40mq0CpKTNEfoqforiysC+mZHd+AxU7dBvLxJjm0M3ol1fVZmP0
s+WKKnsaMn0K1t0KNketsKu9pIgbxAYMRPUe0JAbmBdn6W2OExV73zV9584b
U6R9ry0dRzysOnnkzJHNL+1yrt8dxWc1v9++Qkf2psQew0tmCH9TsHlZswfk
HspKlokzoJhh49uzxAxkTtmbje6eOJYQdSoqhAGP6hfqz81Nwfw21ybF9S3z
z5yWiJcycDEvLOIpzQQfXy6yW6fFAfvuRR/5LgYG4n98ok4ZIfvL9BH3LG5e
vyWqf4QB+4xlxYMphhCYCxLK+MDByHCPaMRrBt4OJa8e6KfDt/rwymRjL8iI
LryQamcg27nf8vM/ru+TNPDbk+CFo1n0wH17GLgUzuP4YAkF/8zO+Cyr8sLY
upxpFXUGFqrOhkZ80cHBx2UrhR944fqzrjPJFXQsMXQqq2/QwJ5DR5V4+r2w
uGtCLX0xV7fmZXyKDqui6I+iWcZDL7wceaVd4UFD1jHNj2XKKyA4WQ2by17w
kNQXz0uhIqGt7PDs9eVg+eBl/y4vROukWQzrGKBtQKbvr7QIHFbPKFyy9sK2
R/n3j1mQUX1qiHpw+C9T/NrtkpNTHMS2+ZtbmurB8axH3o81b5mkWyYLScUc
FPRsecaro4NVNQeiRGpetu9abPHtqzUH1sLa529Ia2Ha/UYvK/dHO79Y3KzC
K090Je72e7BIA2Tz5kIxgfl2qaqdPFU7PBHSv67KdY6EtxsuZjvf4yVcV/1q
ui7Grd8Xts9+XgUVGceTotv4iRaKS0O7nQf0nvwtllRUwhnGOZM7RxYRBwS/
fbwY6Y7dzrsohqEKqLWNIh1etYjwsdUvf3jEDd0Tai2Kj2VgnmcjzWDyE5fr
yrrkLrGha1g3+jNmOYK7kvSHgnmJt7ZdJTO3WVBmbLtX7rIMUwHvHrXUzLd3
7RUcQZ8ror3VKjoei6Am+wGJs/9Xexk/T0LwgAu0UxNzSPUCGJjMzetMmGhX
Lzb3Cu52xstcvd/sIF5krI3IDtw90n50b/wNpVonFEfHtcV8nGMOr+nIflRz
un1lXyTp+F5HeGuuSNWw+sXcqCpTP/l1mBk+u2i3vqUDri/5m2O+8idTqSKm
VLtgitnas0xg85AdeDq+doaozzCPr6x+Sdr6j/lBpipSd6MtHsxt+nLt2ByT
dPtxgpn7YiyJqm/rGwZoQnK2bgv8mN7TN7fzqRRWC9lXy/dYI/5yy4wQTZzr
S8ocG6GKP6GCKQWFltj+6T1p5qkMLPVm0ypGdFA2PX5h8JUFAoZ7WzJklTCr
8ix8iQ4NF590HRNab4l07/jB2B0klGoE6q9bMISzaVKDVJ0VJg5y1hWc14DQ
O2e97k2maPWfb5HJZIKy4tpe9llthNWIDQ5usUBU22Z20xvgSl+Mc1+0Hqws
2lwUJa1hU3qzcpuyLZoP2TFOiFNw6fqhjm49YL16uurbZDu0koPJEg5UaPsv
rDZVtUHztqLTIeP2kOXs7ZSK5XLmQWhFwGcb5O7M/3p+hyMip0iZDzPpILdb
Krdl2KI+PFraStQZC0soX4hcBmQ7Z99H/rZFoX7YNs3LLviWc4emlGUInTNX
K79b2+HTAVrIkVUsxM2uvV+01QgpuqtfbPK3g2b4V6VMLt+6ZU1D05yNkZry
avacjR3sMnpPv293R6zdlo8nRU3wKPLCnMFfWwQMBd7dYe6JlFD3fNNmE6QZ
Jxlmp9vCekCz/owkByXj9C59L1NcMaDnxL6yQfT7hsv9oxzId9B5Hz42xYya
EOffP8C0U6hZ9JoXWq41OU7SzVBh+Oz1hmEmlCL1JW7HesOQsTVZc4cZcmza
XTcFWkHoyJYpCVUfXGujPK89bgZ6K8P3WKI5bra3lXTe5EKCaDn77JAZrELH
Sx1sTNCl+Mr7lK0vZK5kpC32N0NS6J+jzh0MPBv4pp9U7QuRs57vHX6aorOu
ybqTe1/e/LN7/fC0L8o/N2b5rzeF9ekmh/pobWw88iiGoegHJ82tY6qlJsj8
IJf887oKpCo8qlao+EFLbnFYb7UxDiYUrd7qIYnfpeff3uTxw5kY+QNfM4wQ
Zfun0YU6zrzXzcvpavfFkUspi5kmhpCo3Xzr8igfoU5t9NkY4ovHQW+/l96k
o9XBL/12rDQR5MXj9+SDD7bpDRqVKXM5+TZlY+5rZeJLUfO4yCofDPQ3CnLu
UHBvh9GlT+7qxOCFasK3yRtN51R3y0npoXlsznDsiRYxsU6wvE/cG7Gvnq9N
NdEC++9genCaLtFtOvhIP8QLe827S9eEq8F+QPD5KEefsNzveL/wOgfLZR5+
LL2kjLyyYl7mRjLBcdVRtFrJQerPNynM5fL49ZgK5VkyYV6af1I3zxNXviaL
h8xLcn2DRPFWAwrx7vWb+fXcO3e7e/5C/10RhPwlvw0lU4jg8mf8LwI9wL5T
cKk+jgdRUSz1E4spRE9WR4/taXdEPRH8Lz7vC/O7wswJv6dk4nVGmGz3lBti
XzzPVLj0X/u+mryHTqe5/wZLPMwKcIOenc+22tzp9sub7wR9jyQTsqLftv3s
ZeN4eGenOYmPyKco7xt2IBNn1p7vnvZjY2wkwPR76WJiIPuaabchmTh8L6Tk
9xgL0bv1ZqJjlxHZEjpBIdZkYvrCmJPUfhZ4vL68SVxYTqjO1bfwct9PVz89
p6nHwh61e181MmQJ1carElYEmci1//7H+DWXtxbCGeJSKwj+ycqzFFcKwRYd
Xz5Y4gr/34KtsZVKxLH3iS65Sw2Iu8vuHo7Y7oonJYxlzxRUiQ6NfQ/KBKjE
txN7uqxCXSHS+ml6vJdESEjIP9p+gkoI3meXv9vkCs7EK8GtkeoEQ/2HXQyF
Rtxp+XPZ5ogrojqXZM6/0iBI7rcND92kEeaqld/8Ol3xbpELQ1xXi6hL8C6f
s6QTet2TJ9aKs3DyXd+eXl9twkr//ejqi3QisTt08ZX1LNDPSfjzh+kQB4uD
QnJ5GYRs2QBbkGBhgw/77501uoRl+xg704FBaBRMTVBIbNjmC3/wttIjyNQG
ctgOBnHGI9q++iAb/wMVh0t8
     "]]}}]], "Output",
 CellChangeTimes->{3.483842290234375*^9}]
}, Open  ]],

Cell["\<\
Now that the traces look OK, it is easy to turn them into a polygon surface:\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.420923408375*^9, 3.420923409515625*^9}, 
   3.42092348371875*^9},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"polygons", "[", "tr", "]"}], "]"}]], "Input",
 CellChangeTimes->{3.42092348371875*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[{
   Polygon3DBox[{{14.499810923528726`, 17.262065949823867`, 
    58.08645767382165}, {14.795651669675117`, 17.9755737977894, 
    57.94832539706522}, {14.995842981223255`, 18.021681104327662`, 
    58.67437375329362}, {14.675982737565853`, 17.301514068583305`, 
    58.71627956649333}}], 
   Polygon3DBox[{{14.675982737565853`, 17.301514068583305`, 
    58.71627956649333}, {14.995842981223255`, 18.021681104327662`, 
    58.67437375329362}, {15.183499014852048`, 17.998888016823006`, 
    59.408464211782}, {14.841098192000404`, 17.281653321859864`, 
    59.35320187664972}}], 
   Polygon3DBox[{{14.841098192000404`, 17.281653321859864`, 
    59.35320187664972}, {15.183499014852048`, 17.998888016823006`, 
    59.408464211782}, {15.356408671967861`, 17.905044373241775`, 
    60.147539787522426`}, {14.993239045232635`, 17.200658131578955`, 
    59.994714946024175`}}], 
   Polygon3DBox[{{14.993239045232635`, 17.200658131578955`, 
    59.994714946024175`}, {15.356408671967861`, 17.905044373241775`, 
    60.147539787522426`}, {15.511915804204495`, 17.73699789609201, 
    60.88756107893667}, {15.130088043808803`, 17.05579582591804, 
    60.63747763263542}}], 
   Polygon3DBox[{{15.130088043808803`, 17.05579582591804, 
    60.63747763263542}, {15.511915804204495`, 17.73699789609201, 
    60.88756107893667}, {15.646762478024206`, 17.49083773644815, 
    61.62301027933108}, {15.248787886974295`, 16.843626649342117`, 
    61.276878020866874`}}], 
   Polygon3DBox[{{15.248787886974295`, 16.843626649342117`, 
    61.276878020866874`}, {15.646762478024206`, 17.49083773644815, 
    61.62301027933108}, {15.756965045267522`, 17.162281340348994`, 
    62.34637736650836}, {15.345827715578915`, 16.560326513228716`, 
    61.90657206249345}}], 
   Polygon3DBox[{{15.345827715578915`, 16.560326513228716`, 
    61.90657206249345}, {15.756965045267522`, 17.162281340348994`, 
    62.34637736650836}, {15.83774059722203, 16.74725981714861, 
    63.04765835744582}, {15.416972909006828`, 16.202183035844456`, 
    62.51802287422184}}], 
   Polygon3DBox[{{15.416972909006828`, 16.202183035844456`, 
    62.51802287422184}, {15.83774059722203, 16.74725981714861, 
    63.04765835744582}, {15.883519056161818`, 16.24276251319848, 
    63.71393712327929}, {15.457270413965274`, 15.766323070041587`, 
    63.10010018977281}}], 
   Polygon3DBox[{{15.457270413965274`, 15.766323070041587`, 
    63.10010018977281}, {15.883519056161818`, 16.24276251319848, 
    63.71393712327929}, {15.888097195088715`, 15.647984801000934`, 
    64.32918392008969}, {15.461182037182999`, 15.25171905194965, 
    63.6388561534349}}], 
   Polygon3DBox[{{15.461182037182999`, 15.25171905194965, 63.6388561534349}, {
    15.888097195088715`, 15.647984801000934`, 64.32918392008969}, {
    15.845009157054887`, 14.965760325660824`, 64.87447999002819}, {
    15.422916717648397`, 14.660469606858763`, 64.11766741053279}}], 
   Polygon3DBox[{{15.422916717648397`, 14.660469606858763`, 
    64.11766741053279}, {15.845009157054887`, 14.965760325660824`, 
    64.87447999002819}, {15.748186752460215`, 14.204120520888369`, 
    65.32893817061833}, {15.337033811436555`, 13.999226602550774`, 
    64.51799888564358}}], 
   Polygon3DBox[{{15.337033811436555`, 13.999226602550774`, 
    64.51799888564358}, {15.748186752460215`, 14.204120520888369`, 
    65.32893817061833}, {15.592931395385586`, 13.377600187558489`, 
    65.67156096699189}, {15.199342493909867`, 13.280430662292432`, 
    64.82103313515547}}], 
   Polygon3DBox[{{15.199342493909867`, 13.280430662292432`, 
    64.82103313515547}, {15.592931395385586`, 13.377600187558489`, 
    65.67156096699189}, {15.377086386713927`, 12.507666463293193`, 
    65.88404946602573}, {15.007994225586021`, 12.522777019152977`, 
    65.01020912924412}}], 
   Polygon3DBox[{{15.007994225586021`, 12.522777019152977`, 
    65.01020912924412}, {15.377086386713927`, 12.507666463293193`, 
    65.88404946602573}, {15.102096736170207`, 11.621595046487334`, 
    65.95408990066083}, {14.764466565172285`, 11.750259788198358`, 
    65.07425386791557}}], 
   Polygon3DBox[{{14.764466565172285`, 11.750259788198358`, 
    65.07425386791557}, {15.102096736170207`, 11.621595046487334`, 
    65.95408990066083}, {14.773493459967472`, 10.749524052583661`, 
    65.87807566676723}, {14.473988024468694`, 10.989513061845491`, 
    65.00972747964597}}], 
   Polygon3DBox[{{14.473988024468694`, 10.989513061845491`, 
    65.00972747964597}, {14.773493459967472`, 10.749524052583661`, 
    65.87807566676723}, {14.400437130582608`, 9.920297609015385, 
    65.66205443723015}, {14.145057210508883`, 10.26601493739883, 
    64.82191887596119}}], 
   Polygon3DBox[{{14.145057210508883`, 10.26601493739883, 
    64.82191887596119}, {14.400437130582608`, 9.920297609015385, 
    65.66205443723015}, {13.994363907944576`, 9.157520305390996, 
    65.32032875245218}, {13.7881236233529, 9.600504391747322, 
    64.52354483697005}}], 
   Polygon3DBox[{{13.7881236233529, 9.600504391747322, 64.52354483697005}, {
    13.994363907944576`, 9.157520305390996, 65.32032875245218}, {
    13.567235492868555`, 8.477226286528913, 64.87228503933419}, {
    13.413942102121636`, 9.006926283493073, 64.13182010259396}}], 
   Polygon3DBox[{{13.413942102121636`, 9.006926283493073, 
    64.13182010259396}, {13.567235492868555`, 8.477226286528913, 
    64.87228503933419}, {13.130026925144918`, 7.887660168627487, 
    64.33878102602384}, {13.032209759510957`, 8.49232614554471, 
    63.66517215558254}}], 
   Polygon3DBox[{{13.032209759510957`, 8.49232614554471, 63.66517215558254}, {
    13.130026925144918`, 7.887660168627487, 64.33878102602384}, {
    12.691831582610108`, 7.390653738024759, 63.73926941220336}, {
    12.650814272898538`, 8.058163286019393, 63.14068594431298}}], 
   Polygon3DBox[{{12.650814272898538`, 8.058163286019393, 
    63.14068594431298}, {12.691831582610108`, 7.390653738024759, 
    63.73926941220336}, {12.259600926952986`, 6.983670329729211, 
    63.09013699932233}, {12.275670085919597`, 7.702167958308453, 
    62.57267908687548}}], 
   Polygon3DBox[{{12.275670085919597`, 7.702167958308453, 62.57267908687548}, 
    {12.259600926952986`, 6.983670329729211, 63.09013699932233}, {
    11.838324907956723`, 6.661775599204366, 62.40413011700631}, {
    11.910937106808586`, 7.420082602461465, 61.972250666294926`}}], 
   Polygon3DBox[{{11.910937106808586`, 7.420082602461465, 
    61.972250666294926`}, {11.838324907956723`, 6.661775599204366, 
    62.40413011700631}, {11.431431693073957`, 6.419181344731298, 
    61.690489872146074`}, {11.55941226313173, 7.206996737304243, 
    61.347444533582426`}}], 
   Polygon3DBox[{{11.55941226313173, 7.206996737304243, 
    61.347444533582426`}, {11.431431693073957`, 6.419181344731298, 
    61.690489872146074`}, {11.04125049345099, 6.250306617947479, 
    60.95544332443047}, {11.222956418386081`, 7.058248406823701, 
    60.70370850336631}}], 
   Polygon3DBox[{{11.222956418386081`, 7.058248406823701, 
    60.70370850336631}, {11.04125049345099, 6.250306617947479, 
    60.95544332443047}, {10.669456709025836`, 6.150442674895377, 
    60.2028167301372}, {10.902891247798454`, 6.96998095423434, 
    60.044447560650745`}}], 
   Polygon3DBox[{{10.902891247798454`, 6.96998095423434, 
    60.044447560650745`}, {10.669456709025836`, 6.150442674895377, 
    60.2028167301372}, {10.317471667643503`, 6.116143272662103, 
    59.43465161746421}, {10.600347463959388`, 6.939465851646155, 
    59.37157261991629}}], 
   Polygon3DBox[{{10.600347463959388`, 6.939465851646155, 
    59.37157261991629}, {10.317471667643503`, 6.116143272662103, 
    59.43465161746421}, {9.98681824191428, 6.145447900082872, 
    58.65178335896715}, {10.316569517914147`, 6.9652848571269015`, 
    58.686014460781244`}}], 
   Polygon3DBox[{{10.316569517914147`, 6.9652848571269015`, 
    58.686014460781244`}, {9.98681824191428, 6.145447900082872, 
    58.65178335896715}, {9.679446432598773, 6.238018262001906, 
    57.85438944275263}, {10.05319128650006, 7.047438237162784, 
    57.988212010857026`}}], 
   Polygon3DBox[{{10.05319128650006, 7.047438237162784, 
    57.988212010857026`}, {9.679446432598773, 6.238018262001906, 
    57.85438944275263}, {9.398046749181853, 6.395242329522117, 
    57.04254376603693}, {9.812499057841505, 7.18742144473796, 
    57.27860751003216}}], 
   Polygon3DBox[{{9.812499057841505, 7.18742144473796, 57.27860751003216}, {
    9.398046749181853, 6.395242329522117, 57.04254376603693}, {
    9.14636773815737, 6.620337974398073, 56.21683551654834}, {
    9.597695635510041, 7.388291465084951, 56.55819817756609}}], 
   Polygon3DBox[{{9.597695635510041, 7.388291465084951, 56.55819817756609}, {
    9.14636773815737, 6.620337974398073, 56.21683551654834}, {
    8.929547633851891, 6.918465205589516, 55.379134525322854`}, {
    9.413172649906176, 7.65472156747653, 55.82921085654868}}], 
   Polygon3DBox[{{9.413172649906176, 7.65472156747653, 55.82921085654868}, {
    8.929547633851891, 6.918465205589516, 55.379134525322854`}, {
    8.75445500759446, 7.296821591785773, 54.533612840424716`}, {
    9.264783702302788, 7.9930102812467805`, 55.09598413440621}}], 
   Polygon3DBox[{{9.264783702302788, 7.9930102812467805`, 
    55.09598413440621}, {8.75445500759446, 7.296821591785773, 
    54.533612840424716`}, {8.62999900701541, 7.764628992161529, 
    53.68815893316048}, {9.160080034257064, 8.410951276840402, 
    54.366154199372616`}}], 
   Polygon3DBox[{{9.160080034257064, 8.410951276840402, 
    54.366154199372616`}, {8.62999900701541, 7.764628992161529, 
    53.68815893316048}, {8.567294406208022, 8.332785329029795, 
    52.856315319083855`}, {9.108406149374472, 8.917361544712566, 
    53.65221703377451}}], 
   Polygon3DBox[{{9.108406149374472, 8.917361544712566, 53.65221703377451}, {
    8.567294406208022, 8.332785329029795, 52.856315319083855`}, {
    8.579413918780865, 9.012707000064049, 52.05973563690732}, {
    9.120630698465511, 9.520884413694233, 52.973401161736575`}}], 
   Polygon3DBox[{{9.120630698465511, 9.520884413694233, 
    52.973401161736575`}, {8.579413918780865, 9.012707000064049, 
    52.05973563690732}, {8.680203580251899, 9.813538076945022, 
    51.33066390752967}, {9.208100163616189, 10.227473880761867`, 
    52.35736681712659}}], 
   Polygon3DBox[{{9.208100163616189, 10.227473880761867`, 
    52.35736681712659}, {8.680203580251899, 9.813538076945022, 
    51.33066390752967}, {8.881393962468023, 10.736782381476132`, 
    50.71274846244471}, {9.380261708425387, 11.036017305647775`, 
    51.840357236132654`}}], 
   Polygon3DBox[{{9.380261708425387, 11.036017305647775`, 
    51.840357236132654`}, {8.881393962468023, 10.736782381476132`, 
    50.71274846244471}, {9.187606185596666, 11.768634997397395`, 
    50.256806253300475`}, {9.640751754427654, 11.932634878464594`, 
    51.46334702992584}}], 
   Polygon3DBox[{{9.640751754427654, 11.932634878464594`, 
    51.46334702992584}, {9.187606185596666, 11.768634997397395`, 
    50.256806253300475`}, {9.590902534988274, 12.874144550447959`, 
    50.00848137852349}, {9.983269262868209, 12.886926236067636`, 
    51.26232580530706}}], 
   Polygon3DBox[{{9.983269262868209, 12.886926236067636`, 
    51.26232580530706}, {9.590902534988274, 12.874144550447959`, 
    50.00848137852349}, {10.069523122726123`, 14.000863503817376`, 
    49.991503111744855`}, {10.390582637598676`, 13.855423926767228`, 
    51.25578544005588}}], 
   Polygon3DBox[{{10.390582637598676`, 13.855423926767228`, 
    51.25578544005588}, {10.069523122726123`, 14.000863503817376`, 
    49.991503111744855`}, {10.594044340919204`, 15.093770397809685`, 
    50.199156926434696`}, {10.838994801725933`, 14.793046809250258`, 
    51.43836601619575}}], 
   Polygon3DBox[{{10.838994801725933`, 14.793046809250258`, 
    51.43836601619575}, {10.594044340919204`, 15.093770397809685`, 
    50.199156926434696`}, {11.136777014637797`, 16.110582935067647`, 
    50.60147383995116}, {11.305489587572948`, 15.664784690799356`, 
    51.78600313531889}}], 
   Polygon3DBox[{{11.305489587572948`, 15.664784690799356`, 
    51.78600313531889}, {11.136777014637797`, 16.110582935067647`, 
    50.60147383995116}, {11.677404421993248`, 17.026911166868715`, 
    51.15990560556981}, {11.772480892077777`, 16.449992468552832`, 
    52.267058392505014`}}], 
   Polygon3DBox[{{11.772480892077777`, 16.449992468552832`, 
    52.267058392505014`}, {11.677404421993248`, 17.026911166868715`, 
    51.15990560556981}, {12.203424039962993`, 17.83275344805809, 
    51.83823565155955}, {12.228649267775424`, 17.139966495023295`, 
    52.8511648216909}}], 
   Polygon3DBox[{{12.228649267775424`, 17.139966495023295`, 
    52.8511648216909}, {12.203424039962993`, 17.83275344805809, 
    51.83823565155955}, {12.708147511136971`, 18.526767877446467`, 
    52.60699528571556}, {12.667621270604341`, 17.73344441406862, 
    53.51319838881625}}], 
   Polygon3DBox[{{12.667621270604341`, 17.73344441406862, 
    53.51319838881625}, {12.708147511136971`, 18.526767877446467`, 
    52.60699528571556}, {13.188528527663607`, 19.111782802554714`, 
    53.44385663176656}, {13.08627398992849, 18.23286989913702, 
    54.23391334592914}}], 
   Polygon3DBox[{{13.08627398992849, 18.23286989913702, 54.23391334592914}, {
    13.188528527663607`, 19.111782802554714`, 53.44385663176656}, {
    13.64356265692033, 19.59202997661157, 54.33248650631772}, {
    13.48338806848456, 18.64199637196066, 54.99915236950842}}], 
   Polygon3DBox[{{13.48338806848456, 18.64199637196066, 54.99915236950842}, {
    13.64356265692033, 19.59202997661157, 54.33248650631772}, {
    14.073252674157807`, 19.97161054280351, 55.26110130249882}, {
    13.85873305927643, 18.964520484735242`, 55.798696449211356`}}], 
   Polygon3DBox[{{13.85873305927643, 18.964520484735242`, 
    55.798696449211356`}, {14.073252674157807`, 19.97161054280351, 
    55.26110130249882}, {14.477962990575811`, 20.253690207737964`, 
    56.221151393560355`}, {14.212477016997415`, 19.203350776102074`, 
    56.625166853565354`}}], 
   Polygon3DBox[{{14.212477016997415`, 19.203350776102074`, 
    56.625166853565354`}, {14.477962990575811`, 20.253690207737964`, 
    56.221151393560355`}, {14.85800996328506, 20.440099109301492`, 
    57.20621821938638}, {14.54480315599906, 19.36023762510394, 
    57.47308293356712}}], 
   Polygon3DBox[{{14.54480315599906, 19.36023762510394, 57.47308293356712}, {
    14.85800996328506, 20.440099109301492`, 57.20621821938638}, {
    15.213386879557047`, 20.53115804564663, 58.211093187532676`}, {
    14.855649145252627`, 19.435607072662442`, 58.33806584372039}}], 
   Polygon3DBox[{{14.855649145252627`, 19.435607072662442`, 
    58.33806584372039}, {15.213386879557047`, 20.53115804564663, 
    58.211093187532676`}, {15.54356267715687, 20.525643483302634`, 
    59.230982160143945`}, {15.14451545256815, 19.428518351550192`, 
    59.21614669701919}}], 
   Polygon3DBox[{{15.14451545256815, 19.428518351550192`, 
    59.21614669701919}, {15.54356267715687, 20.525643483302634`, 
    59.230982160143945`}, {15.847319579645019`, 20.42085756465877, 
    60.260782993900015`}, {15.41031087093837, 19.336712500566183`, 
    60.10313570953634}}], 
   Polygon3DBox[{{15.41031087093837, 19.336712500566183`, 
    60.10313570953634}, {15.847319579645019`, 20.42085756465877, 
    60.260782993900015`}, {16.12261172788115, 20.212803322345273`, 
    61.29439599515668}, {15.651218106324315`, 19.156750152709147`, 
    60.99401684227039}}], 
   Polygon3DBox[{{15.651218106324315`, 19.156750152709147`, 
    60.99401684227039}, {16.12261172788115, 20.212803322345273`, 
    61.29439599515668}, {16.36643930058272, 19.89648974733502, 
    62.324043511818246`}, {15.864573464623472`, 18.884259128917865`, 
    61.88234491609583}}], 
   Polygon3DBox[{{15.864573464623472`, 18.884259128917865`, 
    61.88234491609583}, {16.36643930058272, 19.89648974733502, 
    62.324043511818246`}, {16.57474407003728, 19.466410937146556`, 
    63.33959659388499}, {16.04676518922444, 18.514331186891155`, 
    62.759639834281984`}}], 
   Polygon3DBox[{{16.04676518922444, 18.514331186891155`, 
    62.759639834281984`}, {16.57474407003728, 19.466410937146556`, 
    63.33959659388499}, {16.74234544009487, 18.91725830925245, 
    64.32793776127033}, {16.19316727706915, 18.04212262195821, 
    63.614799014652434`}}], 
   Polygon3DBox[{{16.19316727706915, 18.04212262195821, 
    63.614799014652434`}, {16.74234544009487, 18.91725830925245, 
    64.32793776127033}, {16.862952453814334`, 18.24492959885697, 
    65.27243432101699}, {16.29814140442996, 17.463721157215268`, 
    64.43358945061216}}], 
   Polygon3DBox[{{16.29814140442996, 17.463721157215268`, 
    64.43358945061216}, {16.862952453814334`, 18.24492959885697, 
    65.27243432101699}, {16.929306955726776`, 17.447880806069605`, 
    66.15265932999942}, {16.35515917070397, 16.77733066049494, 
    65.19833911123641}}], 
   Polygon3DBox[{{16.35515917070397, 16.77733066049494, 65.19833911123641}, {
    16.929306955726776`, 17.447880806069605`, 66.15265932999942}, {
    16.933531930090194`, 16.528806684591515`, 66.94457197062198}, {
    16.3571166174028, 15.984775627146592`, 65.88802114235789}}], 
   Polygon3DBox[{{16.3571166174028, 15.984775627146592`, 65.88802114235789}, {
    16.933531930090194`, 16.528806684591515`, 66.94457197062198}, {
    16.867765082387216`, 15.496506235900057`, 67.62143085438234}, {
    16.29692130126914, 15.093211940093637`, 66.47899271673765}}], 
   Polygon3DBox[{{16.29692130126914, 15.093211940093637`, 
    66.47899271673765}, {16.867765082387216`, 15.496506235900057`, 
    67.62143085438234}, {16.72512804586393, 14.367579665639607`, 
    68.15570398290494}, {16.16840541133018, 14.116730986948975`, 
    66.9466579894166}}], 
   Polygon3DBox[{{16.16840541133018, 14.116730986948975`, 66.9466579894166}, {
    16.72512804586393, 14.367579665639607`, 68.15570398290494}, {
    16.500986993484293`, 13.167354903997351`, 68.52206602893602}, {
    15.967524675816094`, 13.077293925167282`, 67.2681766037196}}], 
   Polygon3DBox[{{15.967524675816094`, 13.077293925167282`, 
    67.2681766037196}, {16.500986993484293`, 13.167354903997351`, 
    68.52206602893602}, {16.194290832082363`, 11.929304035436067`, 
    68.70116434434465}, {15.693629034824609`, 12.004275680202907`, 
    67.42594902950934}}], 
   Polygon3DBox[{{15.693629034824609`, 12.004275680202907`, 
    67.42594902950934}, {16.194290832082363`, 11.929304035436067`, 
    68.70116434434465}, {15.808584871263882`, 10.692425171893259`, 
    68.68326379767817}, {15.350396650625227`, 10.932087494295805`, 
    67.41103623915646}}], 
   Polygon3DBox[{{15.350396650625227`, 10.932087494295805`, 
    67.41103623915646}, {15.808584871263882`, 10.692425171893259`, 
    68.68326379767817}, {15.352236666972322`, 9.496780310944349, 
    68.47048452563904}, {14.945967311402939`, 9.896050218604497, 
    67.22525721349855}}], 
   Polygon3DBox[{{14.945967311402939`, 9.896050218604497, 
    67.22525721349855}, {15.352236666972322`, 9.496780310944349, 
    68.47048452563904}, {14.837622140321297`, 8.378336988266785, 
    68.0765855491724}, {14.492049833126158`, 8.927646239645748, 
    66.88094318142355}}], 
   Polygon3DBox[{{14.492049833126158`, 8.927646239645748, 
    66.88094318142355}, {14.837622140321297`, 8.378336988266785, 
    68.0765855491724}, {14.279459163077892`, 7.3647823405938375`, 
    67.52421598183513}, {14.002243471655314`, 8.05077043880818, 
    66.3983105936537}}], 
   Polygon3DBox[{{14.002243471655314`, 8.05077043880818, 66.3983105936537}, {
    14.279459163077892`, 7.3647823405938375`, 67.52421598183513}, {
    13.692854064109168`, 6.4735556525988525`, 66.84066750567587}, {
    13.49017582691342, 7.2801231347088695`, 65.80150863477151}}], 
   Polygon3DBox[{{13.49017582691342, 7.2801231347088695`, 
    65.80150863477151}, {13.692854064109168`, 6.4735556525988525`, 
    66.84066750567587}, {13.091669542164498`, 5.712264116299259, 
    66.0536211340155}, {12.9680457065595, 6.621795570713255, 
    65.1147831082919}}], 
   Polygon3DBox[{{12.9680457065595, 6.621795570713255, 65.1147831082919}, {
    13.091669542164498`, 5.712264116299259, 66.0536211340155}, {
    12.487553140290155`, 5.080718833839113, 65.187990923176}, {
    12.445844897368467`, 6.075244042821943, 64.3597435238244}}], 
   Polygon3DBox[{{12.445844897368467`, 6.075244042821943, 64.3597435238244}, {
    12.487553140290155`, 5.080718833839113, 65.187990923176}, {
    11.889634681433286`, 4.573557088357057, 64.26421174490822}, {
    11.931205297035277`, 5.635676111494505, 63.55397301409478}}], 
   Polygon3DBox[{{11.931205297035277`, 5.635676111494505, 
    63.55397301409478}, {11.889634681433286`, 4.573557088357057, 
    64.26421174490822}, {11.304707445659986`, 4.182679358893726, 
    63.29774457779741}, {11.429659222650754`, 5.296181336541979, 
    62.710710761973736`}}], 
   Polygon3DBox[{{11.429659222650754`, 5.296181336541979, 
    62.710710761973736`}, {11.304707445659986`, 4.182679358893726, 
    63.29774457779741}, {10.737674922802727`, 3.8991429622910068`, 
    62.299361382237095`}, {10.945100154877116`, 5.0493363067476675`, 
    61.83918629789784}}], 
   Polygon3DBox[{{10.945100154877116`, 5.0493363067476675`, 
    61.83918629789784}, {10.737674922802727`, 3.8991429622910068`, 
    62.299361382237095`}, {10.192099133678706`, 3.7144647759935014`, 
    61.27581373863599}, {10.480299719172557`, 4.8882818418661875`, 
    60.945254857081686`}}], 
   Polygon3DBox[{{10.480299719172557`, 4.8882818418661875`, 
    60.945254857081686`}, {10.192099133678706`, 3.7144647759935014`, 
    61.27581373863599}, {9.670757717457358, 3.6214391315650984`, 
    60.23062303968187}, {10.037407822664756`, 4.807387101262332, 
    60.032115688558434`}}], 
   Polygon3DBox[{{10.037407822664756`, 4.807387101262332, 
    60.032115688558434`}, {9.670757717457358, 3.6214391315650984`, 
    60.23062303968187}, {9.176172426105913, 3.614619550406212, 
    59.16485806093633}, {9.618412197671336, 4.802637088638126, 
    59.101009816379936`}}], 
   Polygon3DBox[{{9.618412197671336, 4.802637088638126, 
    59.101009816379936`}, {9.176172426105913, 3.614619550406212, 
    59.16485806093633}, {8.711105743835375, 3.6906025521637416`, 
    58.077857885731724`}, {9.22556111303483, 4.87186132844969, 
    58.15187127259594}}], 
   Polygon3DBox[{{9.22556111303483, 4.87186132844969, 58.15187127259594}, {
    8.711105743835375, 3.6906025521637416`, 58.077857885731724`}, {
    8.279040106186319, 3.848226470997011, 56.96791856333435}, {
    8.861765745432331, 5.014893748391379, 57.18395442147507}}], 
   Polygon3DBox[{{8.861765745432331, 5.014893748391379, 57.18395442147507}, {
    8.279040106186319, 3.848226470997011, 56.96791856333435}, {
    7.884661806231775, 4.088776011411257, 55.833005363033806`}, {
    8.531002803863267, 5.233729477801066, 56.19649398147532}}], 
   Polygon3DBox[{{8.531002803863267, 5.233729477801066, 56.19649398147532}, {
    7.884661806231775, 4.088776011411257, 55.833005363033806`}, {
    7.534372955998206, 4.416268866017572, 54.67159484349802}, {
    8.238736439132538, 5.5327243725446955`, 55.1894867077746}}], 
   Polygon3DBox[{{8.238736439132538, 5.5327243725446955`, 55.1894867077746}, {
    7.534372955998206, 4.416268866017572, 54.67159484349802}, {
    7.23684989337708, 4.837889069382188, 53.483807155241045`}, {
    7.9923701859837575`, 5.918860357066361, 54.16472469377109}}], 
   Polygon3DBox[{{7.9923701859837575`, 5.918860357066361, 
    54.16472469377109}, {7.23684989337708, 4.837889069382188, 
    53.483807155241045`}, {7.003648789711147, 5.364603682111747, 
    52.273072905397285`}, {7.801717339264175, 6.402055429627455, 
    53.127265741988055`}}], 
   Polygon3DBox[{{7.801717339264175, 6.402055429627455, 
    53.127265741988055`}, {7.003648789711147, 5.364603682111747, 
    52.273072905397285`}, {6.849807668791901, 6.011903548617434, 
    51.04869592070618}, {7.679421931530681, 6.995389947288149, 
    52.08758779571535}}], 
   Polygon3DBox[{{7.679421931530681, 6.995389947288149, 52.08758779571535}, {
    6.849807668791901, 6.011903548617434, 51.04869592070618}, {
    6.794251638231678, 6.800321373347492, 49.82978224677969}, {
    7.6411278681278105`, 7.714867782283505, 51.064683441918866`}}], 
   Polygon3DBox[{{7.6411278681278105`, 7.714867782283505, 
    51.064683441918866`}, {6.794251638231678, 6.800321373347492, 
    49.82978224677969}, {6.859447533184737, 7.754652724651701, 
    48.650883484476296`}, {7.704902414929189, 8.577809566390133, 
    50.09009959306526}}], 
   Polygon3DBox[{{7.704902414929189, 8.577809566390133, 50.09009959306526}, {
    6.859447533184737, 7.754652724651701, 48.650883484476296`}, {
    7.069000226343038, 8.899372549199283, 47.56859557926529}, {
    7.888922633514346, 9.598190414457601, 49.21188487222791}}], 
   Polygon3DBox[{{7.888922633514346, 9.598190414457601, 49.21188487222791}, {
    7.069000226343038, 8.899372549199283, 47.56859557926529}, {
    7.4409810152979645`, 10.246353789606841`, 46.66468011344282}, {
    8.20608008770582, 10.777049517358494`, 48.49482128623556}}], 
   Polygon3DBox[{{8.20608008770582, 10.777049517358494`, 48.49482128623556}, {
    7.4409810152979645`, 10.246353789606841`, 46.66468011344282}, {
    7.97602226014039, 11.774382400482704`, 46.03503449034168}, {
    8.655523387902821, 12.089426275384188`, 48.01020486690359}}], 
   Polygon3DBox[{{8.655523387902821, 12.089426275384188`, 
    48.01020486690359}, {7.97602226014039, 11.774382400482704`, 
    46.03503449034168}, {8.646901071232334, 13.414993658030621`, 
    45.75611169652395}, {9.216117495067198, 13.478111826394477`, 
    47.81206476816454}}], 
   Polygon3DBox[{{9.216117495067198, 13.478111826394477`, 
    47.81206476816454}, {8.646901071232334, 13.414993658030621`, 
    45.75611169652395}, {9.403886336191489, 15.06931732426709, 
    45.84815796044728}, {9.850363596610384, 14.867233415141403`, 
    47.913690423187745`}}], 
   Polygon3DBox[{{9.850363596610384, 14.867233415141403`, 
    47.913690423187745`}, {9.403886336191489, 15.06931732426709, 
    45.84815796044728}, {10.19561426709588, 16.64819396231886, 
    46.27359271547617}, {10.518305853389128`, 16.188811032216897`, 
    48.286869107567426`}}], 
   Polygon3DBox[{{10.518305853389128`, 16.188811032216897`, 
    48.286869107567426`}, {10.19561426709588, 16.64819396231886, 
    46.27359271547617}, {10.984979621361981`, 18.095940231723045`, 
    46.967878492814734`}, {11.189167253711915`, 17.39899605402916, 
    48.882187262537045`}}], 
   Polygon3DBox[{{11.189167253711915`, 17.39899605402916, 
    48.882187262537045`}, {10.984979621361981`, 18.095940231723045`, 
    46.967878492814734`}, {11.75084294485914, 19.387326883672557`, 
    47.86745205085049}, {11.843953666209533`, 18.47699650781066, 
    49.64910374219256}}], 
   Polygon3DBox[{{11.843953666209533`, 18.47699650781066, 
    49.64910374219256}, {11.75084294485914, 19.387326883672557`, 
    47.86745205085049}, {12.48311734896761, 20.515492702401833`, 
    48.920901633159744`}, {12.472704924521151`, 19.416842523409887`, 
    50.54541121379806}}], 
   Polygon3DBox[{{12.472704924521151`, 19.416842523409887`, 
    50.54541121379806}, {12.48311734896761, 20.515492702401833`, 
    48.920901633159744`}, {13.17796632814651, 21.482376803983893`, 
    50.0898474200772}, {13.07102790582319, 20.220091143810137`, 
    51.538922209769275`}}], 
   Polygon3DBox[{{13.07102790582319, 20.220091143810137`, 
    51.538922209769275`}, {13.17796632814651, 21.482376803983893`, 
    50.0898474200772}, {13.834715506536106`, 22.293197349348517`, 
    51.346497063675166`}, {13.637571493610654`, 20.891271604596927`, 
    52.60606193160358}}], 
   Polygon3DBox[{{13.637571493610654`, 20.891271604596927`, 
    52.60606193160358}, {13.834715506536106`, 22.293197349348517`, 
    51.346497063675166`}, {14.454099616708373`, 22.953593939319294`, 
    52.67085444809672}, {14.172467613142423`, 21.435395692424557`, 
    53.729816247869074`}}], 
   Polygon3DBox[{{14.172467613142423`, 21.435395692424557`, 
    53.729816247869074`}, {14.454099616708373`, 22.953593939319294`, 
    52.67085444809672}, {15.037288059694122`, 23.46820266794426, 
    54.04837441687454}, {14.676411673786218`, 21.856670441003068`, 
    54.897860374779086`}}], 
   Polygon3DBox[{{14.676411673786218`, 21.856670441003068`, 
    54.897860374779086`}, {15.037288059694122`, 23.46820266794426, 
    54.04837441687454}, {15.585325139416117`, 23.839965005784247`, 
    55.468119038409775`}, {15.150112590552984`, 22.157857328665, 
    56.101025678380545`}}], 
   Polygon3DBox[{{15.150112590552984`, 22.157857328665, 
    56.101025678380545`}, {15.585325139416117`, 23.839965005784247`, 
    55.468119038409775`}, {16.098784164062998`, 24.06982220389537, 
    56.921296467160005`}, {15.593945121666005`, 22.33997920250414, 
    57.33205760387947}}], 
   Polygon3DBox[{{15.593945121666005`, 22.33997920250414, 
    57.33205760387947}, {16.098784164062998`, 24.06982220389537, 
    56.921296467160005`}, {16.5775297063966, 24.156633576050535`, 
    58.400054452836514`}, {16.007709520388804`, 22.40222856657869, 
    58.58457818510372}}], 
   Polygon3DBox[{{16.007709520388804`, 22.40222856657869, 
    58.58457818510372}, {16.5775297063966, 24.156633576050535`, 
    58.400054452836514`}, {17.020533354977445`, 24.09725394608189, 
    59.89642842840819}, {16.390446443781574`, 22.342015241818306`, 
    59.852175180424595`}}], 
   Polygon3DBox[{{16.390446443781574`, 22.342015241818306`, 
    59.852175180424595`}, {17.020533354977445`, 24.09725394608189, 
    59.89642842840819}, {17.42571627910442, 23.886759306913444`, 
    61.401375333005745`}, {16.740280203866792`, 22.155140162129594`, 
    61.12755954748672}}], 
   Polygon3DBox[{{16.740280203866792`, 22.155140162129594`, 
    61.12755954748672}, {17.42571627910442, 23.886759306913444`, 
    61.401375333005745`}, {17.789809187402156`, 23.51884347562563, 
    62.90385412680849}, {17.05427961018863, 21.836113682899033`, 
    62.401755068939806`}}], 
   Polygon3DBox[{{17.05427961018863, 21.836113682899033`, 
    62.401755068939806`}, {17.789809187402156`, 23.51884347562563, 
    62.90385412680849}, {18.10823355550359, 22.986432095572866`, 
    64.38994551420407}, {17.328338417339992`, 21.37865991121645, 
    63.6633093123586}}], 
   Polygon3DBox[{{17.328338417339992`, 21.37865991121645, 63.6633093123586}, {
    18.10823355550359, 22.986432095572866`, 64.38994551420407}, {
    18.37502116690645, 22.282575680330837`, 65.84204179919625}, {
    17.5570902866547, 20.776465370015607`, 64.89754778006363}}], 
   Polygon3DBox[{{17.5570902866547, 20.776465370015607`, 64.89754778006363}, {
    18.37502116690645, 22.282575680330837`, 65.84204179919625}, {
    18.58280413502114, 21.401686238725844`, 67.23818777847183}, {
    17.733888378361875`, 20.024237295862555`, 66.0859378703549}}], 
   Polygon3DBox[{{17.733888378361875`, 20.024237295862555`, 
    66.0859378703549}, {18.58280413502114, 21.401686238725844`, 
    67.23818777847183}, {18.72292495681785, 20.341161673609175`, 
    68.55171695110073}, {17.850897833628178`, 19.119124135003446`, 
    67.20568926661764}}], 
   Polygon3DBox[{{17.850897833628178`, 19.119124135003446`, 
    67.20568926661764}, {18.72292495681785, 20.341161673609175`, 
    68.55171695110073}, {18.785733156282724`, 19.103381525445066`, 
    69.75139817531883}, {17.899368194566396`, 18.06250107150412, 
    68.22978934063414}}], 
   Polygon3DBox[{{17.899368194566396`, 18.06250107150412, 
    68.22978934063414}, {18.785733156282724`, 19.103381525445066`, 
    69.75139817531883}, {18.761144002604176`, 17.697936963975085`, 
    70.80236466856049}, {17.870164417604546`, 16.862014285063974`, 
    69.1277378374267}}], 
   Polygon3DBox[{{17.870164417604546`, 16.862014285063974`, 
    69.1277378374267}, {18.761144002604176`, 17.697936963975085`, 
    70.80236466856049}, {18.63952081949871, 16.14376769530231, 
    71.6680940937847}, {17.754623274078842`, 15.533593359695653`, 
    69.86726001318435}}], 
   Polygon3DBox[{{17.754623274078842`, 15.533593359695653`, 
    69.86726001318435}, {18.63952081949871, 16.14376769530231, 
    71.6680940937847}, {18.41288508966285, 14.470646482151691`, 
    72.3135759433922}, {17.545742579019098`, 14.102901794951029`, 
    70.41716682095394}}], 
   Polygon3DBox[{{17.545742579019098`, 14.102901794951029`, 
    70.41716682095394}, {18.41288508966285, 14.470646482151691`, 
    72.3135759433922}, {18.076342960935758`, 12.719278164460476`, 
    72.70947735499846}, {17.23958465906759, 12.60549939543272, 
    70.75121700105566}}], 
   Polygon3DBox[{{17.23958465906759, 12.60549939543272, 70.75121700105566}, {
    18.076342960935758`, 12.719278164460476`, 72.70947735499846}, {
    17.62945819430195, 10.939342391304715`, 72.83661986204652}, {
    16.836599423037047`, 11.085031509491664`, 70.85232314374785}}], 
   Polygon3DBox[{{16.836599423037047`, 11.085031509491664`, 
    70.85232314374785}, {17.62945819430195, 10.939342391304715`, 
    72.83661986204652}, {17.07717139036589, 9.185276852077587, 
    72.68959960442653}, {16.342432910214786`, 9.589236477562192, 
    70.71593295065492}}], 
   Polygon3DBox[{{16.342432910214786`, 9.589236477562192, 
    70.71593295065492}, {17.07717139036589, 9.185276852077587, 
    72.68959960442653}, {16.42987788227035, 7.510434363705487, 
    72.2782749159385}, {15.767823006758592`, 8.164440630025274, 
    70.35130471748514}}], 
   Polygon3DBox[{{15.767823006758592`, 8.164440630025274, 
    70.35130471748514}, {16.42987788227035, 7.510434363705487, 
    72.2782749159385}, {15.70250387808167, 5.961063486903562, 
    71.62638258054807}, {15.12747001649288, 6.850041935390561, 
    69.77998974507676}}], 
   Polygon3DBox[{{15.12747001649288, 6.850041935390561, 69.77998974507676}, {
    15.70250387808167, 5.961063486903562, 71.62638258054807}, {
    14.912785885561961`, 4.571794750922659, 70.7675823037927}, {
    14.438185036204885`, 5.67463869434472, 69.03193824903761}}], 
   Polygon3DBox[{{14.438185036204885`, 5.67463869434472, 69.03193824903761}, {
    14.912785885561961`, 4.571794750922659, 70.7675823037927}, {
    14.079250208367428`, 3.3637197328636708`, 69.74017445867364}, {
    13.716894579380579`, 4.654733969754185, 68.14056422707772}}], 
   Polygon3DBox[{{13.716894579380579`, 4.654733969754185, 
    68.14056422707772}, {14.079250208367428`, 3.3637197328636708`, 
    69.74017445867364}, {13.219431905553131`, 2.3450970370624233`, 
    68.58201830776643}, {12.979042836364275`, 3.795841794258134, 
    67.13825525912992}}], 
   Polygon3DBox[{{12.979042836364275`, 3.795841794258134, 
    67.13825525912992}, {13.219431905553131`, 2.3450970370624233`, 
    68.58201830776643}, {12.348679711048222`, 1.513867634501591, 
    67.32674381436712}, {12.237663375844146`, 3.0950616589399695`, 
    66.05325525228014}}], 
   Polygon3DBox[{{12.237663375844146`, 3.0950616589399695`, 
    66.05325525228014}, {12.348679711048222`, 1.513867634501591, 
    67.32674381436712}, {11.479626261680613`, 0.8608911469438024, 
    66.00161944126907}, {11.503105173320579`, 2.544071016391707, 
    64.90810253959896}}], 
   Polygon3DBox[{{11.503105173320579`, 2.544071016391707, 
    64.90810253959896}, {11.479626261680613`, 0.8608911469438024, 
    66.00161944126907}, {10.622210854849367`, 0.3730348742512632, 
    64.62685883240668}, {10.783237125482653`, 2.1318053873092637`, 
    63.71930692310368}}], 
   Polygon3DBox[{{10.783237125482653`, 2.1318053873092637`, 
    63.71930692310368}, {10.622210854849367`, 0.3730348742512632, 
    64.62685883240668}, {9.784070856911647, 0.03564970935649747, 
    63.21589555171435}, {10.083928737768176`, 1.8465060165935256`, 
    62.49779309211839}}], 
   Polygon3DBox[{{10.083928737768176`, 1.8465060165935256`, 
    62.49779309211839}, {9.784070856911647, 0.03564970935649747, 
    63.21589555171435}, {8.971134473578633, -0.16568887485748068`, 
    61.77616089974504}, {9.409651783400184, 1.67711143954778, 
    61.24970318297406}}], 
   Polygon3DBox[{{9.409651783400184, 1.67711143954778, 61.24970318297406}, {
    8.971134473578633, -0.16568887485748068`, 61.77616089974504}, {
    8.188300116485374, -0.2440938733568936, 60.31002604127617}, {
    8.764111606721581, 1.6141162236203683`, 59.97729226827215}}], 
   Polygon3DBox[{{8.764111606721581, 1.6141162236203683`, 
    59.97729226827215}, {8.188300116485374, -0.2440938733568936, 
    60.31002604127617}, {7.44014074512522, -0.21077051172880928`, 
    58.815713825967165`}, {8.150868986849563, 1.650062994967496, 
    58.679782831539455`}}], 
   Polygon3DBox[{{8.150868986849563, 1.650062994967496, 
    58.679782831539455`}, {7.44014074512522, -0.21077051172880928`, 
    58.815713825967165`}, {6.73161067502699, -0.0747321569709832, 
    57.28810386159672}, {7.5739475768758355`, 1.7798277516241368`, 
    57.354142106297175`}}], 
   Polygon3DBox[{{7.5739475768758355`, 1.7798277516241368`, 
    57.354142106297175`}, {6.73161067502699, -0.0747321569709832, 
    57.28810386159672}, {6.068755403664033, 0.15734567062090443`, 
    55.719442290862915`}, {7.038441074485122, 2.0008418461780235`, 
    55.995815106769705`}}], 
   Polygon3DBox[{{7.038441074485122, 2.0008418461780235`, 
    55.995815106769705`}, {6.068755403664033, 0.15734567062090443`, 
    55.719442290862915`}, {5.459435373747843, 0.48131712392438525`, 
    54.10003906078334}, {6.551143775290332, 2.3133882289202496`, 
    54.599503074747396`}}], 
   Polygon3DBox[{{6.551143775290332, 2.3133882289202496`, 
    54.599503074747396`}, {5.459435373747843, 0.48131712392438525`, 
    54.10003906078334}, {4.914078599535008, 0.8960382539375088, 
    52.419110340052086`}, {6.121232600657506, 2.7211247014490674`, 
    53.16014232031137}}], 
   Polygon3DBox[{{6.121232600657506, 2.7211247014490674`, 
    53.16014232031137}, {4.914078599535008, 0.8960382539375088, 
    52.419110340052086`}, {4.44648669423851, 1.4044698095167143`, 
    50.66602738159652}, {5.761030978174868, 3.232023497380343, 
    51.67433701222787}}], 
   Polygon3DBox[{{5.761030978174868, 3.232023497380343, 51.67433701222787}, {
    4.44648669423851, 1.4044698095167143`, 50.66602738159652}, {
    4.074757506083159, 2.015960291975998, 48.83240805552001}, {
    5.486882736404973, 3.859953424891018, 50.14266694081017}}], 
   Polygon3DBox[{{5.486882736404973, 3.859953424891018, 50.14266694081017}, {
    4.074757506083159, 2.015960291975998, 48.83240805552001}, {
    3.8224883369922678`, 2.750523960549099, 46.91583258985769}, {
    5.320132693141234, 4.62707965233582, 48.57357729517011}}], 
   Polygon3DBox[{{5.320132693141234, 4.62707965233582, 48.57357729517011}, {
    3.8224883369922678`, 2.750523960549099, 46.91583258985769}, {
    3.7205735608507675`, 3.6460711686672425`, 44.926721854543366`}, {
    5.288042156257922, 5.566827910895854, 46.989983516028275`}}], 
   Polygon3DBox[{{5.288042156257922, 5.566827910895854, 
    46.989983516028275`}, {3.7205735608507675`, 3.6460711686672425`, 
    44.926721854543366`}, {3.809783734149848, 4.768686070936746, 
    42.90150524157738}, {5.423813495614917, 6.725558592853378, 
    45.439991200029574`}}], 
   Polygon3DBox[{{5.423813495614917, 6.725558592853378, 
    45.439991200029574`}, {3.809783734149848, 4.768686070936746, 
    42.90150524157738}, {4.142376293838385, 6.220759864532667, 
    40.92725915745179}, {5.763003156357024, 8.15680543929752, 
    44.01143037158833}}], 
   Polygon3DBox[{{5.763003156357024, 8.15680543929752, 44.01143037158833}, {
    4.142376293838385, 6.220759864532667, 40.92725915745179}, {
    4.773087163431232, 8.123162892771592, 39.17776586082316}, {
    6.330503663927765, 9.895589615108552, 42.84061505196724}}], 
   Polygon3DBox[{{6.330503663927765, 9.895589615108552, 42.84061505196724}, {
    4.773087163431232, 8.123162892771592, 39.17776586082316}, {
    5.717992991378458, 10.521694606378494`, 37.91825689270537}, {
    7.115503276479835, 11.90865153146701, 42.08621116629531}}], 
   Polygon3DBox[{{7.115503276479835, 11.90865153146701, 42.08621116629531}, {
    5.717992991378458, 10.521694606378494`, 37.91825689270537}, {
    6.897454233929082, 13.256779696767442`, 37.37533855425329}, {
    8.05647009523412, 14.0682439643849, 41.85055083200473}}], 
   Polygon3DBox[{{8.05647009523412, 14.0682439643849, 41.85055083200473}, {
    6.897454233929082, 13.256779696767442`, 37.37533855425329}, {
    8.171942118629088, 16.040498269018773`, 37.56035534239874}, {
    9.06881969565325, 16.211780652375932`, 42.12156197177031}}], 
   Polygon3DBox[{{9.06881969565325, 16.211780652375932`, 42.12156197177031}, {
    8.171942118629088, 16.040498269018773`, 37.56035534239874}, {
    9.440606148584632, 18.66820257401434, 38.32632153012382}, {
    10.086957335544238`, 18.222168694674828`, 42.80984643075855}}], 
   Polygon3DBox[{{10.086957335544238`, 18.222168694674828`, 
    42.80984643075855}, {9.440606148584632, 18.66820257401434, 
    38.32632153012382}, {10.65929248172009, 21.054034684075525`, 
    39.516527518230475`}, {11.075275874958628`, 20.042648639280706`, 
    43.814748354025994`}}], 
   Polygon3DBox[{{11.075275874958628`, 20.042648639280706`, 
    43.814748354025994`}, {10.65929248172009, 21.054034684075525`, 
    39.516527518230475`}, {11.814015610027626`, 23.173827681850025`, 
    41.014743740799766`}, {12.01848437168618, 21.65418628805449, 
    45.05444531472443}}], 
   Polygon3DBox[{{12.01848437168618, 21.65418628805449, 45.05444531472443}, {
    11.814015610027626`, 23.173827681850025`, 41.014743740799766`}, {
    12.902792646206228`, 25.027126476149544`, 42.74112013405392}, {
    12.911664168599277`, 23.055343646948835`, 46.469057719285225`}}], 
   Polygon3DBox[{{12.911664168599277`, 23.055343646948835`, 
    46.469057719285225`}, {12.902792646206228`, 25.027126476149544`, 
    42.74112013405392}, {13.92792511864389, 26.621214687425947`, 
    44.6406959470362}, {13.754586833224874`, 24.251444782485862`, 
    48.015980578077475`}}], 
   Polygon3DBox[{{13.754586833224874`, 24.251444782485862`, 
    48.015980578077475`}, {13.92792511864389, 26.621214687425947`, 
    44.6406959470362}, {14.892952208811844`, 27.964793993217945`, 
    46.674796596168896`}, {14.548905642794812`, 25.24945770956769, 
    49.66487492746122}}], 
   Polygon3DBox[{{14.548905642794812`, 25.24945770956769, 
    49.66487492746122}, {14.892952208811844`, 27.964793993217945`, 
    46.674796596168896`}, {15.801391583833418`, 29.065368137818048`, 
    48.815386858597414`}, {15.296782844325291`, 26.055620397468786`, 
    51.39379579646481}}], 
   Polygon3DBox[{{15.296782844325291`, 26.055620397468786`, 
    51.39379579646481}, {15.801391583833418`, 29.065368137818048`, 
    48.815386858597414`}, {16.656165400577745`, 29.928103719579667`, 
    51.0413042837098}, {16.00018536075182, 26.6743335278778, 
    53.186360524185254`}}], 
   Polygon3DBox[{{16.00018536075182, 26.6743335278778, 53.186360524185254`}, {
    16.656165400577745`, 29.928103719579667`, 51.0413042837098}, {
    17.459297033858558`, 30.555345146659338`, 53.33559168768486}, {
    16.660489154338155`, 27.10766321274343, 55.02963509917598}}], 
   Polygon3DBox[{{16.660489154338155`, 27.10766321274343, 
    55.02963509917598}, {17.459297033858558`, 30.555345146659338`, 
    53.33559168768486}, {18.211716053954067`, 30.946473255160384`, 
    55.68346259279295}, {17.27822620978619, 27.355170842305643`, 
    56.91247422593211}}], 
   Polygon3DBox[{{17.27822620978619, 27.355170842305643`, 
    56.91247422593211}, {18.211716053954067`, 30.946473255160384`, 
    55.68346259279295}, {18.913105088531342`, 31.09799633865905, 
    58.070630019124486`}, {17.852896599645803`, 27.413956373060685`, 
    58.82413472589913}}], 
   Polygon3DBox[{{17.852896599645803`, 27.413956373060685`, 
    58.82413472589913}, {18.913105088531342`, 31.09799633865905, 
    58.070630019124486`}, {19.561762149219877`, 31.003849838006047`, 
    60.48184472021694}, {18.382810037589, 27.278883607443106`, 
    60.753047430905575`}}], 
   Polygon3DBox[{{18.382810037589, 27.278883607443106`, 
    60.753047430905575`}, {19.561762149219877`, 31.003849838006047`, 
    60.48184472021694}, {20.154471391149638`, 30.655926070069285`, 
    62.89956254034665}, {18.864943486423535`, 26.943001406018354`, 
    62.68568210950875}}], 
   Polygon3DBox[{{18.864943486423535`, 26.943001406018354`, 
    62.68568210950875}, {20.154471391149638`, 30.655926070069285`, 
    62.89956254034665}, {20.686387568693302`, 30.04488186925986, 
    65.3027163511438}, {19.294815836431436`, 26.39820318464342, 
    64.60548236685499}}], 
   Polygon3DBox[{{19.294815836431436`, 26.39820318464342, 
    64.60548236685499}, {20.686387568693302`, 30.04488186925986, 
    65.3027163511438}, {21.15095013913501, 29.16128602655844, 
    67.66562027817046}, {19.666393104118164`, 25.636184477776947`, 
    66.49189124789964}}], 
   Polygon3DBox[{{19.666393104118164`, 25.636184477776947`, 
    66.49189124789964}, {21.15095013913501, 29.16128602655844, 
    67.66562027817046}, {21.539854292789474`, 27.99716747923623, 
    69.95709051310553}, {19.972050765838908`, 24.649762841368187`, 
    68.31953959819874}}], 
   Polygon3DBox[{{19.972050765838908`, 24.649762841368187`, 
    68.31953959819874}, {21.539854292789474`, 27.99716747923623, 
    69.95709051310553}, {21.843118524255598`, 26.54800114265502, 
    72.1399300059025}, {20.202634563401055`, 23.434607747821406`, 
    70.05773067137814}}], 
   Polygon3DBox[{{20.202634563401055`, 23.434607747821406`, 
    70.05773067137814}, {21.843118524255598`, 26.54800114265502, 
    72.1399300059025}, {22.049300176335212`, 24.81510894980036, 
    74.1709880675877}, {20.347676032348097`, 21.991376844505048`, 
    71.6704218912266}}], 
   Polygon3DBox[{{20.347676032348097`, 21.991376844505048`, 
    71.6704218912266}, {22.049300176335212`, 24.81510894980036, 
    74.1709880675877}, {22.145917601314398`, 22.808346736052712`, 
    76.0020531837164}, {20.395829421055467`, 20.328153033412182`, 
    73.11696191757463}}], 
   Polygon3DBox[{{20.395829421055467`, 20.328153033412182`, 
    73.11696191757463}, {22.145917601314398`, 22.808346736052712`, 
    76.0020531837164}, {22.120132942328677`, 20.548788936110363`, 
    77.58183609299925}, {20.33559327981226, 18.4629145936774, 
    74.35385409006673}}], 
   Polygon3DBox[{{20.33559327981226, 18.4629145936774, 74.35385409006673}, {
    22.120132942328677`, 20.548788936110363`, 77.58183609299925}, {
    21.959723219474743`, 18.07093113266397, 78.85920576397339}, {
    20.156349037344697`, 16.42556233182066, 75.33773308456456}}], 
   Polygon3DBox[{{20.156349037344697`, 16.42556233182066, 
    75.33773308456456}, {21.959723219474743`, 18.07093113266397, 
    78.85920576397339}, {21.65431057785845, 15.42376317611764, 
    79.78761176451339}, {19.849676833936947`, 14.258836127581336`, 
    76.02950469464773}}], 
   Polygon3DBox[{{19.849676833936947`, 14.258836127581336`, 
    76.02950469464773}, {21.65431057785845, 15.42376317611764, 
    79.78761176451339}, {21.196735180033475`, 12.670025401403592`, 
    80.33025930191536}, {19.41079475930394, 12.017402374127744`, 
    76.39919559970754}}], 
   Polygon3DBox[{{19.41079475930394, 12.017402374127744`, 
    76.39919559970754}, {21.196735180033475`, 12.670025401403592`, 
    80.33025930191536}, {20.58435516210824, 9.883165159647483, 
    80.46517798498323}, {18.83984037478668, 9.764634975601034, 
    76.4305850332646}}], 
   Polygon3DBox[{{18.83984037478668, 9.764634975601034, 76.4305850332646}, {
    20.58435516210824, 9.883165159647483, 80.46517798498323}, {
    19.81998929778823, 7.142015228704761, 80.18902395783383}, {
    18.142639165402727`, 7.567213741391585, 76.12437707719964}}], 
   Polygon3DBox[{{18.142639165402727`, 7.567213741391585, 
    76.12437707719964}, {19.81998929778823, 7.142015228704761, 
    80.18902395783383}, {18.91223108716216, 4.523915849140914, 
    79.51849986310994}, {17.33066035153191, 5.488469337494427, 
    75.49880398490637}}], 
   Polygon3DBox[{{17.33066035153191, 5.488469337494427, 75.49880398490637}, {
    18.91223108716216, 4.523915849140914, 79.51849986310994}, {
    17.87498524728475, 2.097613820306425, 78.48878162455036}, {
    16.4200709724514, 3.5820163496253055`, 74.58723415567628}}], 
   Polygon3DBox[{{16.4200709724514, 3.5820163496253055`, 74.58723415567628}, {
    17.87498524728475, 2.097613820306425, 78.48878162455036}, {
    16.72627930747742, -0.08253695535180361, 77.14916955397227}, {
    15.430086640144578`, 1.8872292967516155`, 73.43333736469597}}], 
   Polygon3DBox[{{15.430086640144578`, 1.8872292967516155`, 
    73.43333736469597}, {16.72627930747742, -0.08253695535180361, 
    77.14916955397227}, {15.486600748791329`, -1.9799266023043467`, 
    75.55697175320059}, {14.381034289888438`, 0.4274602989074976, 
    72.08512177747826}}], 
   Polygon3DBox[{{14.381034289888438`, 0.4274602989074976, 
    72.08512177747826}, {15.486600748791329`, -1.9799266023043467`, 
    75.55697175320059}, {14.177116060972963`, -3.57622145909234, 
    73.7710134599923}, {13.292579532514576`, -0.7890625642395339, 
    70.58931214348236}}], 
   Polygon3DBox[{{13.292579532514576`, -0.7890625642395339, 
    70.58931214348236}, {14.177116060972963`, -3.57622145909234, 
    73.7710134599923}, {12.81810722079441, -4.869505044739576, 
    71.84601959611733}, {12.182438289723729`, -1.7664672416791851`, 
    68.98710699537874}}], 
   Polygon3DBox[{{12.182438289723729`, -1.7664672416791851`, 
    68.98710699537874}, {12.81810722079441, -4.869505044739576, 
    71.84601959611733}, {11.427846241979701`, -5.8709512800217265`, 
    69.82860207606291}, {11.065690808588872`, -2.5176713069997376`, 
    67.31168006891897}}], 
   Polygon3DBox[{{11.065690808588872`, -2.5176713069997376`, 
    67.31168006891897}, {11.427846241979701`, -5.8709512800217265`, 
    69.82860207606291}, {10.021986427955598`, -6.601050003875824, 
    67.7549918776731}, {9.95464978233992, -3.060921444721665, 
    65.58723521583501}}], 
   Polygon3DBox[{{9.95464978233992, -3.060921444721665, 65.58723521583501}, {
    10.021986427955598`, -6.601050003875824, 67.7549918776731}, {
    8.613435183493017, -7.086215036012263, 65.65021596913638}, {
    8.859149470850314, -3.4169874688239377`, 63.829144286236854`}}], 
   Polygon3DBox[{{8.859149470850314, -3.4169874688239377`, 
    63.829144286236854`}, {8.613435183493017, -7.086215036012263, 
    65.65021596913638}, {7.212609188621679, -7.356319397003395, 
    63.528208163325345`}, {7.787110251247723, -3.607224919115957, 
    62.04466251732241}}], 
   Polygon3DBox[{{7.787110251247723, -3.607224919115957, 62.04466251732241}, {
    7.212609188621679, -7.356319397003395, 63.528208163325345`}, {
    5.838691677797813, -7.443419100191418, 61.40908384455828}, {
    6.745260098237756, -3.6525029121728325`, 60.233817409360746`}}], 
   Polygon3DBox[{{6.745260098237756, -3.6525029121728325`, 
    60.233817409360746`}, {5.838691677797813, -7.443419100191418, 
    61.40908384455828}, {4.598306483831555, -7.393786630982394, 
    59.4477163271094}, {5.739929635086288, -3.5728972724879693`, 
    58.39021074210346}}], 
   Polygon3DBox[{{5.739929635086288, -3.5728972724879693`, 
    58.39021074210346}, {4.598306483831555, -7.393786630982394, 
    59.4477163271094}, {3.4727120190011065`, -7.263671250194934, 
    57.60872187763264}, {4.777858019369244, -3.3880342524848976`, 
    56.50161149689248}}], 
   Polygon3DBox[{{4.777858019369244, -3.3880342524848976`, 
    56.50161149689248}, {3.4727120190011065`, -7.263671250194934, 
    57.60872187763264}, {2.4431768696253906`, -7.093980016773761, 
    55.85584715864569}, {3.8669353309077925`, -3.117989781568495, 
    54.55034252488384}}], 
   Polygon3DBox[{{3.8669353309077925`, -3.117989781568495, 
    54.55034252488384}, {2.4431768696253906`, -7.093980016773761, 
    55.85584715864569}, {1.4921240345730216`, -6.91709903689402, 
    54.15386340856762}, {3.016744206679544, -2.7846561218850674`, 
    52.51358939431306}}], 
   Polygon3DBox[{{3.016744206679544, -2.7846561218850674`, 
    52.51358939431306}, {1.4921240345730216`, -6.91709903689402, 
    54.15386340856762}, {0.6034750065745661, -6.762894154039191, 
    52.46948015836863}, {2.2386299295578915`, -2.4134345459242903`, 
    50.36389375766042}}], 
   Polygon3DBox[{{2.2386299295578915`, -2.4134345459242903`, 
    50.36389375766042}, {0.6034750065745661, -6.762894154039191, 
    52.46948015836863}, {-0.23774702614579746`, -6.664581868581148, 
    50.77239454070263}, {1.551447440920593, -2.038752020346289, 
    48.09445495674605}}], 
   Polygon3DBox[{{1.551447440920593, -2.038752020346289, 
    48.09445495674605}, {-0.23774702614579746`, -6.664581868581148, 
    50.77239454070263}, {-1.0467789056002692`, -6.665210632017653, 
    49.03768184029957}, {0.9657064997294699, -1.6979766861066286`, 
    45.69151711809242}}], 
   Polygon3DBox[{{0.9657064997294699, -1.6979766861066286`, 
    45.69151711809242}, {-1.0467789056002692`, -6.665210632017653, 
    49.03768184029957}, {-1.8419368601660928`, -6.825319699000542, 
    47.251394369462496`}, {0.47820092433029104`, -1.4283855333987918`, 
    43.114398180767196`}}], 
   Polygon3DBox[{{0.47820092433029104`, -1.4283855333987918`, 
    43.114398180767196`}, {-1.8419368601660928`, -6.825319699000542, 
    47.251394369462496`}, {-2.6493589670449023`, -7.231341702393221, 
    45.4226233894201}, {0.07791978222498286, -1.275877920558114, 
    40.3298680514758}}], 
   Polygon3DBox[{{0.07791978222498286, -1.275877920558114, 
    40.3298680514758}, {-2.6493589670449023`, -7.231341702393221, 
    45.4226233894201}, {-3.508615096818469, -8.000132527428065, 
    43.60687776643703}, {-0.26341436146540687`, -1.303845218959815, 
    37.31500992235913}}], 
   Polygon3DBox[{{-0.26341436146540687`, -1.303845218959815, 
    37.31500992235913}, {-3.508615096818469, -8.000132527428065, 
    43.60687776643703}, {-4.4719044894976285`, -9.2613586249427, 
    41.94165810023179}, {-0.6071482493747289, -1.6236445027458428`, 
    34.06385030739365}}], 
   Polygon3DBox[{{-0.6071482493747289, -1.6236445027458428`, 
    34.06385030739365}, {-4.4719044894976285`, -9.2613586249427, 
    41.94165810023179}, {-5.5783082660990875`, -11.078227799270318`, 
    40.66219036412664}, {-1.084426282339908, -2.4899574764404013`, 
    30.617722518363845`}}], 
   Polygon3DBox[{{-1.084426282339908, -2.4899574764404013`, 
    30.617722518363845`}, {-5.5783082660990875`, -11.078227799270318`, 
    40.66219036412664}, {-6.8035556826240455`, -13.323771496897514`, 
    40.0041235475539}, {-1.98457878508033, -4.54174735811207, 
    27.217101153044958`}}], 
   Polygon3DBox[{{-1.98457878508033, -4.54174735811207, 
    27.217101153044958`}, {-6.8035556826240455`, -13.323771496897514`, 
    40.0041235475539}, {-8.064720149403758, -15.717019904491575`, 
    40.02453710950524}, {-3.699360351831942, -8.690171032537611, 
    24.807320512444754`}}], 
   Polygon3DBox[{{-3.699360351831942, -8.690171032537611, 
    24.807320512444754`}, {-8.064720149403758, -15.717019904491575`, 
    40.02453710950524}, {-9.292526937061375, -18.02789762000172, 
    40.60764394705654}, {-5.796726960158205, -13.78466555878845, 
    24.386530636045357`}}], 
   Polygon3DBox[{{-5.796726960158205, -13.78466555878845, 
    24.386530636045357`}, {-9.292526937061375, -18.02789762000172, 
    40.60764394705654}, {-10.457118875977374`, -20.14705111805355, 
    41.604997637636274`}, {-7.767648506844356, -18.478100044753944`, 
    25.29347427184355}}], 
   Polygon3DBox[{{-7.767648506844356, -18.478100044753944`, 
    25.29347427184355}, {-10.457118875977374`, -20.14705111805355, 
    41.604997637636274`}, {-11.55141053832335, -22.037603169257896`, 
    42.900899172335635`}, {-9.586046051824344, -22.659644566802864`, 
    26.957289108393248`}}], 
   Polygon3DBox[{{-9.586046051824344, -22.659644566802864`, 
    26.957289108393248`}, {-11.55141053832335, -22.037603169257896`, 
    42.900899172335635`}, {-12.577044196518738`, -23.692981486277038`, 
    44.41509029259338}, {-11.275433345317078`, -26.364852110438, 
    29.128016027243685`}}], 
   Polygon3DBox[{{-11.275433345317078`, -26.364852110438, 
    29.128016027243685`}, {-12.577044196518738`, -23.692981486277038`, 
    44.41509029259338}, {-13.538357126442701`, -25.117541972554946`, 
    46.092618065366516`}, {-12.854296866682851`, -29.62630161112722, 
    31.67236278771765}}], 
   Polygon3DBox[{{-12.854296866682851`, -29.62630161112722, 
    31.67236278771765}, {-13.538357126442701`, -25.117541972554946`, 
    46.092618065366516`}, {-14.440112667872482`, -26.318625749429888`, 
    47.89527081387469}, {-14.33593545529319, -32.468063703665344`, 
    34.50674422261155}}], 
   Polygon3DBox[{{-14.33593545529319, -32.468063703665344`, 
    34.50674422261155}, {-14.440112667872482`, -26.318625749429888`, 
    47.89527081387469}, {-15.28662978757628, -27.303229333523266`, 
    49.79580648369985}, {-15.730157139012771`, -34.907579711547264`, 
    37.57327934835316}}], 
   Polygon3DBox[{{-15.730157139012771`, -34.907579711547264`, 
    37.57327934835316}, {-15.28662978757628, -27.303229333523266`, 
    49.79580648369985}, {-16.081416091858816`, -28.07654333746726, 
    51.774108653842305`}, {-17.044258285825673`, -36.956867565174726`, 
    40.82906299111574}}], 
   Polygon3DBox[{{14.795651669675117`, 17.9755737977894, 57.94832539706522}, {
    15.13622505124681, 18.796967685294405`, 57.7893068128711}, {
    15.363306557889995`, 18.850938693913136`, 58.62639057831343}, {
    14.995842981223255`, 18.021681104327662`, 58.67437375329362}}], 
   Polygon3DBox[{{14.995842981223255`, 18.021681104327662`, 
    58.67437375329362}, {15.363306557889995`, 18.850938693913136`, 
    58.62639057831343}, {15.576211335640432`, 18.824791974484757`, 
    59.472564955406746`}, {15.183499014852048`, 17.998888016823006`, 
    59.408464211782}}], 
   Polygon3DBox[{{15.183499014852048`, 17.998888016823006`, 
    59.408464211782}, {15.576211335640432`, 18.824791974484757`, 
    59.472564955406746`}, {15.772389947006896`, 18.715995822453547`, 
    60.324094797356445`}, {15.356408671967861`, 17.905044373241775`, 
    60.147539787522426`}}], 
   Polygon3DBox[{{15.356408671967861`, 17.905044373241775`, 
    60.147539787522426`}, {15.772389947006896`, 18.715995822453547`, 
    60.324094797356445`}, {15.948799446090554`, 18.520919971672086`, 
    61.17608373936328}, {15.511915804204495`, 17.73699789609201, 
    60.88756107893667}}], 
   Polygon3DBox[{{15.511915804204495`, 17.73699789609201, 
    60.88756107893667}, {15.948799446090554`, 18.520919971672086`, 
    61.17608373936328}, {16.10172992869624, 18.23513236868562, 
    62.02191633207582}, {15.646762478024206`, 17.49083773644815, 
    61.62301027933108}}], 
   Polygon3DBox[{{15.646762478024206`, 17.49083773644815, 
    61.62301027933108}, {16.10172992869624, 18.23513236868562, 
    62.02191633207582}, {16.226670149529426`, 17.853862897331854`, 
    62.85268925987246}, {15.756965045267522`, 17.162281340348994`, 
    62.34637736650836}}], 
   Polygon3DBox[{{15.756965045267522`, 17.162281340348994`, 
    62.34637736650836}, {16.226670149529426`, 17.853862897331854`, 
    62.85268925987246}, {16.318231616246088`, 17.372693503091934`, 
    63.65667038646385}, {15.83774059722203, 16.74725981714861, 
    63.04765835744582}}], 
   Polygon3DBox[{{15.83774059722203, 16.74725981714861, 63.04765835744582}, {
    16.318231616246088`, 17.372693503091934`, 63.65667038646385}, {
    16.370169368722962`, 16.788536558413643`, 64.41887105317097}, {
    15.883519056161818`, 16.24276251319848, 63.71393712327929}}], 
   Polygon3DBox[{{15.883519056161818`, 16.24276251319848, 
    63.71393712327929}, {16.370169368722962`, 16.788536558413643`, 
    64.41887105317097}, {16.37555919959281, 16.1009393418957, 
    65.12088325573616}, {15.888097195088715`, 15.647984801000934`, 
    64.32918392008969}}], 
   Polygon3DBox[{{15.888097195088715`, 15.647984801000934`, 
    64.32918392008969}, {16.37555919959281, 16.1009393418957, 
    65.12088325573616}, {16.327208529358348`, 15.313677419305307`, 
    65.74121028955673}, {15.845009157054887`, 14.965760325660824`, 
    64.87447999002819}}], 
   Polygon3DBox[{{15.845009157054887`, 14.965760325660824`, 
    64.87447999002819}, {16.327208529358348`, 15.313677419305307`, 
    65.74121028955673}, {16.2183740552073, 14.436445778097205`, 
    66.25637203389152}, {15.748186752460215`, 14.204120520888369`, 
    65.32893817061833}}], 
   Polygon3DBox[{{15.748186752460215`, 14.204120520888369`, 
    65.32893817061833}, {16.2183740552073, 14.436445778097205`, 
    66.25637203389152}, {16.043803561146714`, 13.48622104428972, 
    66.64301692613894}, {15.592931395385586`, 13.377600187558489`, 
    65.67156096699189}}], 
   Polygon3DBox[{{15.592931395385586`, 13.377600187558489`, 
    65.67156096699189}, {16.043803561146714`, 13.48622104428972, 
    66.64301692613894}, {15.80098282576341, 12.487630725761212`, 
    66.88101527577821}, {15.377086386713927`, 12.507666463293193`, 
    65.88404946602573}}], 
   Polygon3DBox[{{15.377086386713927`, 12.507666463293193`, 
    65.88404946602573}, {15.80098282576341, 12.487630725761212`, 
    66.88101527577821}, {15.491267467953199`, 11.471637741359812`, 
    66.9570002483442}, {15.102096736170207`, 11.621595046487334`, 
    65.95408990066083}}], 
   Polygon3DBox[{{15.102096736170207`, 11.621595046487334`, 
    65.95408990066083}, {15.491267467953199`, 11.471637741359812`, 
    66.9570002483442}, {15.120430309265158`, 10.472290566500343`, 
    66.86725673222247}, {14.773493459967472`, 10.749524052583661`, 
    65.87807566676723}}], 
   Polygon3DBox[{{14.773493459967472`, 10.749524052583661`, 
    65.87807566676723}, {15.120430309265158`, 10.472290566500343`, 
    66.86725673222247}, {14.698244983464553`, 9.522195859076813, 
    66.61871161363283}, {14.400437130582608`, 9.920297609015385, 
    65.66205443723015}}], 
   Polygon3DBox[{{14.400437130582608`, 9.920297609015385, 
    65.66205443723015}, {14.698244983464553`, 9.522195859076813, 
    66.61871161363283}, {14.237121100128492`, 8.64819493696475, 
    66.22743533480201}, {13.994363907944576`, 9.157520305390996, 
    65.32032875245218}}], 
   Polygon3DBox[{{13.994363907944576`, 9.157520305390996, 
    65.32032875245218}, {14.237121100128492`, 8.64819493696475, 
    66.22743533480201}, {13.750269366550143`, 7.868728147438019, 
    65.71522986491475}, {13.567235492868555`, 8.477226286528913, 
    64.87228503933419}}], 
   Polygon3DBox[{{13.567235492868555`, 8.477226286528913, 
    64.87228503933419}, {13.750269366550143`, 7.868728147438019, 
    65.71522986491475}, {13.250043562827441`, 7.193466617510687, 
    65.10567620476004}, {13.130026925144918`, 7.887660168627487, 
    64.33878102602384}}], 
   Polygon3DBox[{{13.130026925144918`, 7.887660168627487, 
    64.33878102602384}, {13.250043562827441`, 7.193466617510687, 
    65.10567620476004}, {12.7468876316018, 6.624728143279308, 
    64.42090785220307}, {12.691831582610108`, 7.390653738024759, 
    63.73926941220336}}], 
   Polygon3DBox[{{12.691831582610108`, 7.390653738024759, 
    63.73926941220336}, {12.7468876316018, 6.624728143279308, 
    64.42090785220307}, {12.24895520788311, 6.159707005134184, 
    63.67967722633582}, {12.259600926952986`, 6.983670329729211, 
    63.09013699932233}}], 
   Polygon3DBox[{{12.259600926952986`, 6.983670329729211, 
    63.09013699932233}, {12.24895520788311, 6.159707005134184, 
    63.67967722633582}, {11.762229519909196`, 5.792693103329517, 
    62.89662643129898}, {11.838324907956723`, 6.661775599204366, 
    62.40413011700631}}], 
   Polygon3DBox[{{11.838324907956723`, 6.661775599204366, 
    62.40413011700631}, {11.762229519909196`, 5.792693103329517, 
    62.89662643129898}, {11.290916703625113`, 5.516853623788383, 
    62.082375502687654`}, {11.431431693073957`, 6.419181344731298, 
    61.690489872146074`}}], 
   Polygon3DBox[{{11.431431693073957`, 6.419181344731298, 
    61.690489872146074`}, {11.290916703625113`, 5.516853623788383, 
    62.082375502687654`}, {10.83793843848397, 5.3254825082254, 
    61.24403865623272}, {11.04125049345099, 6.250306617947479, 
    60.95544332443047}}], 
   Polygon3DBox[{{11.04125049345099, 6.250306617947479, 60.95544332443047}, {
    10.83793843848397, 5.3254825082254, 61.24403865623272}, {
    10.405425882736187`, 5.212796281594644, 60.385898554540034`}, {
    10.669456709025836`, 6.150442674895377, 60.2028167301372}}], 
   Polygon3DBox[{{10.669456709025836`, 6.150442674895377, 60.2028167301372}, {
    10.405425882736187`, 5.212796281594644, 60.385898554540034`}, {
    9.995175696358352, 5.1744071390305075`, 59.51009402907751}, {
    10.317471667643503`, 6.116143272662103, 59.43465161746421}}], 
   Polygon3DBox[{{10.317471667643503`, 6.116143272662103, 
    59.43465161746421}, {9.995175696358352, 5.1744071390305075`, 
    59.51009402907751}, {9.60906378420947, 5.207596545027625, 
    58.617267665799474`}, {9.98681824191428, 6.145447900082872, 
    58.65178335896715}}], 
   Polygon3DBox[{{9.98681824191428, 6.145447900082872, 58.65178335896715}, {
    9.60906378420947, 5.207596545027625, 58.617267665799474`}, {
    9.249429410128016, 5.311485975305109, 57.70717674823558}, {
    9.679446432598773, 6.238018262001906, 57.85438944275263}}], 
   Polygon3DBox[{{9.679446432598773, 6.238018262001906, 57.85438944275263}, {
    9.249429410128016, 5.311485975305109, 57.70717674823558}, {
    8.919448721468592, 5.4871746546660845`, 56.77930734179653}, {
    9.398046749181853, 6.395242329522117, 57.04254376603693}}], 
   Polygon3DBox[{{9.398046749181853, 6.395242329522117, 57.04254376603693}, {
    8.919448721468592, 5.4871746546660845`, 56.77930734179653}, {
    8.623516877640112, 5.737891918082068, 55.833560121487594`}, {
    9.14636773815737, 6.620337974398073, 56.21683551654834}}], 
   Polygon3DBox[{{9.14636773815737, 6.620337974398073, 56.21683551654834}, {
    8.623516877640112, 5.737891918082068, 55.833560121487594`}, {
    8.367652664642446, 6.069190385856685, 54.87110838060683}, {
    8.929547633851891, 6.918465205589516, 55.379134525322854`}}], 
   Polygon3DBox[{{8.929547633851891, 6.918465205589516, 
    55.379134525322854`}, {8.367652664642446, 6.069190385856685, 
    54.87110838060683}, {8.159924772115149, 6.4891735024419095`, 
    53.89557027859031}, {8.75445500759446, 7.296821591785773, 
    54.533612840424716`}}], 
   Polygon3DBox[{{8.75445500759446, 7.296821591785773, 54.533612840424716`}, {
    8.159924772115149, 6.4891735024419095`, 53.89557027859031}, {
    8.010862691549333, 7.008680965381849, 52.91468703846885}, {
    8.62999900701541, 7.764628992161529, 53.68815893316048}}], 
   Polygon3DBox[{{8.62999900701541, 7.764628992161529, 53.68815893316048}, {
    8.010862691549333, 7.008680965381849, 52.91468703846885}, {
    7.933729419150588, 7.641195673000602, 51.942727105663195`}, {
    8.567294406208022, 8.332785329029795, 52.856315319083855`}}], 
   Polygon3DBox[{{8.567294406208022, 8.332785329029795, 
    52.856315319083855`}, {7.933729419150588, 7.641195673000602, 
    51.942727105663195`}, {7.944344195039262, 8.401899830434994, 
    51.00373044327282}, {8.579413918780865, 9.012707000064049, 
    52.05973563690732}}], 
   Polygon3DBox[{{8.579413918780865, 9.012707000064049, 52.05973563690732}, {
    7.944344195039262, 8.401899830434994, 51.00373044327282}, {
    8.059789674430897, 9.304739195140325, 50.135153231551264`}, {
    8.680203580251899, 9.813538076945022, 51.33066390752967}}], 
   Polygon3DBox[{{8.680203580251899, 9.813538076945022, 51.33066390752967}, {
    8.059789674430897, 9.304739195140325, 50.135153231551264`}, {
    8.29491697312315, 10.3558817810334, 49.38988739024377}, {
    8.881393962468023, 10.736782381476132`, 50.71274846244471}}], 
   Polygon3DBox[{{8.881393962468023, 10.736782381476132`, 
    50.71274846244471}, {8.29491697312315, 10.3558817810334, 
    49.38988739024377}, {8.655866166432011, 11.543176368605089`, 
    48.8319151965267}, {9.187606185596666, 11.768634997397395`, 
    50.256806253300475`}}], 
   Polygon3DBox[{{9.187606185596666, 11.768634997397395`, 
    50.256806253300475`}, {8.655866166432011, 11.543176368605089`, 
    48.8319151965267}, {9.132621422235227, 12.82675723853713, 
    48.5204160974147}, {9.590902534988274, 12.874144550447959`, 
    50.00848137852349}}], 
   Polygon3DBox[{{9.590902534988274, 12.874144550447959`, 
    50.00848137852349}, {9.132621422235227, 12.82675723853713, 
    48.5204160974147}, {9.69727499743406, 14.142444574657121`, 
    48.48660184209298}, {10.069523122726123`, 14.000863503817376`, 
    49.991503111744855`}}], 
   Polygon3DBox[{{10.069523122726123`, 14.000863503817376`, 
    49.991503111744855`}, {9.69727499743406, 14.142444574657121`, 
    48.48660184209298}, {10.31277432986933, 15.42184022905188, 
    48.72182100354787}, {10.594044340919204`, 15.093770397809685`, 
    50.199156926434696`}}], 
   Polygon3DBox[{{10.594044340919204`, 15.093770397809685`, 
    50.199156926434696`}, {10.31277432986933, 15.42184022905188, 
    48.72182100354787}, {10.945595032512916`, 16.61312932195646, 
    49.18801418221576}, {11.136777014637797`, 16.110582935067647`, 
    50.60147383995116}}], 
   Polygon3DBox[{{11.136777014637797`, 16.110582935067647`, 
    50.60147383995116}, {10.945595032512916`, 16.61312932195646, 
    49.18801418221576}, {11.572367209285659`, 17.687278802904128`, 
    49.83761607570451}, {11.677404421993248`, 17.026911166868715`, 
    51.15990560556981}}], 
   Polygon3DBox[{{11.677404421993248`, 17.026911166868715`, 
    51.15990560556981}, {11.572367209285659`, 17.687278802904128`, 
    49.83761607570451}, {12.179508324969833`, 18.63280173311518, 
    50.627125975412795`}, {12.203424039962993`, 17.83275344805809, 
    51.83823565155955}}], 
   Polygon3DBox[{{12.203424039962993`, 17.83275344805809, 
    51.83823565155955}, {12.179508324969833`, 18.63280173311518, 
    50.627125975412795`}, {12.760226076177142`, 19.448319356213908`, 
    51.52185702673096}, {12.708147511136971`, 18.526767877446467`, 
    52.60699528571556}}], 
   Polygon3DBox[{{12.708147511136971`, 18.526767877446467`, 
    52.60699528571556}, {12.760226076177142`, 19.448319356213908`, 
    51.52185702673096}, {13.311742994073937`, 20.137123653548933`, 
    52.49586181314776}, {13.188528527663607`, 19.111782802554714`, 
    53.44385663176656}}], 
   Polygon3DBox[{{13.188528527663607`, 19.111782802554714`, 
    53.44385663176656}, {13.311742994073937`, 20.137123653548933`, 
    52.49586181314776}, {13.833414539246993`, 20.7039843730468, 
    53.53027565562512}, {13.64356265692033, 19.59202997661157, 
    54.33248650631772}}], 
   Polygon3DBox[{{13.64356265692033, 19.59202997661157, 54.33248650631772}, {
    13.833414539246993`, 20.7039843730468, 53.53027565562512}, {
    14.325577732129739`, 21.15343666232858, 54.61149043302447}, {
    14.073252674157807`, 19.97161054280351, 55.26110130249882}}], 
   Polygon3DBox[{{14.073252674157807`, 19.97161054280351, 
    55.26110130249882}, {14.325577732129739`, 21.15343666232858, 
    54.61149043302447}, {14.788859796861887`, 21.488903129580176`, 
    55.7295742540563}, {14.477962990575811`, 20.253690207737964`, 
    56.221151393560355`}}], 
   Polygon3DBox[{{14.477962990575811`, 20.253690207737964`, 
    56.221151393560355`}, {14.788859796861887`, 21.488903129580176`, 
    55.7295742540563}, {15.223750296794544`, 21.71226629957138, 
    56.87697980469656}, {14.85800996328506, 20.440099109301492`, 
    57.20621821938638}}], 
   Polygon3DBox[{{14.85800996328506, 20.440099109301492`, 
    57.20621821938638}, {15.223750296794544`, 21.71226629957138, 
    56.87697980469656}, {15.630317634859466`, 21.823690800387382`, 
    58.047479446679624`}, {15.213386879557047`, 20.53115804564663, 
    58.211093187532676`}}], 
   Polygon3DBox[{{15.213386879557047`, 20.53115804564663, 
    58.211093187532676`}, {15.630317634859466`, 21.823690800387382`, 
    58.047479446679624`}, {16.00800207606556, 21.821600728037936`, 
    59.2352514350985}, {15.54356267715687, 20.525643483302634`, 
    59.230982160143945`}}], 
   Polygon3DBox[{{15.54356267715687, 20.525643483302634`, 
    59.230982160143945`}, {16.00800207606556, 21.821600728037936`, 
    59.2352514350985}, {16.35544820081598, 21.702778042957448`, 
    60.43405376041366}, {15.847319579645019`, 20.42085756465877, 
    60.260782993900015`}}], 
   Polygon3DBox[{{15.847319579645019`, 20.42085756465877, 
    60.260782993900015`}, {16.35544820081598, 21.702778042957448`, 
    60.43405376041366}, {16.670358670699528`, 21.462585051401962`, 
    61.636440464314596`}, {16.12261172788115, 20.212803322345273`, 
    61.29439599515668}}], 
   Polygon3DBox[{{16.12261172788115, 20.212803322345273`, 
    61.29439599515668}, {16.670358670699528`, 21.462585051401962`, 
    61.636440464314596`}, {16.949364719697737`, 21.095340125029246`, 
    62.83299648834664}, {16.36643930058272, 19.89648974733502, 
    62.324043511818246`}}], 
   Polygon3DBox[{{16.36643930058272, 19.89648974733502, 
    62.324043511818246`}, {16.949364719697737`, 21.095340125029246`, 
    62.83299648834664}, {17.187921031153017`, 20.59489579373952, 
    64.01159358324004}, {16.57474407003728, 19.466410937146556`, 
    63.33959659388499}}], 
   Polygon3DBox[{{16.57474407003728, 19.466410937146556`, 
    63.33959659388499}, {17.187921031153017`, 20.59489579373952, 
    64.01159358324004}, {17.380246387280216`, 19.955481723889612`, 
    65.156706019669}, {16.74234544009487, 18.91725830925245, 
    64.32793776127033}}], 
   Polygon3DBox[{{16.74234544009487, 18.91725830925245, 64.32793776127033}, {
    17.380246387280216`, 19.955481723889612`, 65.156706019669}, {
    17.51934823527726, 19.172875644276726`, 66.2488753424949}, {
    16.862952453814334`, 18.24492959885697, 65.27243432101699}}], 
   Polygon3DBox[{{16.862952453814334`, 18.24492959885697, 
    65.27243432101699}, {17.51934823527726, 19.172875644276726`, 
    66.2488753424949}, {17.597188642881203`, 18.24593968714583, 
    67.26447958866672}, {16.929306955726776`, 17.447880806069605`, 
    66.15265932999942}}], 
   Polygon3DBox[{{16.929306955726776`, 17.447880806069605`, 
    66.15265932999942}, {17.597188642881203`, 18.24593968714583, 
    67.26447958866672}, {17.60506643750758, 17.178487089807394`, 
    68.17603591093501}, {16.933531930090194`, 16.528806684591515`, 
    66.94457197062198}}], 
   Polygon3DBox[{{16.933531930090194`, 16.528806684591515`, 
    66.94457197062198}, {17.60506643750758, 17.178487089807394`, 
    68.17603591093501}, {17.534293676035517`, 15.981301962811205`, 
    68.95331748847997}, {16.867765082387216`, 15.496506235900057`, 
    67.62143085438234}}], 
   Polygon3DBox[{{16.867765082387216`, 15.496506235900057`, 
    67.62143085438234}, {17.534293676035517`, 15.981301962811205`, 
    68.95331748847997}, {17.37721241756372, 14.673917575969973`, 
    69.56553551838964}, {16.72512804586393, 14.367579665639607`, 
    68.15570398290494}}], 
   Polygon3DBox[{{16.72512804586393, 14.367579665639607`, 
    68.15570398290494}, {17.37721241756372, 14.673917575969973`, 
    69.56553551838964}, {17.12850431660011, 13.28551795456412, 
    69.98463907885004}, {16.500986993484293`, 13.167354903997351`, 
    68.52206602893602}}], 
   Polygon3DBox[{{16.500986993484293`, 13.167354903997351`, 
    68.52206602893602}, {17.12850431660011, 13.28551795456412, 
    69.98463907885004}, {16.786583882975464`, 11.85421397736983, 
    70.18936288078778}, {16.194290832082363`, 11.929304035436067`, 
    68.70116434434465}}], 
   Polygon3DBox[{{16.194290832082363`, 11.929304035436067`, 
    68.70116434434465}, {16.786583882975464`, 11.85421397736983, 
    70.18936288078778}, {16.354688217090644`, 10.424184164482215`, 
    70.16909358045251}, {15.808584871263882`, 10.692425171893259`, 
    68.68326379767817}}], 
   Polygon3DBox[{{15.808584871263882`, 10.692425171893259`, 
    68.68326379767817}, {16.354688217090644`, 10.424184164482215`, 
    70.16909358045251}, {15.84121041613467, 9.040885179762007, 
    69.92625357466562}, {15.352236666972322`, 9.496780310944349, 
    68.47048452563904}}], 
   Polygon3DBox[{{15.352236666972322`, 9.496780310944349, 
    68.47048452563904}, {15.84121041613467, 9.040885179762007, 
    69.92625357466562}, {15.259002566982948`, 7.745480549090454, 
    69.47613828886946}, {14.837622140321297`, 8.378336988266785, 
    68.0765855491724}}], 
   Polygon3DBox[{{14.837622140321297`, 8.378336988266785, 68.0765855491724}, {
    15.259002566982948`, 7.745480549090454, 69.47613828886946}, {
    14.623773806049005`, 6.5701806762926696`, 68.84407973961932}, {
    14.279459163077892`, 7.3647823405938375`, 67.52421598183513}}], 
   Polygon3DBox[{{14.279459163077892`, 7.3647823405938375`, 
    67.52421598183513}, {14.623773806049005`, 6.5701806762926696`, 
    68.84407973961932}, {13.952089888488427`, 5.535837188741262, 
    68.06092161532264}, {13.692854064109168`, 6.4735556525988525`, 
    66.84066750567587}}], 
   Polygon3DBox[{{13.692854064109168`, 6.4735556525988525`, 
    66.84066750567587}, {13.952089888488427`, 5.535837188741262, 
    68.06092161532264}, {13.25958125349448, 4.652094748569869, 
    67.15832537736871}, {13.091669542164498`, 5.712264116299259, 
    66.0536211340155}}], 
   Polygon3DBox[{{13.091669542164498`, 5.712264116299259, 66.0536211340155}, {
    13.25958125349448, 4.652094748569869, 67.15832537736871}, {
    12.55975889893419, 3.9194178303112466`, 66.16512494414904}, {
    12.487553140290155`, 5.080718833839113, 65.187990923176}}], 
   Polygon3DBox[{{12.487553140290155`, 5.080718833839113, 65.187990923176}, {
    12.55975889893419, 3.9194178303112466`, 66.16512494414904}, {
    11.863521327197288`, 3.331926312504408, 65.10520795802509}, {
    11.889634681433286`, 4.573557088357057, 64.26421174490822}}], 
   Polygon3DBox[{{11.889634681433286`, 4.573557088357057, 
    64.26421174490822}, {11.863521327197288`, 3.331926312504408, 
    65.10520795802509}, {11.179213007396859`, 2.8801618586804754`, 
    63.99676900874456}, {11.304707445659986`, 4.182679358893726, 
    63.29774457779741}}], 
   Polygon3DBox[{{11.304707445659986`, 4.182679358893726, 
    63.29774457779741}, {11.179213007396859`, 2.8801618586804754`, 
    63.99676900874456}, {10.513023771223882`, 2.5533185193752885`, 
    62.85249520704102}, {10.737674922802727`, 3.8991429622910068`, 
    62.299361382237095`}}], 
   Polygon3DBox[{{10.737674922802727`, 3.8991429622910068`, 
    62.299361382237095`}, {10.513023771223882`, 2.5533185193752885`, 
    62.85249520704102}, {9.869549661603049, 2.340822397509501, 
    61.680243609420444`}, {10.192099133678706`, 3.7144647759935014`, 
    61.27581373863599}}], 
   Polygon3DBox[{{10.192099133678706`, 3.7144647759935014`, 
    61.27581373863599}, {9.869549661603049, 2.340822397509501, 
    61.680243609420444`}, {9.252401183600748, 2.233343287119699, 
    60.48389566001985}, {9.670757717457358, 3.6214391315650984`, 
    60.23062303968187}}], 
   Polygon3DBox[{{9.670757717457358, 3.6214391315650984`, 
    60.23062303968187}, {9.252401183600748, 2.233343287119699, 
    60.48389566001985}, {8.664804264272725, 2.2233933098734444`, 
    59.2642133616579}, {9.176172426105913, 3.614619550406212, 
    59.16485806093633}}], 
   Polygon3DBox[{{9.176172426105913, 3.614619550406212, 59.16485806093633}, {
    8.664804264272725, 2.2233933098734444`, 59.2642133616579}, {
    8.1101798930876, 2.3056715835758093`, 58.019630493737864`}, {
    8.711105743835375, 3.6906025521637416`, 58.077857885731724`}}], 
   Polygon3DBox[{{8.711105743835375, 3.6906025521637416`, 
    58.077857885731724`}, {8.1101798930876, 2.3056715835758093`, 
    58.019630493737864`}, {7.592711966007817, 2.4772950116498103`, 
    56.746987119545985`}, {8.279040106186319, 3.848226470997011, 
    56.96791856333435}}], 
   Polygon3DBox[{{8.279040106186319, 3.848226470997011, 56.96791856333435}, {
    7.592711966007817, 2.4772950116498103`, 56.746987119545985`}, {
    7.117924765754297, 2.7380388565362828`, 55.44227083987731}, {
    7.884661806231775, 4.088776011411257, 55.833005363033806`}}], 
   Polygon3DBox[{{7.884661806231775, 4.088776011411257, 
    55.833005363033806`}, {7.117924765754297, 2.7380388565362828`, 
    55.44227083987731}, {6.6932965491250505`, 3.0907081379785204`, 
    54.101482105759956`}, {7.534372955998206, 4.416268866017572, 
    54.67159484349802}}], 
   Polygon3DBox[{{7.534372955998206, 4.416268866017572, 54.67159484349802}, {
    6.6932965491250505`, 3.0907081379785204`, 54.101482105759956`}, {
    6.328936339804237, 3.541773355604953, 52.72181380462425}, {
    7.23684989337708, 4.837889069382188, 53.483807155241045`}}], 
   Polygon3DBox[{{7.23684989337708, 4.837889069382188, 53.483807155241045`}, {
    6.328936339804237, 3.541773355604953, 52.72181380462425}, {
    6.038345078988708, 4.102418270251807, 51.3034523406176}, {
    7.003648789711147, 5.364603682111747, 52.273072905397285`}}], 
   Polygon3DBox[{{7.003648789711147, 5.364603682111747, 
    52.273072905397285`}, {6.038345078988708, 4.102418270251807, 
    51.3034523406176}, {5.839253713174497, 4.790111278349207, 
    49.85249930831259}, {6.849807668791901, 6.011903548617434, 
    51.04869592070618}}], 
   Polygon3DBox[{{6.849807668791901, 6.011903548617434, 51.04869592070618}, {
    5.839253713174497, 4.790111278349207, 49.85249930831259}, {
    5.754418524281587, 5.630563740867972, 48.38579239057638}, {
    6.794251638231678, 6.800321373347492, 49.82978224677969}}], 
   Polygon3DBox[{{6.794251638231678, 6.800321373347492, 49.82978224677969}, {
    5.754418524281587, 5.630563740867972, 48.38579239057638}, {
    5.811870922795198, 6.65904853781128, 46.93862039729137}, {
    6.859447533184737, 7.754652724651701, 48.650883484476296`}}], 
   Polygon3DBox[{{6.859447533184737, 7.754652724651701, 
    48.650883484476296`}, {5.811870922795198, 6.65904853781128, 
    46.93862039729137}, {6.04304080751938, 7.917661302979714, 
    45.57559076904606}, {7.069000226343038, 8.899372549199283, 
    47.56859557926529}}], 
   Polygon3DBox[{{7.069000226343038, 8.899372549199283, 47.56859557926529}, {
    6.04304080751938, 7.917661302979714, 45.57559076904606}, {
    6.47511652056684, 9.44092323992347, 44.40026373379119}, {
    7.4409810152979645`, 10.246353789606841`, 46.66468011344282}}], 
   Polygon3DBox[{{7.4409810152979645`, 10.246353789606841`, 
    46.66468011344282}, {6.47511652056684, 9.44092323992347, 
    44.40026373379119}, {7.113812463576855, 11.2226988981469, 
    43.54687888364518}, {7.97602226014039, 11.774382400482704`, 
    46.03503449034168}}], 
   Polygon3DBox[{{7.97602226014039, 11.774382400482704`, 46.03503449034168}, {
    7.113812463576855, 11.2226988981469, 43.54687888364518}, {
    7.924513400880055, 13.182707550147335`, 43.1319683873778}, {
    8.646901071232334, 13.414993658030621`, 45.75611169652395}}], 
   Polygon3DBox[{{8.646901071232334, 13.414993658030621`, 
    45.75611169652395}, {7.924513400880055, 13.182707550147335`, 
    43.1319683873778}, {8.83845978106852, 15.184818066816042`, 
    43.190233107902756`}, {9.403886336191489, 15.06931732426709, 
    45.84815796044728}}], 
   Polygon3DBox[{{9.403886336191489, 15.06931732426709, 45.84815796044728}, {
    8.83845978106852, 15.184818066816042`, 43.190233107902756`}, {
    9.786850633777773, 17.104497918999304`, 43.669200188993045`}, {
    10.19561426709588, 16.64819396231886, 46.27359271547617}}], 
   Polygon3DBox[{{10.19561426709588, 16.64819396231886, 46.27359271547617}, {
    9.786850633777773, 17.104497918999304`, 43.669200188993045`}, {
    10.724206148814172`, 18.867718975734615`, 44.48062760660679}, {
    10.984979621361981`, 18.095940231723045`, 46.967878492814734`}}], 
   Polygon3DBox[{{10.984979621361981`, 18.095940231723045`, 
    46.967878492814734`}, {10.724206148814172`, 18.867718975734615`, 
    44.48062760660679}, {11.627436824924871`, 20.44317835022959, 
    45.54201291013661}, {11.75084294485914, 19.387326883672557`, 
    47.86745205085049}}], 
   Polygon3DBox[{{11.75084294485914, 19.387326883672557`, 
    47.86745205085049}, {11.627436824924871`, 20.44317835022959, 
    45.54201291013661}, {12.487012687616096`, 21.82306279680503, 
    46.78941803429217}, {12.48311734896761, 20.515492702401833`, 
    48.920901633159744`}}], 
   Polygon3DBox[{{12.48311734896761, 20.515492702401833`, 
    48.920901633159744`}, {12.487012687616096`, 21.82306279680503, 
    46.78941803429217}, {13.300234803840885`, 23.00993231733384, 
    48.17638512883102}, {13.17796632814651, 21.482376803983893`, 
    50.0898474200772}}], 
   Polygon3DBox[{{13.17796632814651, 21.482376803983893`, 50.0898474200772}, {
    13.300234803840885`, 23.00993231733384, 48.17638512883102}, {
    14.067507338301093`, 24.00991410543451, 49.669721265392376`}, {
    13.834715506536106`, 22.293197349348517`, 51.346497063675166`}}], 
   Polygon3DBox[{{13.834715506536106`, 22.293197349348517`, 
    51.346497063675166`}, {14.067507338301093`, 24.00991410543451, 
    49.669721265392376`}, {14.790431555942757`, 24.82942540246411, 
    51.24561423499889}, {14.454099616708373`, 22.953593939319294`, 
    52.67085444809672}}], 
   Polygon3DBox[{{14.454099616708373`, 22.953593939319294`, 
    52.67085444809672}, {14.790431555942757`, 24.82942540246411, 
    51.24561423499889}, {15.470822083917877`, 25.473613506456672`, 
    52.8866468958415}, {15.037288059694122`, 23.46820266794426, 
    54.04837441687454}}], 
   Polygon3DBox[{{15.037288059694122`, 23.46820266794426, 
    54.04837441687454}, {15.470822083917877`, 25.473613506456672`, 
    52.8866468958415}, {16.110168831346833`, 25.945623173779744`, 
    54.57955771308009}, {15.585325139416117`, 23.839965005784247`, 
    55.468119038409775`}}], 
   Polygon3DBox[{{15.585325139416117`, 23.839965005784247`, 
    55.468119038409775`}, {16.110168831346833`, 25.945623173779744`, 
    54.57955771308009}, {16.709312356877046`, 26.246286554067826`, 
    56.31351015927642}, {16.098784164062998`, 24.06982220389537, 
    56.921296467160005`}}], 
   Polygon3DBox[{{16.098784164062998`, 24.06982220389537, 
    56.921296467160005`}, {16.709312356877046`, 26.246286554067826`, 
    56.31351015927642}, {17.268220617649508`, 26.374059831334794`, 
    58.07868245711269}, {16.5775297063966, 24.156633576050535`, 
    58.400054452836514`}}], 
   Polygon3DBox[{{16.5775297063966, 24.156633576050535`, 
    58.400054452836514`}, {17.268220617649508`, 26.374059831334794`, 
    58.07868245711269}, {17.785813044719404`, 26.325141047211737`, 
    59.865047873300846`}, {17.020533354977445`, 24.09725394608189, 
    59.89642842840819}}], 
   Polygon3DBox[{{17.020533354977445`, 24.09725394608189, 
    59.89642842840819}, {17.785813044719404`, 26.325141047211737`, 
    59.865047873300846`}, {18.25980752945167, 26.093761815994686`, 
    61.66126359487599}, {17.42571627910442, 23.886759306913444`, 
    61.401375333005745`}}], 
   Polygon3DBox[{{17.42571627910442, 23.886759306913444`, 
    61.401375333005745`}, {18.25980752945167, 26.093761815994686`, 
    61.66126359487599}, {18.68658340876719, 25.672680763856583`, 
    63.453626106899534`}, {17.789809187402156`, 23.51884347562563, 
    62.90385412680849}}], 
   Polygon3DBox[{{17.789809187402156`, 23.51884347562563, 
    62.90385412680849}, {18.68658340876719, 25.672680763856583`, 
    63.453626106899534`}, {19.06106675225064, 25.053929642198554`, 
    65.22508993960646}, {18.10823355550359, 22.986432095572866`, 
    64.38994551420407}}], 
   Polygon3DBox[{{18.10823355550359, 22.986432095572866`, 
    64.38994551420407}, {19.06106675225064, 25.053929642198554`, 
    65.22508993960646}, {19.37665715358941, 24.22987585390666, 
    66.95439123728009}, {18.37502116690645, 22.282575680330837`, 
    65.84204179919625}}], 
   Polygon3DBox[{{18.37502116690645, 22.282575680330837`, 
    65.84204179919625}, {19.37665715358941, 24.22987585390666, 
    66.95439123728009}, {19.625229673422826`, 23.19466259460447, 
    68.6153724238826}, {18.58280413502114, 21.401686238725844`, 
    67.23818777847183}}], 
   Polygon3DBox[{{18.58280413502114, 21.401686238725844`, 
    67.23818777847183}, {19.625229673422826`, 23.19466259460447, 
    68.6153724238826}, {19.797261516044543`, 21.946058866444073`, 
    70.1766695873068}, {18.72292495681785, 20.341161673609175`, 
    68.55171695110073}}], 
   Polygon3DBox[{{18.72292495681785, 20.341161673609175`, 
    68.55171695110073}, {19.797261516044543`, 21.946058866444073`, 
    70.1766695873068}, {19.882147594162504`, 20.4876802006104, 
    71.60199150348133}, {18.785733156282724`, 19.103381525445066`, 
    69.75139817531883}}], 
   Polygon3DBox[{{18.785733156282724`, 19.103381525445066`, 
    69.75139817531883}, {19.882147594162504`, 20.4876802006104, 
    71.60199150348133}, {19.86877511788123, 18.831410973301793`, 
    72.851264369366}, {18.761144002604176`, 17.697936963975085`, 
    70.80236466856049}}], 
   Polygon3DBox[{{18.761144002604176`, 17.697936963975085`, 
    70.80236466856049}, {19.86877511788123, 18.831410973301793`, 
    72.851264369366}, {19.746411978742877`, 16.999667932345396`, 
    73.8828940829949}, {18.63952081949871, 16.14376769530231, 
    71.6680940937847}}], 
   Polygon3DBox[{{18.63952081949871, 16.14376769530231, 71.6680940937847}, {
    19.746411978742877`, 16.999667932345396`, 73.8828940829949}, {
    19.505910646762967`, 15.026926219510038`, 74.6572467370206}, {
    18.41288508966285, 14.470646482151691`, 72.3135759433922}}], 
   Polygon3DBox[{{18.41288508966285, 14.470646482151691`, 72.3135759433922}, {
    19.505910646762967`, 15.026926219510038`, 74.6572467370206}, {
    19.14112785840089, 12.959780741677147`, 75.14112034702168}, {
    18.076342960935758`, 12.719278164460476`, 72.70947735499846}}], 
   Polygon3DBox[{{18.076342960935758`, 12.719278164460476`, 
    72.70947735499846}, {19.14112785840089, 12.959780741677147`, 
    75.14112034702168}, {18.650323796281292`, 10.85489375228101, 
    75.31250728624038}, {17.62945819430195, 10.939342391304715`, 
    72.83661986204652}}], 
   Polygon3DBox[{{17.62945819430195, 10.939342391304715`, 
    72.83661986204652}, {18.650323796281292`, 10.85489375228101, 
    75.31250728624038}, {18.037187811172803`, 8.77462256222378, 
    75.16450336294149}, {17.07717139036589, 9.185276852077587, 
    72.68959960442653}}], 
   Polygon3DBox[{{17.07717139036589, 9.185276852077587, 72.68959960442653}, {
    18.037187811172803`, 8.77462256222378, 75.16450336294149}, {
    17.311129144598322`, 6.780894877771412, 74.70710770407831}, {
    16.42987788227035, 7.510434363705487, 72.2782749159385}}], 
   Polygon3DBox[{{16.42987788227035, 7.510434363705487, 72.2782749159385}, {
    17.311129144598322`, 6.780894877771412, 74.70710770407831}, {
    16.48663420511212, 4.928682515557391, 73.96611672670512}, {
    15.70250387808167, 5.961063486903562, 71.62638258054807}}], 
   Polygon3DBox[{{15.70250387808167, 5.961063486903562, 71.62638258054807}, {
    16.48663420511212, 4.928682515557391, 73.96611672670512}, {
    15.58178888263202, 3.260736130842786, 72.97925447518817}, {
    14.912785885561961`, 4.571794750922659, 70.7675823037927}}], 
   Polygon3DBox[{{14.912785885561961`, 4.571794750922659, 70.7675823037927}, {
    15.58178888263202, 3.260736130842786, 72.97925447518817}, {
    14.61634661510991, 1.8048173817457307`, 71.79062646971236}, {
    14.079250208367428`, 3.3637197328636708`, 69.74017445867364}}], 
   Polygon3DBox[{{14.079250208367428`, 3.3637197328636708`, 
    69.74017445867364}, {14.61634661510991, 1.8048173817457307`, 
    71.79062646971236}, {13.609834502421307`, 0.5737245461178098, 
    70.44500689931058}, {13.219431905553131`, 2.3450970370624233`, 
    68.58201830776643}}], 
   Polygon3DBox[{{13.219431905553131`, 2.3450970370624233`, 
    68.58201830776643}, {13.609834502421307`, 0.5737245461178098, 
    70.44500689931058}, {12.580092144991152`, -0.4324976024460958, 
    68.9832108570608}, {12.348679711048222`, 1.513867634501591, 
    67.32674381436712}}], 
   Polygon3DBox[{{12.348679711048222`, 1.513867634501591, 
    67.32674381436712}, {12.580092144991152`, -0.4324976024460958, 
    68.9832108570608}, {11.542424355637305`, -1.2232168380914432`, 
    67.43914614715327}, {11.479626261680613`, 0.8608911469438024, 
    66.00161944126907}}], 
   Polygon3DBox[{{11.479626261680613`, 0.8608911469438024, 
    66.00161944126907}, {11.542424355637305`, -1.2232168380914432`, 
    67.43914614715327}, {10.509348586024224`, -1.8137327161708854`, 
    65.8385010870773}, {10.622210854849367`, 0.3730348742512632, 
    64.62685883240668}}], 
   Polygon3DBox[{{10.622210854849367`, 0.3730348742512632, 
    64.62685883240668}, {10.509348586024224`, -1.8137327161708854`, 
    65.8385010870773}, {9.490804028095397, -2.2223063607640237`, 
    64.1986527362325}, {9.784070856911647, 0.03564970935649747, 
    63.21589555171435}}], 
   Polygon3DBox[{{9.784070856911647, 0.03564970935649747, 
    63.21589555171435}, {9.490804028095397, -2.2223063607640237`, 
    64.1986527362325}, {8.49466333975024, -2.467982251765494, 
    62.52928796838156}, {8.971134473578633, -0.16568887485748068`, 
    61.77616089974504}}], 
   Polygon3DBox[{{8.971134473578633, -0.16568887485748068`, 
    61.77616089974504}, {8.49466333975024, -2.467982251765494, 
    62.52928796838156}, {7.527414753848045, -2.5692219111428605`, 
    60.83331023763189}, {8.188300116485374, -0.2440938733568936, 
    60.31002604127617}}], 
   Polygon3DBox[{{8.188300116485374, -0.2440938733568936, 
    60.31002604127617}, {7.527414753848045, -2.5692219111428605`, 
    60.83331023763189}, {6.594925619503668, -2.54323603527913, 
    59.107746502505194`}, {7.44014074512522, -0.21077051172880928`, 
    58.815713825967165`}}], 
   Polygon3DBox[{{7.44014074512522, -0.21077051172880928`, 
    58.815713825967165`}, {6.594925619503668, -2.54323603527913, 
    59.107746502505194`}, {5.703234600132601, -2.4058591519010664`, 
    57.344506816334025`}, {6.73161067502699, -0.0747321569709832, 
    57.28810386159672}}], 
   Polygon3DBox[{{6.73161067502699, -0.0747321569709832, 57.28810386159672}, {
    5.703234600132601, -2.4058591519010664`, 57.344506816334025`}, {
    4.8593364611270236`, -2.1718085741972994`, 55.53096387361235}, {
    6.068755403664033, 0.15734567062090443`, 55.719442290862915`}}], 
   Polygon3DBox[{{6.068755403664033, 0.15734567062090443`, 
    55.719442290862915`}, {4.8593364611270236`, -2.1718085741972994`, 
    55.53096387361235}, {4.071913830190879, -1.855159565389553, 
    53.650417450122035`}, {5.459435373747843, 0.48131712392438525`, 
    54.10003906078334}}], 
   Polygon3DBox[{{5.459435373747843, 0.48131712392438525`, 
    54.10003906078334}, {4.071913830190879, -1.855159565389553, 
    53.650417450122035`}, {3.3519318561106304`, -1.4698039397125444`, 
    51.68260097504323}, {4.914078599535008, 0.8960382539375088, 
    52.419110340052086`}}], 
   Polygon3DBox[{{4.914078599535008, 0.8960382539375088, 
    52.419110340052086`}, {3.3519318561106304`, -1.4698039397125444`, 
    51.68260097504323}, {2.712956551273141, -1.0294862559959392`, 
    49.60447147237599}, {4.44648669423851, 1.4044698095167143`, 
    50.66602738159652}}], 
   Polygon3DBox[{{4.44648669423851, 1.4044698095167143`, 50.66602738159652}, {
    2.712956551273141, -1.0294862559959392`, 49.60447147237599}, {
    2.1710452524588226`, -0.5466749936485237, 47.391562517504205`}, {
    4.074757506083159, 2.015960291975998, 48.83240805552001}}], 
   Polygon3DBox[{{4.074757506083159, 2.015960291975998, 48.83240805552001}, {
    2.1710452524588226`, -0.5466749936485237, 47.391562517504205`}, {
    1.7442471923048748`, -0.02898710306939367, 45.02011518684433}, {
    3.8224883369922678`, 2.750523960549099, 46.91583258985769}}], 
   Polygon3DBox[{{3.8224883369922678`, 2.750523960549099, 
    46.91583258985769}, {1.7442471923048748`, -0.02898710306939367, 
    45.02011518684433}, {1.4524283375816551`, 0.5289238469422742, 
    42.47010779612246}, {3.7205735608507675`, 3.6460711686672425`, 
    44.926721854543366`}}], 
   Polygon3DBox[{{3.7205735608507675`, 3.6460711686672425`, 
    44.926721854543366`}, {1.4524283375816551`, 0.5289238469422742, 
    42.47010779612246}, {1.3196359313450166`, 1.1616598383938093`, 
    39.72982848473245}, {3.809783734149848, 4.768686070936746, 
    42.90150524157738}}], 
   Polygon3DBox[{{3.809783734149848, 4.768686070936746, 42.90150524157738}, {
    1.3196359313450166`, 1.1616598383938093`, 39.72982848473245}, {
    1.3838813562870769`, 1.9653652745053918`, 36.80598195367001}, {
    4.142376293838385, 6.220759864532667, 40.92725915745179}}], 
   Polygon3DBox[{{4.142376293838385, 6.220759864532667, 40.92725915745179}, {
    1.3838813562870769`, 1.9653652745053918`, 36.80598195367001}, {
    1.7230700679644875`, 3.1631955565175227`, 33.756461942764965`}, {
    4.773087163431232, 8.123162892771592, 39.17776586082316}}], 
   Polygon3DBox[{{4.773087163431232, 8.123162892771592, 39.17776586082316}, {
    1.7230700679644875`, 3.1631955565175227`, 33.756461942764965`}, {
    2.4991707957823555`, 5.208461699280168, 30.805079177959986`}, {
    5.717992991378458, 10.521694606378494`, 37.91825689270537}}], 
   Polygon3DBox[{{5.717992991378458, 10.521694606378494`, 
    37.91825689270537}, {2.4991707957823555`, 5.208461699280168, 
    30.805079177959986`}, {3.8989409709953935`, 8.626398284289486, 
    28.59604621082142}, {6.897454233929082, 13.256779696767442`, 
    37.37533855425329}}], 
   Polygon3DBox[{{6.897454233929082, 13.256779696767442`, 
    37.37533855425329}, {3.8989409709953935`, 8.626398284289486, 
    28.59604621082142}, {5.708946747991252, 12.940723448080114`, 
    27.86268096788684}, {8.171942118629088, 16.040498269018773`, 
    37.56035534239874}}], 
   Polygon3DBox[{{8.171942118629088, 16.040498269018773`, 
    37.56035534239874}, {5.708946747991252, 12.940723448080114`, 
    27.86268096788684}, {7.522978720364415, 17.160360743787322`, 
    28.386834251885976`}, {9.440606148584632, 18.66820257401434, 
    38.32632153012382}}], 
   Polygon3DBox[{{9.440606148584632, 18.66820257401434, 38.32632153012382}, {
    7.522978720364415, 17.160360743787322`, 28.386834251885976`}, {
    9.22937656838054, 20.993685505387134`, 29.69953474267848}, {
    10.65929248172009, 21.054034684075525`, 39.516527518230475`}}], 
   Polygon3DBox[{{10.65929248172009, 21.054034684075525`, 
    39.516527518230475`}, {9.22937656838054, 20.993685505387134`, 
    29.69953474267848}, {10.823412964299195`, 24.413286881727824`, 
    31.535503148413895`}, {11.814015610027626`, 23.173827681850025`, 
    41.014743740799766`}}], 
   Polygon3DBox[{{11.814015610027626`, 23.173827681850025`, 
    41.014743740799766`}, {10.823412964299195`, 24.413286881727824`, 
    31.535503148413895`}, {12.315036853904157`, 27.43299627599335, 
    33.747842362031264`}, {12.902792646206228`, 25.027126476149544`, 
    42.74112013405392}}], 
   Polygon3DBox[{{12.902792646206228`, 25.027126476149544`, 
    42.74112013405392}, {12.315036853904157`, 27.43299627599335, 
    33.747842362031264`}, {13.714502586031669`, 30.070744141524518`, 
    36.24571701773721}, {13.92792511864389, 26.621214687425947`, 
    44.6406959470362}}], 
   Polygon3DBox[{{13.92792511864389, 26.621214687425947`, 44.6406959470362}, {
    13.714502586031669`, 30.070744141524518`, 36.24571701773721}, {
    15.030450441355573`, 32.342216675502044`, 38.96783846856194}, {
    14.892952208811844`, 27.964793993217945`, 46.674796596168896`}}], 
   Polygon3DBox[{{14.892952208811844`, 27.964793993217945`, 
    46.674796596168896`}, {15.030450441355573`, 32.342216675502044`, 
    38.96783846856194}, {16.269793353783584`, 34.25953221243827, 
    41.870135975746464`}, {15.801391583833418`, 29.065368137818048`, 
    48.815386858597414`}}], 
   Polygon3DBox[{{15.801391583833418`, 29.065368137818048`, 
    48.815386858597414`}, {16.269793353783584`, 34.25953221243827, 
    41.870135975746464`}, {17.43781700784265, 35.830891416309115`, 
    44.91912610338217}, {16.656165400577745`, 29.928103719579667`, 
    51.0413042837098}}], 
   Polygon3DBox[{{16.656165400577745`, 29.928103719579667`, 
    51.0413042837098}, {17.43781700784265, 35.830891416309115`, 
    44.91912610338217}, {18.538246699363675`, 37.06048956361915, 
    48.0878016266046}, {17.459297033858558`, 30.555345146659338`, 
    53.33559168768486}}], 
   Polygon3DBox[{{17.459297033858558`, 30.555345146659338`, 
    53.33559168768486}, {18.538246699363675`, 37.06048956361915, 
    48.0878016266046}, {19.573256205314458`, 37.94857465884359, 
    51.352735924149954`}, {18.211716053954067`, 30.946473255160384`, 
    55.68346259279295}}], 
   Polygon3DBox[{{18.211716053954067`, 30.946473255160384`, 
    55.68346259279295}, {19.573256205314458`, 37.94857465884359, 
    51.352735924149954`}, {20.543429480066084`, 38.49165817378918, 
    54.691814445670225`}, {18.913105088531342`, 31.09799633865905, 
    58.070630019124486`}}], 
   Polygon3DBox[{{18.913105088531342`, 31.09799633865905, 
    58.070630019124486`}, {20.543429480066084`, 38.49165817378918, 
    54.691814445670225`}, {21.44768955511285, 38.68291787484938, 
    58.08230959456368}, {19.561762149219877`, 31.003849838006047`, 
    60.48184472021694}}], 
   Polygon3DBox[{{19.561762149219877`, 31.003849838006047`, 
    60.48184472021694}, {21.44768955511285, 38.68291787484938, 
    58.08230959456368}, {22.283208919710706`, 38.51284704938825, 
    61.49916432124021}, {20.154471391149638`, 30.655926070069285`, 
    62.89956254034665}}], 
   Polygon3DBox[{{20.154471391149638`, 30.655926070069285`, 
    62.89956254034665}, {22.283208919710706`, 38.51284704938825, 
    61.49916432124021}, {23.045317198676855`, 37.970214326128904`, 
    64.91343816822828}, {20.686387568693302`, 30.04488186925986, 
    65.3027163511438}}], 
   Polygon3DBox[{{20.686387568693302`, 30.04488186925986, 65.3027163511438}, {
    23.045317198676855`, 37.970214326128904`, 64.91343816822828}, {
    23.727425891529023`, 37.04340225188662, 68.29093650620504}, {
    21.15095013913501, 29.16128602655844, 67.66562027817046}}], 
   Polygon3DBox[{{21.15095013913501, 29.16128602655844, 67.66562027817046}, {
    23.727425891529023`, 37.04340225188662, 68.29093650620504}, {
    24.32099605792575, 35.722185158257496`, 71.59110586893958}, {
    21.539854292789474`, 27.99716747923623, 69.95709051310553}}], 
   Polygon3DBox[{{21.539854292789474`, 27.99716747923623, 
    69.95709051310553}, {24.32099605792575, 35.722185158257496`, 
    71.59110586893958}, {24.815582346812423`, 33.99997914169937, 
    74.76634073981484}, {21.843118524255598`, 26.54800114265502, 
    72.1399300059025}}], 
   Polygon3DBox[{{21.843118524255598`, 26.54800114265502, 72.1399300059025}, {
    24.815582346812423`, 33.99997914169937, 74.76634073981484}, {
    25.19899408372451, 31.87653916101103, 77.76190594994884}, {
    22.049300176335212`, 24.81510894980036, 74.1709880675877}}], 
   Polygon3DBox[{{22.049300176335212`, 24.81510894980036, 74.1709880675877}, {
    25.19899408372451, 31.87653916101103, 77.76190594994884}, {
    25.457618441944945`, 29.360981628125558`, 80.51672039791093}, {
    22.145917601314398`, 22.808346736052712`, 76.0020531837164}}], 
   Polygon3DBox[{{22.145917601314398`, 22.808346736052712`, 
    76.0020531837164}, {25.457618441944945`, 29.360981628125558`, 
    80.51672039791093}, {25.576947759544684`, 26.474873852854394`, 
    82.9652480471404}, {22.120132942328677`, 20.548788936110363`, 
    77.58183609299925}}], 
   Polygon3DBox[{{22.120132942328677`, 20.548788936110363`, 
    77.58183609299925}, {25.576947759544684`, 26.474873852854394`, 
    82.9652480471404}, {25.542337520921915`, 23.254968698923438`, 
    85.0406694078003}, {21.959723219474743`, 18.07093113266397, 
    78.85920576397339}}], 
   Polygon3DBox[{{21.959723219474743`, 18.07093113266397, 
    78.85920576397339}, {25.542337520921915`, 23.254968698923438`, 
    85.0406694078003}, {25.33998874008747, 19.755013464573018`, 
    86.67933200098864}, {21.65431057785845, 15.42376317611764, 
    79.78761176451339}}], 
   Polygon3DBox[{{21.65431057785845, 15.42376317611764, 79.78761176451339}, {
    25.33998874008747, 19.755013464573018`, 86.67933200098864}, {
    24.958097715077237`, 16.045993728959523`, 87.82619559669816}, {
    21.196735180033475`, 12.670025401403592`, 80.33025930191536}}], 
   Polygon3DBox[{{21.196735180033475`, 12.670025401403592`, 
    80.33025930191536}, {24.958097715077237`, 16.045993728959523`, 
    87.82619559669816}, {24.38805459251547, 12.21426599398421, 
    88.44063944700393}, {20.58435516210824, 9.883165159647483, 
    80.46517798498323}}], 
   Polygon3DBox[{{20.58435516210824, 9.883165159647483, 80.46517798498323}, {
    24.38805459251547, 12.21426599398421, 88.44063944700393}, {
    23.625517335289512`, 8.357341620244613, 88.50168855455587}, {
    19.81998929778823, 7.142015228704761, 80.18902395783383}}], 
   Polygon3DBox[{{19.81998929778823, 7.142015228704761, 80.18902395783383}, {
    23.625517335289512`, 8.357341620244613, 88.50168855455587}, {
    22.671163859100627`, 4.577584648241221, 88.01158968138397}, {
    18.91223108716216, 4.523915849140914, 79.51849986310994}}], 
   Polygon3DBox[{{18.91223108716216, 4.523915849140914, 79.51849986310994}, {
    22.671163859100627`, 4.577584648241221, 88.01158968138397}, {
    21.53095281716343, 0.9746445267974884, 86.99684548545984}, {
    17.87498524728475, 2.097613820306425, 78.48878162455036}}], 
   Polygon3DBox[{{17.87498524728475, 2.097613820306425, 78.48878162455036}, {
    21.53095281716343, 0.9746445267974884, 86.99684548545984}, {
    20.215805619180674`, -2.362147826110466, 85.50630681886156}, {
    16.72627930747742, -0.08253695535180361, 77.14916955397227}}], 
   Polygon3DBox[{{16.72627930747742, -0.08253695535180361, 
    77.14916955397227}, {20.215805619180674`, -2.362147826110466, 
    85.50630681886156}, {18.740736894861413`, -5.36012085284295, 
    83.60658788710995}, {15.486600748791329`, -1.9799266023043467`, 
    75.55697175320059}}], 
   Polygon3DBox[{{15.486600748791329`, -1.9799266023043467`, 
    75.55697175320059}, {18.740736894861413`, -5.36012085284295, 
    83.60658788710995}, {17.123568883205234`, -7.967355362889644, 
    81.37566750739613}, {14.177116060972963`, -3.57622145909234, 
    73.7710134599923}}], 
   Polygon3DBox[{{14.177116060972963`, -3.57622145909234, 73.7710134599923}, {
    17.123568883205234`, -7.967355362889644, 81.37566750739613}, {
    15.383430681171758`, -10.154126531148803`, 78.89585892451885}, {
    12.81810722079441, -4.869505044739576, 71.84601959611733}}], 
   Polygon3DBox[{{12.81810722079441, -4.869505044739576, 71.84601959611733}, {
    15.383430681171758`, -10.154126531148803`, 78.89585892451885}, {
    13.539249364477984`, -11.911920219183106`, 76.24729228614501}, {
    11.427846241979701`, -5.8709512800217265`, 69.82860207606291}}], 
   Polygon3DBox[{{11.427846241979701`, -5.8709512800217265`, 
    69.82860207606291}, {13.539249364477984`, -11.911920219183106`, 
    76.24729228614501}, {11.608393605083819`, -13.250728781449787`, 
    73.50273414721887}, {10.021986427955598`, -6.601050003875824, 
    67.7549918776731}}], 
   Polygon3DBox[{{10.021986427955598`, -6.601050003875824, 
    67.7549918776731}, {11.608393605083819`, -13.250728781449787`, 
    73.50273414721887}, {9.699917817165673, -14.159956724247998`, 
    70.85307509313947}, {8.613435183493017, -7.086215036012263, 
    65.65021596913638}}], 
   Polygon3DBox[{{8.613435183493017, -7.086215036012263, 65.65021596913638}, {
    9.699917817165673, -14.159956724247998`, 70.85307509313947}, {
    7.918582570394864, -14.701652574892513`, 68.45685485870605}, {
    7.212609188621679, -7.356319397003395, 63.528208163325345`}}], 
   Polygon3DBox[{{7.212609188621679, -7.356319397003395, 
    63.528208163325345`}, {7.918582570394864, -14.701652574892513`, 
    68.45685485870605}, {6.26879687420785, -14.984613424262063`, 
    66.31510009395507}, {5.838691677797813, -7.443419100191418, 
    61.40908384455828}}], 
   Polygon3DBox[{{5.838691677797813, -7.443419100191418, 61.40908384455828}, {
    6.26879687420785, -14.984613424262063`, 66.31510009395507}, {
    4.747436754168276, -15.092671277179544`, 64.41235300886505}, {
    4.598306483831555, -7.393786630982394, 59.4477163271094}}], 
   Polygon3DBox[{{4.598306483831555, -7.393786630982394, 59.4477163271094}, {
    4.747436754168276, -15.092671277179544`, 64.41235300886505}, {
    3.3465976609530177`, -15.088637416947847`, 62.725403289607804`}, {
    3.4727120190011065`, -7.263671250194934, 57.60872187763264}}], 
   Polygon3DBox[{{3.4727120190011065`, -7.263671250194934, 
    57.60872187763264}, {3.3465976609530177`, -15.088637416947847`, 
    62.725403289607804`}, {2.05552038989166, -15.018731245238278`, 
    61.22860130739683}, {2.4431768696253906`, -7.093980016773761, 
    55.85584715864569}}], 
   Polygon3DBox[{{2.4431768696253906`, -7.093980016773761, 
    55.85584715864569}, {2.05552038989166, -15.018731245238278`, 
    61.22860130739683}, {0.8618735354890084, -14.916676281730783`, 
    59.896883892608216`}, {1.4921240345730216`, -6.91709903689402, 
    54.15386340856762}}], 
   Polygon3DBox[{{1.4921240345730216`, -6.91709903689402, 
    54.15386340856762}, {0.8618735354890084, -14.916676281730783`, 
    59.896883892608216`}, {-0.24743968707089747`, -14.807188349389667`, 
    58.70739103172532}, {0.6034750065745661, -6.762894154039191, 
    52.46948015836863}}], 
   Polygon3DBox[{{0.6034750065745661, -6.762894154039191, 
    52.46948015836863}, {-0.24743968707089747`, -14.807188349389667`, 
    58.70739103172532}, {-1.2858147149128836`, -14.70884987018311, 
    57.64030312609082}, {-0.23774702614579746`, -6.664581868581148, 
    50.77239454070263}}], 
   Polygon3DBox[{{-0.23774702614579746`, -6.664581868581148, 
    50.77239454070263}, {-1.2858147149128836`, -14.70884987018311, 
    57.64030312609082}, {-2.266713669709881, -14.63647851710929, 
    56.67934580397126}, {-1.0467789056002692`, -6.665210632017653, 
    49.03768184029957}}], 
   Polygon3DBox[{{-1.0467789056002692`, -6.665210632017653, 
    49.03768184029957}, {-2.266713669709881, -14.63647851710929, 
    56.67934580397126}, {-3.2035793688521497`, -14.603128215479428`, 
    55.81230537629662}, {-1.8419368601660928`, -6.825319699000542, 
    47.251394369462496`}}], 
   Polygon3DBox[{{-1.8419368601660928`, -6.825319699000542, 
    47.251394369462496`}, {-3.2035793688521497`, -14.603128215479428`, 
    55.81230537629662}, {-4.109794470219282, -14.621828978074316`, 
    55.03186892329714}, {-2.6493589670449023`, -7.231341702393221, 
    45.4226233894201}}], 
   Polygon3DBox[{{-2.6493589670449023`, -7.231341702393221, 
    45.4226233894201}, {-4.109794470219282, -14.621828978074316`, 
    55.03186892329714}, {-4.998511790025532, -14.707044473497776`, 
    54.33712716267568}, {-3.508615096818469, -8.000132527428065, 
    43.60687776643703}}], 
   Polygon3DBox[{{-3.508615096818469, -8.000132527428065, 
    43.60687776643703}, {-4.998511790025532, -14.707044473497776`, 
    54.33712716267568}, {-5.881980609564267, -14.87546592027826, 
    53.73605286249325}, {-4.4719044894976285`, -9.2613586249427, 
    41.94165810023179}}], 
   Polygon3DBox[{{-4.4719044894976285`, -9.2613586249427, 
    41.94165810023179}, {-5.881980609564267, -14.87546592027826, 
    53.73605286249325}, {-6.769590482594919, -15.1448870198733, 
    53.2487816731651}, {-5.5783082660990875`, -11.078227799270318`, 
    40.66219036412664}}], 
   Polygon3DBox[{{-5.5783082660990875`, -11.078227799270318`, 
    40.66219036412664}, {-6.769590482594919, -15.1448870198733, 
    53.2487816731651}, {-7.663515985417994, -15.52845983136129, 
    52.909440609191314`}, {-6.8035556826240455`, -13.323771496897514`, 
    40.0041235475539}}], 
   Polygon3DBox[{{-6.8035556826240455`, -13.323771496897514`, 
    40.0041235475539}, {-7.663515985417994, -15.52845983136129, 
    52.909440609191314`}, {-8.552414423276705, -16.022015184896876`, 
    52.75969845130735}, {-8.064720149403758, -15.717019904491575`, 
    40.02453710950524}}], 
   Polygon3DBox[{{-8.064720149403758, -15.717019904491575`, 
    40.02453710950524}, {-8.552414423276705, -16.022015184896876`, 
    52.75969845130735}, {-9.410033849269912, -16.591625875110427`, 
    52.82725945710267}, {-9.292526937061375, -18.02789762000172, 
    40.60764394705654}}], 
   Polygon3DBox[{{-9.292526937061375, -18.02789762000172, 
    40.60764394705654}, {-9.410033849269912, -16.591625875110427`, 
    52.82725945710267}, {-10.20790120551115, -17.181385275707907`, 
    53.10356688254208}, {-10.457118875977374`, -20.14705111805355, 
    41.604997637636274`}}], 
   Polygon3DBox[{{-10.457118875977374`, -20.14705111805355, 
    41.604997637636274`}, {-10.20790120551115, -17.181385275707907`, 
    53.10356688254208}, {-10.931621821338204`, -17.74039010780519, 
    53.54952784214625}, {-11.55141053832335, -22.037603169257896`, 
    42.900899172335635`}}], 
   Polygon3DBox[{{-11.55141053832335, -22.037603169257896`, 
    42.900899172335635`}, {-10.931621821338204`, -17.74039010780519, 
    53.54952784214625}, {-11.582147219336951`, -18.238214691046505`, 
    54.120043747965916`}, {-12.577044196518738`, -23.692981486277038`, 
    44.41509029259338}}], 
   Polygon3DBox[{{-12.577044196518738`, -23.692981486277038`, 
    44.41509029259338}, {-11.582147219336951`, -18.238214691046505`, 
    54.120043747965916`}, {-12.167614037623752`, -18.661527984815837`, 
    54.77877919459838}, {-13.538357126442701`, -25.117541972554946`, 
    46.092618065366516`}}], 
   Polygon3DBox[{{-13.538357126442701`, -25.117541972554946`, 
    46.092618065366516`}, {-12.167614037623752`, -18.661527984815837`, 
    54.77877919459838}, {-12.69729110803937, -19.00613977727747, 
    55.50019226578677}, {-14.440112667872482`, -26.318625749429888`, 
    47.89527081387469}}], 
   Polygon3DBox[{{-14.440112667872482`, -26.318625749429888`, 
    47.89527081387469}, {-12.69729110803937, -19.00613977727747, 
    55.50019226578677}, {-13.179237255399308`, -19.27162628801237, 
    56.267057531786385`}, {-15.28662978757628, -27.303229333523266`, 
    49.79580648369985}}], 
   Polygon3DBox[{{-15.28662978757628, -27.303229333523266`, 
    49.79580648369985}, {-13.179237255399308`, -19.27162628801237, 
    56.267057531786385`}, {-13.61978072027944, -19.45857511209049, 
    57.06772666299297}, {-16.081416091858816`, -28.07654333746726, 
    51.774108653842305`}}]}]], "Output",
 CellChangeTimes->{3.483842290765625*^9}]
}, Open  ]],

Cell["\<\
Continue the innermost path, and check how many turns it makes:\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{3.42092348371875*^9},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1a", "=", 
   RowBox[{
    RowBox[{"tr", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
    "\[LeftDoubleBracket]", 
    RowBox[{"nt", "+", "1"}], "\[RightDoubleBracket]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"p1b", "=", 
   RowBox[{
    RowBox[{"tr", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
    "\[LeftDoubleBracket]", 
    RowBox[{"nt", "+", "1"}], "\[RightDoubleBracket]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"dt", "=", "0.02`"}], ";"}], "\n", 
 RowBox[{"gb", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"line", "[", 
    RowBox[{"trace", "[", 
     RowBox[{"U", ",", "p1b", ",", "dt", ",", "150"}], "]"}], "]"}], 
   "]"}]}]}], "Input",
 PageBreakAbove->False,
 CellChangeTimes->{3.42092348371875*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[
  {Thickness[0.001], Line3DBox[CompressedData["
1:eJwNVnc8FQoUNiPryczIuua93OEi+x4yrnG5VyX1IhSRkUqFvFBmSJ6MjDIa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    "]]}]], "Output",
 CellChangeTimes->{3.483842290875*^9}]
}, Open  ]],

Cell["It makes 2 and a half turn.  Try the outer path:", "Text",
 Evaluatable->False,
 CellChangeTimes->{3.42092348371875*^9},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"line", "[", 
   RowBox[{"trace", "[", 
    RowBox[{"U", ",", "p1a", ",", "dt", ",", "70"}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{3.42092348371875*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[
  {Thickness[0.001], Line3DBox[CompressedData["
1:eJwNlGs81PkChxEOhhaZJJdEDMbIfxBG5TuM+4wZjEvaRuiiNqlVKgqFIpft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    "]]}]], "Output",
 CellChangeTimes->{3.4838422909375*^9}]
}, Open  ]],

Cell["\<\
It makes only a half turn.  Thus there are two dividing lines in between, \
where the winding number changes from 1/2 to 3/2, and to 5/2.  By \
trial-and-error, it turns out that these paths start at 13%,  and 35% of the \
distance between the inntermost and outermost endpoint.\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.420923449578125*^9, 3.42092345209375*^9}, 
   3.420923483734375*^9},
 AspectRatioFixed->True],

Cell["Here are three paths, all close to the division lines.", "Text",
 Evaluatable->False,
 PageBreakBelow->False,
 CellChangeTimes->{3.420923483734375*^9},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"div", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0.13`", ",", "0.35`", ",", "1"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"nt2", "=", 
   RowBox[{"{", 
    RowBox[{"57", ",", "37", ",", "18", ",", "18"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"dt", "=", "0.05`"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"nt", "=", 
      RowBox[{"nt2", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}],
      ";", 
     RowBox[{"p2", "=", 
      RowBox[{
       RowBox[{"p1a", " ", 
        RowBox[{
        "div", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], "+", 
       
       RowBox[{"p1b", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
          "div", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
         ")"}]}]}]}], ";", 
     RowBox[{"Print", "[", 
      RowBox[{"Show", "[", 
       RowBox[{"line", "[", 
        RowBox[{"trace", "[", 
         RowBox[{"U", ",", "p2", ",", "dt", ",", "nt"}], "]"}], "]"}], "]"}], 
      "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{3.420923483734375*^9},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 Graphics3DBox[
  {Thickness[0.001], Line3DBox[CompressedData["
1:eJwN1Gk4FAgYwHGN7ErkmkaHa8ZgMsaMceSKN4xjjLmoKJRI8millYSiNKGk
rBJ5VOOoyEYHSZhX0pbtWEqHaY3r6RjP7libcrRsH37f/p//5O1J4h0ENTU1
t+/Uv/M+q/k+ZB0dGawmxo59DnhBsNv3Wh4PbANJp/LpDAw+k+LDP+OAQju3
hNTyYIhIaa9KqbVDaZDsJIHhgMyywPqsm3x4tfTZxbhmJgpkv6fRndlY3F8V
LukUQJ9lusNvxiz0uyzfmFnFQuu+nv6hcCG09Sm7Vi9mIZbHDSX+Y4tEztgC
3hJC9SXzz7xZOwTXi6fePbHGbEepsv6tEDZ4BOSOEhm4Jmvz56gGCjpQzz2v
6BBC196fNnFrbHDVocJosZYJjh/40E5OEEKSmgkhgkjD1sfq2lOpRqgISdo5
PCaApoXnMXNXLVFzrWkD4QARRxsmD+n08+HF0YHWvUcs8I6k/E5bqSGmEKsn
x5uDgfSQvJnbSEZr3Ufi1xIi5kgbdb8U8qA33/hhYIA5toXfArarEd6cTsrp
iAgC5U4LWvaEKeaP16+/STDG+c4BVZ4FF9aqaPuW2ZlhSodG4PAzMh6NyV5e
Mh0AUWVf/g2ikNGsrKLSPcsa25aFNTmZB8D81T4dVxcq1n6SBFdV2WHXzJKe
OGIAhCrKZnJ7rDEj6O9fqzPYaKAV31WtDICZTU2RwmkbrHveGUypcsTdFdZ1
PzpzwWM3o/JlNQPlBV9zRt85ITkyWZTfGATbZir17//JxJo5yzs+/s5I7y6Q
o2cwHBfQv2m8ZGHFwYuefOX33ih0V0EfH7ZoaBNup9vj/opPzl33HFE38iHt
HUMIKg61N/YPe0wIYF3eUc/GKYrmBXeFEJrXJ1IlLfaYXsMrf3eYifaqwXba
ThFQxPL8lSR7vHlgKetEIg05BPXlHnUiCMmgLsADJjqHevvH0clYKmLPh58V
QebDHZ/lWbZ4e1C1x0WfhNolr1+F2IngJUmY6DtIQx9HgoWT4VK0qfXzXV4k
hARh1tcYniXyeleFfcxehBNOZGX5LQHkXC10WvMDBeUnLid0rvgm6xa2y0uY
fAi6HT+8LMQUPXkDI+GKeRkjYhe9vYIHRH23xutXVmJz5Ln9/Us0cMYnmhE1
w4WsjKmsgjQSnn5Dm3pA0sVF5Sd1fNwDoXOLzVyndDnKR203DFUaIQ55ipvj
/SE+hNnIvbsC10nXxDw6TsGC7k18UxkHevoeaFg1m6OeR2yyqx0DfVpc6KuI
HLherIrWEFmhYu5gGUfPEWV1NncLDP1gImjc6dwaOs6lPDuerliLGY4sEnvK
H9RVwWODNCbm2d8bFlm5IYVzdLWEzoUUr+jdo+72uOda2OCMmTtGbh0pOibh
gXT43pn+YjamJucdqVC44ZtcPeqkkg9jHVu71pU4oG8bK61miyv2pB9UmUmF
4O7yFuQMR9x+2y7j0hFnfHpFvyrzhghGFu+ZXeHiiH/d99WNiGSjc0qky51c
MXAk0vvXCx3wY/eTiZYDNhjlWUnLnheDeXYhtcWEjfHBc2aRm8xwodL0seas
GKi5louTZpg4MmLY0JaniUOpVt+6M8WQnhX2/JvcBtP0CEY3Yge8nn5Idk2s
FQHJtslyY7olhsX90qloVQdPp8zDI3VC8A17T9zubY717SYvSs5owQ3Kur5S
NwFsPHn2i/gDCS0GQncxf9aCOB2N/vsG3z9WoOx9rdTGVv9rw0WtGlD6wKsh
t48Lhw5u1FbFzsvObi5+VBX/n9eTS4LMtZsDoE7hdrXo2HtZWu/ltwYrJ7xy
e0fO+x3iAGvW4LR0tF52Xjj9pNZz1CtTGq3LJ3uDbntFh0TwxstvG7dF5Tfp
ZbyaSjXa4AH/Aw7vkrQ=
    "]]}]], "Print",
 CellChangeTimes->{3.483842290984375*^9}],

Cell[BoxData[
 Graphics3DBox[
  {Thickness[0.001], Line3DBox[CompressedData["
1:eJwBoQNe/CFib1JlAgAAACYAAAADAAAADo/7zUIhLMAGB+IHvbs1wGQ3gih1
ektAvqYG9hGvLsCNPngb+0E2wHIxF5cj/kxAfW5pBjRbMMAWiSpfHQU2wC7l
j8mgik5AuNlf3l4cMcCwv8ZG4f00wBNJlBtICFBAs22/c6mNMcDDBtC4uxwz
wCpuYf+Zu1BAtT/qz8qVMcCXKm5b218wwLi0LPL5SlFAqDpZOakXMcCJ1MNt
JespwOvwy7+0m1FAe8sRUqQGMMCm32O71K4iwDmo+xjil1FABaDjQdb7LMCi
/bUWi6gYwHVb19nLP1FA0oPn/vJ0KcAVbajZFPkOwEB0PHY+rFBAgFqaMc7s
JcDDDRm4yy0EwPTRkDcR9U9Alft2gFenIsDzK8DKPmX/v3sIBsa4eE5Aavis
YKqKH8AC0PPPhzMAwB23eNWI7kxAfuWogzzDGsDAzEVkN/MEwLXQO/OgU0tA
8NYNr1ZXF8DL+s+XDwQOwJQp018AoUlAY5ubhdEFFsBpmlyGNl0WwG7Z0e9x
2EdAK/T4OCg1GMAoaAAvQDkhwC36V9cVJ0ZAEKbFxQm2H8AlnYHUCwArwG9s
U1rbPEVAxhbk0ydWJcDchKfaFgszwFWDwVOc8UVAzS8vAFZFKsAYFMQccxY3
wByup1anrkdAc02ACz1ZLsBJUIFRC5Q5wLTfDllEz0lAtCfoY8zcMMDQ1Dz0
fsM6wIZxUWEHGUxAVetm9zk+MsBaeLF1n746wIhaHasjck5A8PXEqcJNM8A5
i00nEYA5wG4DHVyWYVBAXFtSNEX5M8AK9y3szPU2wDjex6cSdFFAZY4xOqsg
NMD5mRS/rB8zwK++NThCVFJAc01eD3GdM8BeK7eCWHcswIIUb8/I3VJAhU2J
KFNWMsBd8+GRLtIhwKGZFIGg8VJArJtMZKJZMMAekWMDXi0QwL5bCPNKi1JA
s5jTm+bGK8CAvcTJeRPXv9V8WqkjyFFAFtilBTyAJsB+PH0coJr+P8tg80cH
01BA5+5VjDZVIcD4M5MdhKIHQFigJsBPlk9AA/7Q87gVGcB5HSwlfJ0IQAIv
i3XBeE1ATneOv9KbEMAnQapErpQEQM8ALV6zRktAMEpcPS1DA8BCJ45Omzj7
P7LQ1jEG5UhACardphvE8r/Wgxf7VlrnP7ipSIbbK0ZAUTy2KW8z4r9kO9U4
02vAv6+M2Xbc80JAlhvowF5G5r/I8aicXk3zvyEqboEoUj5AcGWvrw==
    "]]}]], "Print",
 CellChangeTimes->{3.483842291015625*^9}],

Cell[BoxData[
 Graphics3DBox[
  {Thickness[0.001], Line3DBox[CompressedData["
1:eJwB2QEm/iFib1JlAgAAABMAAAADAAAAjITlff6iLcAU1fICPpU5wGQOCEgt
sUlAuoP+hN+aMMA+/7uIKtQ6wJ2+zIJi+ktALlD2+EUNMsCN1ddhjt06wAox
4mxTVE5AzepIlzgqM8BrqR3Bwq05wHaxF1rTU1BALeT7+BXiM8DZC2Ax5zI3
wNTIGA6faFFAjWxMWUUWNMD7O9sl3GozwO/i2vHYTFJAegq4SqygM8ACLhpq
DB4twF54v7VY3FJAIjr2EsxmMsAmmKnFeHIiwIsrJN4691JA2EWwcVR0MMBn
+cxomi4RwGl68scLl1JAF9rKSMMGLMAQVgILU77gv9Yp/MaS11FAUOnno03B
JsBSQGXH9Vv9P3+C9y7B41BA5awCd6GRIcCeHOJMM4oHQCaqaerPt09Axlyd
vvB+GcDSBQnXIOQIQC2ZFbTomU1AmPaNqYPwEMCID6XG4RoFQP+ZjHyAaEtA
HNGb35O1A8DWDSpDVpP8P91mUNVOCUlAWVEetSMS87/ZkMNHgnHqP2jcXWi4
VEZAxtaxq5Ey4b8AesBKn+Vev3izwW2PIkNA0gHfJQD84b/kPjVrTa3sv00c
3+kVuD5A6CfG0LnKAsCyymgJnFIVwDezTfUJdDZAsmbilg==
    "]]}]], "Print",
 CellChangeTimes->{3.483842291078125*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Here is  a procedure for tracing out each of the three different kinds of \
strips that the original strip splits into.\
\>", "Text",
 Evaluatable->False,
 PageBreakAbove->True,
 CellChangeTimes->{3.420923483734375*^9},
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "strip", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"strip", "[", 
    RowBox[{"i_", ",", "n_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p2a", ",", "p2b", ",", "p3a", ",", "p3b"}], "}"}], ",", 
     RowBox[{
      RowBox[{"p2a", "=", 
       RowBox[{
        RowBox[{"p1a", " ", 
         RowBox[{
         "div", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], "+", 
        RowBox[{"p1b", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{
           "div", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
          ")"}]}]}]}], ";", 
      RowBox[{"p2b", "=", 
       RowBox[{
        RowBox[{"p1a", " ", 
         RowBox[{"div", "\[LeftDoubleBracket]", 
          RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}]}], "+", 
        RowBox[{"p1b", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"div", "\[LeftDoubleBracket]", 
            RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}]}], ")"}]}]}]}],
       ";", 
      RowBox[{"p3a", "=", 
       RowBox[{
        RowBox[{"p2a", " ", "cut"}], "+", 
        RowBox[{"p2b", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "cut"}], ")"}]}]}]}], ";", 
      RowBox[{"p3b", "=", 
       RowBox[{
        RowBox[{"p2b", " ", "cut"}], "+", 
        RowBox[{"p2a", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "cut"}], ")"}]}]}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"trace", "[", 
         RowBox[{"U", ",", "p3a", ",", "dt", ",", "n"}], "]"}], ",", 
        RowBox[{"trace", "[", 
         RowBox[{"U", ",", "p3b", ",", "dt", ",", "n"}], "]"}]}], "}"}]}]}], 
    "]"}]}], ";"}]}], "Input",
 PageBreakWithin->Automatic,
 CellChangeTimes->{3.420923483734375*^9},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"polygons", "[", 
   RowBox[{"strip", "[", 
    RowBox[{"1", ",", "55"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.420923483734375*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[{
   Polygon3DBox[{{-14.0427036996244, -21.61961423004639, 
    55.06225169951613}, {-13.642039824455491`, -19.572314013035538`, 
    56.962175349125765`}, {-14.622946981691378`, -19.712842946533428`, 
    59.152223886339776`}, {-15.304220146716073`, -22.123398711257693`, 
    58.04621104962267}}], 
   Polygon3DBox[{{-15.304220146716073`, -22.123398711257693`, 
    58.04621104962267}, {-14.622946981691378`, -19.712842946533428`, 
    59.152223886339776`}, {-15.382511677326843`, -19.317953928283007`, 
    61.37727142709593}, {-16.305345773321374`, -21.87753011789724, 
    61.09721357101996}}], 
   Polygon3DBox[{{-16.305345773321374`, -21.87753011789724, 
    61.09721357101996}, {-15.382511677326843`, -19.317953928283007`, 
    61.37727142709593}, {-15.919703423822801`, -18.35151311373025, 
    63.540728218566905`}, {-17.048811156704524`, -20.853217090995244`, 
    64.09675966837933}}], 
   Polygon3DBox[{{-17.048811156704524`, -20.853217090995244`, 
    64.09675966837933}, {-15.919703423822801`, -18.35151311373025, 
    63.540728218566905`}, {-16.185914136483806`, -16.764558028691653`, 
    65.47923648959991}, {-17.482598973273518`, -18.9901827314441, 
    66.85349540930213}}], 
   Polygon3DBox[{{-17.482598973273518`, -18.9901827314441, 
    66.85349540930213}, {-16.185914136483806`, -16.764558028691653`, 
    65.47923648959991}, {-16.096835991997537`, -14.569938364115238`, 
    66.92718303917589}, {-17.50862488364626, -16.281880164295192`, 
    69.05328746909258}}], 
   Polygon3DBox[{{-17.50862488364626, -16.281880164295192`, 
    69.05328746909258}, {-16.096835991997537`, -14.569938364115238`, 
    66.92718303917589}, {-15.57182943895255, -11.95591546556416, 
    67.55577403489897}, {-17.014582958125438`, -12.908853460689558`, 
    70.28337627609467}}], 
   Polygon3DBox[{{-17.014582958125438`, -12.908853460689558`, 
    70.28337627609467}, {-15.57182943895255, -11.95591546556416, 
    67.55577403489897}, {-14.616963383400655`, -9.343369836528014, 
    67.15273371284128}, {-15.953414252296119`, -9.34272140185174, 
    70.20711189072155}}], 
   Polygon3DBox[{{-15.953414252296119`, -9.34272140185174, 
    70.20711189072155}, {-14.616963383400655`, -9.343369836528014, 
    67.15273371284128}, {-13.381163166782713`, -7.2046193559370995`, 
    65.8293394732571}, {-14.4334804287456, -6.219177434590593, 
    68.83356122760165}}], 
   Polygon3DBox[{{-14.4334804287456, -6.219177434590593, 
    68.83356122760165}, {-13.381163166782713`, -7.2046193559370995`, 
    65.8293394732571}, {-12.072400271511803`, -5.7655534597267, 
    63.93608365796769}, {-12.692453856908498`, -3.9707740023392692`, 
    66.54888176958656}}], 
   Polygon3DBox[{{-12.692453856908498`, -3.9707740023392692`, 
    66.54888176958656}, {-12.072400271511803`, -5.7655534597267, 
    63.93608365796769}, {-10.83436484912911, -4.987662731729565, 
    61.77876453141051}, {-10.953718916452434`, -2.6515903304343147`, 
    63.80386903834026}}], 
   Polygon3DBox[{{-10.953718916452434`, -2.6515903304343147`, 
    63.80386903834026}, {-10.83436484912911, -4.987662731729565, 
    61.77876453141051}, {-9.731502677660718, -4.75129161913573, 
    59.50569301634275}, {-9.346345966027332, -2.1081891989819255`, 
    60.86824770785964}}], 
   Polygon3DBox[{{-9.346345966027332, -2.1081891989819255`, 
    60.86824770785964}, {-9.731502677660718, -4.75129161913573, 
    59.50569301634275}, {-8.795347280473862, -4.973691553861737, 
    57.15398172703246}, {-7.932289117533192, -2.1789405735976475`, 
    57.825698350942424`}}], 
   Polygon3DBox[{{-7.932289117533192, -2.1789405735976475`, 
    57.825698350942424`}, {-8.795347280473862, -4.973691553861737, 
    57.15398172703246}, {-8.068570140573575, -5.644237321939491, 
    54.71909740172301}, {-6.763169906180384, -2.776302427322744, 
    54.65455571843257}}], 
   Polygon3DBox[{{-6.763169906180384, -2.776302427322744, 
    54.65455571843257}, {-8.068570140573575, -5.644237321939491, 
    54.71909740172301}, {-7.640652869671166, -6.8387279417837705`, 
    52.222494211852776`}, {-5.931443309740135, -3.9140316369074983`, 
    51.30424223009929}}], 
   Polygon3DBox[{{-5.931443309740135, -3.9140316369074983`, 
    51.30424223009929}, {-7.640652869671166, -6.8387279417837705`, 
    52.222494211852776`}, {-7.682439852468793, -8.741962849438998, 
    49.823172493385485`}, {-5.6230900476203844`, -5.762029901096486, 
    47.79715815910673}}], 
   Polygon3DBox[{{-5.6230900476203844`, -5.762029901096486, 
    47.79715815910673}, {-7.682439852468793, -8.741962849438998, 
    49.823172493385485`}, {-8.44636604387368, -11.608351057808125`, 
    48.05026275771807}, {-6.184833259757571, -8.789290857353686, 
    44.4995415170617}}], 
   Polygon3DBox[{{-6.184833259757571, -8.789290857353686, 
    44.4995415170617}, {-8.44636604387368, -11.608351057808125`, 
    48.05026275771807}, {-10.00941412607546, -15.255915390978416`, 
    47.888807174926}, {-8.049117821429547, -13.626107638969138`, 
    42.77802682370205}}], 
   Polygon3DBox[{{-8.049117821429547, -13.626107638969138`, 
    42.77802682370205}, {-10.00941412607546, -15.255915390978416`, 
    47.888807174926}, {-11.83790366207085, -18.523591572761443`, 
    49.56052915313042}, {-10.735075364784825`, -19.030553666082888`, 
    44.21750426764232}}], 
   Polygon3DBox[{{-10.735075364784825`, -19.030553666082888`, 
    44.21750426764232}, {-11.83790366207085, -18.523591572761443`, 
    49.56052915313042}, {-13.46732804884096, -20.759088720865318`, 
    52.191982578184565`}, {-13.15327260961259, -22.963376778424998`, 
    47.64716276175773}}], 
   Polygon3DBox[{{-13.15327260961259, -22.963376778424998`, 
    47.64716276175773}, {-13.46732804884096, -20.759088720865318`, 
    52.191982578184565`}, {-14.837290244848534`, -22.039490429331575`, 
    55.20877658073641}, {-15.154355523054756`, -25.380159163946733`, 
    51.83060764797685}}], 
   Polygon3DBox[{{-15.154355523054756`, -25.380159163946733`, 
    51.83060764797685}, {-14.837290244848534`, -22.039490429331575`, 
    55.20877658073641}, {-15.975992995685672`, -22.488374088891646`, 
    58.38668742258363}, {-16.811862837915744`, -26.52043297791917, 
    56.32574734386495}}], 
   Polygon3DBox[{{-16.811862837915744`, -26.52043297791917, 
    56.32574734386495}, {-15.975992995685672`, -22.488374088891646`, 
    58.38668742258363}, {-16.89448728543034, -22.14015443754863, 
    61.61154026677983}, {-18.166791082960383`, -26.48088182218792, 
    60.93634116061712}}], 
   Polygon3DBox[{{-18.166791082960383`, -26.48088182218792, 
    60.93634116061712}, {-16.89448728543034, -22.14015443754863, 
    61.61154026677983}, {-17.565630836630312`, -20.955554811312872`, 
    64.75471800596583}, {-19.206026116400782`, -25.239394628560028`, 
    65.48296328381002}}], 
   Polygon3DBox[{{-19.206026116400782`, -25.239394628560028`, 
    65.48296328381002}, {-17.565630836630312`, -20.955554811312872`, 
    64.75471800596583}, {-17.917177667313982`, -18.87415208397147, 
    67.5967511695916}, {-19.858687094157048`, -22.72582309084437, 
    69.68854715450456}}], 
   Polygon3DBox[{{-19.858687094157048`, -22.72582309084437, 
    69.68854715450456}, {-17.917177667313982`, -18.87415208397147, 
    67.5967511695916}, {-17.836706602691052`, -15.912552558839467`, 
    69.7864017726189}, {-20.00004801057481, -18.939873958321744`, 
    73.11704940598291}}], 
   Polygon3DBox[{{-20.00004801057481, -18.939873958321744`, 
    73.11704940598291}, {-17.836706602691052`, -15.912552558839467`, 
    69.7864017726189}, {-17.208562645694652`, -12.307452368110487`, 
    70.88855212251885}, {-19.48114510253462, -14.122299801813046`, 
    75.20776072399467}}], 
   Polygon3DBox[{{-19.48114510253462, -14.122299801813046`, 
    75.20776072399467}, {-17.208562645694652`, -12.307452368110487`, 
    70.88855212251885}, {-16.000749587978873`, -8.598667179145156, 
    70.59386875621281}, {-18.2061058413201, -8.890155089880544, 
    75.48455898481183}}], 
   Polygon3DBox[{{-18.2061058413201, -8.890155089880544, 
    75.48455898481183}, {-16.000749587978873`, -8.598667179145156, 
    70.59386875621281}, {-14.346998095037824`, -5.44468262799935, 
    68.98385116271997}, {-16.234711161766953`, -4.120135870267906, 
    73.88431936116322}}], 
   Polygon3DBox[{{-16.234711161766953`, -4.120135870267906, 
    73.88431936116322}, {-14.346998095037824`, -5.44468262799935, 
    68.98385116271997}, {-12.497132481730116`, -3.2401705912952803`, 
    66.49701729787866}, {-13.80381250159613, -0.521312886617268, 
    70.86519173704956}}], 
   Polygon3DBox[{{-13.80381250159613, -0.521312886617268, 
    70.86519173704956}, {-12.497132481730116`, -3.2401705912952803`, 
    66.49701729787866}, {-10.670146651181039`, -1.994892616168495, 
    63.58627023581353}, {-11.209326750398068`, 1.6916458887787917`, 
    67.08595735288627}}], 
   Polygon3DBox[{{-11.209326750398068`, 1.6916458887787917`, 
    67.08595735288627}, {-10.670146651181039`, -1.994892616168495, 
    63.58627023581353}, {-8.988933612914343, -1.5349001732233924`, 
    60.501895447333766`}, {-8.676501205361028, 2.6992938790187346`, 
    63.02008875657449}}], 
   Polygon3DBox[{{-8.676501205361028, 2.6992938790187346`, 
    63.02008875657449}, {-8.988933612914343, -1.5349001732233924`, 
    60.501895447333766`}, {-7.515003850618612, -1.6934764769910982`, 
    57.308039391752224`}, {-6.335787931917481, 2.806643843253832, 
    58.844333509739286`}}], 
   Polygon3DBox[{{-6.335787931917481, 2.806643843253832, 
    58.844333509739286`}, {-7.515003850618612, -1.6934764769910982`, 
    57.308039391752224`}, {-6.306489049705569, -2.383552716177988, 
    53.966394198540414`}, {-4.272516480760782, 2.2927667006888175`, 
    54.505893141671606`}}], 
   Polygon3DBox[{{-4.272516480760782, 2.2927667006888175`, 
    54.505893141671606`}, {-6.306489049705569, -2.383552716177988, 
    53.966394198540414`}, {-5.470790051313749, -3.6254333034373865`, 
    50.41296342507679}, {-2.5861114494301036`, 1.3960325180719424`, 
    49.800457532212754`}}], 
   Polygon3DBox[{{-2.5861114494301036`, 1.3960325180719424`, 
    49.800457532212754`}, {-5.470790051313749, -3.6254333034373865`, 
    50.41296342507679}, {-5.222095665419603, -5.621436475571414, 
    46.672470613089025`}, {-1.4207316437938473`, 0.33623383758013015`, 
    44.43323793862768}}], 
   Polygon3DBox[{{-1.4207316437938473`, 0.33623383758013015`, 
    44.43323793862768}, {-5.222095665419603, -5.621436475571414, 
    46.672470613089025`}, {-5.961639703840698, -8.956077361311653, 
    43.19411491589203}, {-0.9462752455557878, -0.8073050862948286, 
    38.1263568986753}}], 
   Polygon3DBox[{{-0.9462752455557878, -0.8073050862948286, 
    38.1263568986753}, {-5.961639703840698, -8.956077361311653, 
    43.19411491589203}, {-8.154145044641862, -14.364484675807802`, 
    41.663507355593964`}, {-1.5058125604713157`, -2.9421689907359414`, 
    30.84925227297757}}], 
   Polygon3DBox[{{-1.5058125604713157`, -2.9421689907359414`, 
    30.84925227297757}, {-8.154145044641862, -14.364484675807802`, 
    41.663507355593964`}, {-11.04664578150075, -20.07205521389637, 
    43.618824195263905`}, {-5.738770078590662, -13.450516061070113`, 
    25.507508610836155`}}], 
   Polygon3DBox[{{-5.738770078590662, -13.450516061070113`, 
    25.507508610836155`}, {-11.04664578150075, -20.07205521389637, 
    43.618824195263905`}, {-13.545988415170738`, -24.06037011145307, 
    47.45582168174891}, {-11.76493940669038, -27.046956509072483`, 
    30.888923022970705`}}], 
   Polygon3DBox[{{-11.76493940669038, -27.046956509072483`, 
    30.888923022970705`}, {-13.545988415170738`, -24.06037011145307, 
    47.45582168174891}, {-15.603790346416048`, -26.45661378961682, 
    51.990966451273366`}, {-15.788467985158306`, -34.51533073651692, 
    38.7273211701957}}], 
   Polygon3DBox[{{-15.788467985158306`, -34.51533073651692, 
    38.7273211701957}, {-15.603790346416048`, -26.45661378961682, 
    51.990966451273366`}, {-17.30634619527446, -27.506641588806065`, 
    56.820289774858765`}, {-19.02683755361358, -38.825577396804626`, 
    47.516363555129665`}}], 
   Polygon3DBox[{{-19.02683755361358, -38.825577396804626`, 
    47.516363555129665`}, {-17.30634619527446, -27.506641588806065`, 
    56.820289774858765`}, {-18.690861823984513`, -27.292119775577852`, 
    61.74627001601664}, {-21.698885300627605`, -40.48549835431089, 
    56.75862732040907}}], 
   Polygon3DBox[{{-21.698885300627605`, -40.48549835431089, 
    56.75862732040907}, {-18.690861823984513`, -27.292119775577852`, 
    61.74627001601664}, {-19.735350641002846`, -25.777586961712124`, 
    66.56446409349198}, {-23.849536552256563`, -39.58522454346117, 
    66.05498815210044}}], 
   Polygon3DBox[{{-23.849536552256563`, -39.58522454346117, 
    66.05498815210044}, {-19.735350641002846`, -25.777586961712124`, 
    66.56446409349198}, {-20.357235374450937`, -22.894174938273938`, 
    70.95328066199723}, {-25.42169221583767, -36.069549022255785`, 
    74.88632352904877}}], 
   Polygon3DBox[{{-25.42169221583767, -36.069549022255785`, 
    74.88632352904877}, {-20.357235374450937`, -22.894174938273938`, 
    70.95328066199723}, {-20.420688878352408`, -18.674569377347442`, 
    74.42288967691512}, {-26.276605832921884`, -29.94783325195169, 
    82.507627437136}}], 
   Polygon3DBox[{{-26.276605832921884`, -29.94783325195169, 
    82.507627437136}, {-20.420688878352408`, -18.674569377347442`, 
    74.42288967691512}, {-19.773511642671895`, -13.435099995051768`, 
    76.3785027321932}, {-26.22193541604512, -21.546550507518727`, 
    87.97663988239113}}], 
   Polygon3DBox[{{-26.22193541604512, -21.546550507518727`, 
    87.97663988239113}, {-19.773511642671895`, -13.435099995051768`, 
    76.3785027321932}, {-18.332321348425733`, -7.888079467743552, 
    76.36964545141889}, {-25.071757487280504`, -11.72956626769401, 
    90.39588769524512}}], 
   Polygon3DBox[{{-25.071757487280504`, -11.72956626769401, 
    90.39588769524512}, {-18.332321348425733`, -7.888079467743552, 
    76.36964545141889}, {-16.1814006880387, -2.9625993281768492`, 
    74.42031561069359}, {-22.736388633210414`, -1.8761780985275287`, 
    89.34076522087487}}], 
   Polygon3DBox[{{-22.736388633210414`, -1.8761780985275287`, 
    89.34076522087487}, {-16.1814006880387, -2.9625993281768492`, 
    74.42031561069359}, {-13.576143346284454`, 0.6554782340050038, 
    71.07337483126148}, {-19.293720520776837`, 6.533257193724312, 
    85.19198229164033}}], 
   Polygon3DBox[{{-19.293720520776837`, 6.533257193724312, 
    85.19198229164033}, {-13.576143346284454`, 0.6554782340050038, 
    71.07337483126148}, {-10.81632080150496, 2.8076832797588844`, 
    67.0187723715843}, {-14.977084411093452`, 12.50316095978037, 
    79.02435733288087}}], 
   Polygon3DBox[{{-14.977084411093452`, 12.50316095978037, 
    79.02435733288087}, {-10.81632080150496, 2.8076832797588844`, 
    67.0187723715843}, {-8.125125699321979, 3.7195827230312135`, 
    62.72012930375308}, {-10.078443416314698`, 15.817716031591505`, 
    72.1046958335608}}], 
   Polygon3DBox[{{-10.078443416314698`, 15.817716031591505`, 
    72.1046958335608}, {-8.125125699321979, 3.7195827230312135`, 
    62.72012930375308}, {-5.6333539344418835`, 3.7295413042360206`, 
    58.3278480584963}, {-5.609927622710224, 16.86054431222302, 
    66.35451975215858}}], 
   Polygon3DBox[{{-5.609927622710224, 16.86054431222302, 
    66.35451975215858}, {-5.6333539344418835`, 3.7295413042360206`, 
    58.3278480584963}, {-3.4304257643235054`, 3.159430303368023, 
    53.751244630830804`}, {-1.9287477316831128`, 16.85762046541998, 
    62.17923555641294}}], 
   Polygon3DBox[{{-1.9287477316831128`, 16.85762046541998, 
    62.17923555641294}, {-3.4304257643235054`, 3.159430303368023, 
    53.751244630830804`}, {-1.6163060803882976`, 2.3363503081106214`, 
    48.73060660600241}, {1.1006257586271957`, 16.57867015586105, 
    59.204593747670685`}}], 
   Polygon3DBox[{{1.1006257586271957`, 16.57867015586105, 
    59.204593747670685`}, {-1.6163060803882976`, 2.3363503081106214`, 
    48.73060660600241}, {-0.32693723771791294`, 1.708994092894267, 
    43.127119339995474`}, {3.660496809282835, 16.371589608912604`, 
    57.10636222343546}}]}]], "Output",
 CellChangeTimes->{3.483842291296875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"polygons", "[", 
   RowBox[{"strip", "[", 
    RowBox[{"2", ",", "35"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.420923483734375*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[{
   Polygon3DBox[{{-14.780678614999612`, -25.390496253686045`, 
    51.56281967822659}, {-14.10263205702146, -21.925834347975364`, 
    54.77807508525828}, {-15.405713055997412`, -22.48518121741104, 
    57.882785950738665`}, {-16.542498245920747`, -26.599195908353344`, 
    56.05662171194241}}], 
   Polygon3DBox[{{-16.542498245920747`, -26.599195908353344`, 
    56.05662171194241}, {-15.405713055997412`, -22.48518121741104, 
    57.882785950738665`}, {-16.44233145841088, -22.261132614717912`, 
    61.0593017026703}, {-17.968414340510698`, -26.622048354701914`, 
    60.677940856507846`}}], 
   Polygon3DBox[{{-17.968414340510698`, -26.622048354701914`, 
    60.677940856507846`}, {-16.44233145841088, -22.261132614717912`, 
    61.0593017026703}, {-17.21559241259117, -21.226060909733018`, 
    64.18499710165365}, {-19.064271409133287`, -25.44411930499983, 
    65.2478970532768}}], 
   Polygon3DBox[{{-19.064271409133287`, -25.44411930499983, 
    65.2478970532768}, {-17.21559241259117, -21.226060909733018`, 
    64.18499710165365}, {-17.67285340082686, -19.3185368997325, 
    67.06321869986414}, {-19.76947557177308, -22.995828808574423`, 
    69.49675530931472}}], 
   Polygon3DBox[{{-19.76947557177308, -22.995828808574423`, 
    69.49675530931472}, {-17.67285340082686, -19.3185368997325, 
    67.06321869986414}, {-17.714197502372595`, -16.53061350065913, 
    69.3716564939613}, {-19.965452187830213`, -19.268321717495457`, 
    72.99794946073862}}], 
   Polygon3DBox[{{-19.965452187830213`, -19.268321717495457`, 
    72.99794946073862}, {-17.714197502372595`, -16.53061350065913, 
    69.3716564939613}, {-17.223698547366432`, -13.044072093930232`, 
    70.68565055885692}, {-19.504760058706612`, -14.482602532123554`, 
    75.1938839895343}}], 
   Polygon3DBox[{{-19.504760058706612`, -14.482602532123554`, 
    75.1938839895343}, {-17.223698547366432`, -13.044072093930232`, 
    70.68565055885692}, {-16.14832710692473, -9.339024895279838, 
    70.65353200730684}, {-18.285889108476336`, -9.23251303888548, 
    75.59300449731154}}], 
   Polygon3DBox[{{-18.285889108476336`, -9.23251303888548, 
    75.59300449731154}, {-16.14832710692473, -9.339024895279838, 
    70.65353200730684}, {-14.590636468656937`, -6.072174709992298, 
    69.27233643599077}, {-16.356960432120022`, -4.390159542837851, 
    74.09806759843313}}], 
   Polygon3DBox[{{-16.356960432120022`, -4.390159542837851, 
    74.09806759843313}, {-14.590636468656937`, -6.072174709992298, 
    69.27233643599077}, {-12.789585610357397`, -3.7038982389816435`, 
    66.93172953525689}, {-13.946323938025511`, -0.6906435866724991, 
    71.14035945892442}}], 
   Polygon3DBox[{{-13.946323938025511`, -0.6906435866724991, 
    71.14035945892442}, {-12.789585610357397`, -3.7038982389816435`, 
    66.93172953525689}, {-10.977877235544518`, -2.3037632438569484`, 
    64.10153770484074}, {-11.351758141712807`, 1.6175365164808935`, 
    67.38095597814814}}], 
   Polygon3DBox[{{-11.351758141712807`, 1.6175365164808935`, 
    67.38095597814814}, {-10.977877235544518`, -2.3037632438569484`, 
    64.10153770484074}, {-9.29428404821237, -1.7153655807236374`, 
    61.06970449371914}, {-8.806151522764416, 2.698503908514261, 
    63.313265808081006`}}], 
   Polygon3DBox[{{-8.806151522764416, 2.698503908514261, 
    63.313265808081006`}, {-9.29428404821237, -1.7153655807236374`, 
    61.06970449371914}, {-7.806362411688148, -1.7652280750718417`, 
    57.92779374639874}, {-6.4458710703200675`, 2.8572592459725907`, 
    59.13255675769126}}], 
   Polygon3DBox[{{-6.4458710703200675`, 2.8572592459725907`, 
    59.13255675769126}, {-7.806362411688148, -1.7652280750718417`, 
    57.92779374639874}, {-6.567946119205091, -2.3524896953131336`, 
    54.65198256971497}, {-4.3577007774964525`, 2.3783570597976302`, 
    54.797684308129384`}}], 
   Polygon3DBox[{{-4.3577007774964525`, 2.3783570597976302`, 
    54.797684308129384`}, {-6.567946119205091, -2.3524896953131336`, 
    54.65198256971497}, {-5.672204983277909, -3.477676592523199, 
    51.180511256258825`}, {-2.638592982973778, 1.505481619882923, 
    50.110818291020834`}}], 
   Polygon3DBox[{{-2.638592982973778, 1.505481619882923, 
    50.110818291020834`}, {-5.672204983277909, -3.477676592523199, 
    51.180511256258825`}, {-5.306032501989018, -5.299884595058284, 
    47.51294020754574}, {-1.4280725236708687`, 0.46755488284286084`, 
    44.778063162047566`}}], 
   Polygon3DBox[{{-1.4280725236708687`, 0.46755488284286084`, 
    44.778063162047566`}, {-5.306032501989018, -5.299884595058284, 
    47.51294020754574}, {-5.82459746008651, -8.305122808502052, 
    43.97745279281312}, {-0.886707872779832, -0.6158920652776143, 
    38.5108785496873}}], 
   Polygon3DBox[{{-0.886707872779832, -0.6158920652776143, 
    38.5108785496873}, {-5.82459746008651, -8.305122808502052, 
    43.97745279281312}, {-7.717998695525033, -13.275006703289325`, 
    41.957415790284365`}, {-1.290223047717337, -2.444270753027311, 
    31.22518034252428}}], 
   Polygon3DBox[{{-1.290223047717337, -2.444270753027311, 
    31.22518034252428}, {-7.717998695525033, -13.275006703289325`, 
    41.957415790284365`}, {-10.553126471680635`, -19.059945485463572`, 
    43.318198468657805`}, {-4.879363994763873, -11.40821324637303, 
    24.991866979779118`}}], 
   Polygon3DBox[{{-4.879363994763873, -11.40821324637303, 
    24.991866979779118`}, {-10.553126471680635`, -19.059945485463572`, 
    43.318198468657805`}, {-13.10484915510887, -23.298843051055186`, 
    46.87604612803553}, {-11.48267726204998, -26.598201539917792`, 
    30.04155328427695}}], 
   Polygon3DBox[{{-11.48267726204998, -26.598201539917792`, 
    30.04155328427695}, {-13.10484915510887, -23.298843051055186`, 
    46.87604612803553}, {-15.20859536698773, -25.91782542596441, 
    51.25365877927971}, {-15.614784828506156`, -34.427904008802024`, 
    37.90618573029043}}], 
   Polygon3DBox[{{-15.614784828506156`, -34.427904008802024`, 
    37.90618573029043}, {-15.20859536698773, -25.91782542596441, 
    51.25365877927971}, {-16.949401099446256`, -27.18166981223683, 
    55.9697172761579}, {-18.92676762387794, -38.98613154878077, 
    46.775864305988705`}}], 
   Polygon3DBox[{{-18.92676762387794, -38.98613154878077, 
    46.775864305988705`}, {-16.949401099446256`, -27.18166981223683, 
    55.9697172761579}, {-18.3739201716545, -27.198541093491414`, 
    60.81345567410852}, {-21.659603590609535`, -40.837340248534325`, 
    56.130904977222805`}}], 
   Polygon3DBox[{{-21.659603590609535`, -40.837340248534325`, 
    56.130904977222805`}, {-18.3739201716545, -27.198541093491414`, 
    60.81345567410852}, {-19.471318722340765`, -25.94958237970776, 
    65.5956368718777}, {-23.866249847396706`, -40.089154527954136`, 
    65.56713022431151}}], 
   Polygon3DBox[{{-23.866249847396706`, -40.089154527954136`, 
    65.56713022431151}, {-19.471318722340765`, -25.94958237970776, 
    65.5956368718777}, {-20.17088220401088, -23.363965394832064`, 
    70.02793199537349}, {-25.49471340094154, -36.69007239948919, 
    74.56758934773367}}], 
   Polygon3DBox[{{-25.49471340094154, -36.69007239948919, 
    74.56758934773367}, {-20.17088220401088, -23.363965394832064`, 
    70.02793199537349}, {-20.346239460541312`, -19.440742065053822`, 
    73.65887072681564}, {-26.40979485931131, -30.641316046251557`, 
    82.39066690530164}}], 
   Polygon3DBox[{{-26.40979485931131, -30.641316046251557`, 
    82.39066690530164}, {-20.346239460541312`, -19.440742065053822`, 
    73.65887072681564}, {-19.84448696696038, -14.424570059555622`, 
    75.90757426939508}, {-26.420181517032006`, -22.24987139534352, 
    88.08999937044987}}], 
   Polygon3DBox[{{-26.420181517032006`, -22.24987139534352, 
    88.08999937044987}, {-19.84448696696038, -14.424570059555622`, 
    75.90757426939508}, {-18.562284653708474`, -8.946733832208935, 
    76.27470951917797}, {-25.336353532019025`, -12.356390846378062`, 
    90.74565607121356}}], 
   Polygon3DBox[{{-25.336353532019025`, -12.356390846378062`, 
    90.74565607121356}, {-18.562284653708474`, -8.946733832208935, 
    76.27470951917797}, {-16.54906864818681, -3.915325563278099, 
    74.67816141739146}, {-23.05916856883387, -2.332506557389877, 
    89.88935602753801}}], 
   Polygon3DBox[{{-23.05916856883387, -2.332506557389877, 
    89.88935602753801}, {-16.54906864818681, -3.915325563278099, 
    74.67816141739146}, {-14.035605742457953`, -0.0853055978262236, 
    71.57752974462069}, {-19.653797809851753`, 6.314510120812587, 
    85.85537353196122}}], 
   Polygon3DBox[{{-19.653797809851753`, 6.314510120812587, 
    85.85537353196122}, {-14.035605742457953`, -0.0853055978262236, 
    71.57752974462069}, {-11.32355603806122, 2.2923744553892385`, 
    67.66105202686228}, {-15.343706285502302`, 12.533146363143132`, 
    79.70050081167483}}], 
   Polygon3DBox[{{-15.343706285502302`, 12.533146363143132`, 
    79.70050081167483}, {-11.32355603806122, 2.2923744553892385`, 
    67.66105202686228}, {-8.651703498416557, 3.3927272222002234`, 
    63.4403017799053}, {-10.418088184318032`, 16.05271690067597, 
    72.71461148887231}}], 
   Polygon3DBox[{{-10.418088184318032`, 16.05271690067597, 
    72.71461148887231}, {-8.651703498416557, 3.3927272222002234`, 
    63.4403017799053}, {-6.162299991661452, 3.541263685261469, 
    59.11570003752232}, {-5.863413486391198, 17.21608248764066, 
    66.83496611921532}}], 
   Polygon3DBox[{{-5.863413486391198, 17.21608248764066, 
    66.83496611921532}, {-6.162299991661452, 3.541263685261469, 
    59.11570003752232}, {-3.9462406105722234`, 3.053115381077231, 
    54.63646643377503}, {-2.0921102652718004`, 17.25285602895815, 
    62.56688361798826}}], 
   Polygon3DBox[{{-2.0921102652718004`, 17.25285602895815, 
    62.56688361798826}, {-3.9462406105722234`, 3.053115381077231, 
    54.63646643377503}, {-2.1001868605218164`, 2.22676352202011, 
    49.7782053978897}, {1.0187141689390558`, 16.972812349288162`, 
    59.54586847710426}}], 
   Polygon3DBox[{{1.0187141689390558`, 16.972812349288162`, 
    59.54586847710426}, {-2.1001868605218164`, 2.22676352202011, 
    49.7782053978897}, {-0.7478980471704617, 1.4213113547966574`, 
    44.24309445500312}, {3.6451513130939937`, 16.743796515850498`, 
    57.44335639562211}}]}]], "Output",
 CellChangeTimes->{3.483842291421875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"polygons", "[", 
   RowBox[{"strip", "[", 
    RowBox[{"3", ",", "15"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.42092348375*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[{
   Polygon3DBox[{{-16.93296276494542, -36.38817306044949, 
    41.35681956045175}, {-14.929643389100873`, -26.15167197539521, 
    50.856437808499926`}, {-16.789122913709733`, -27.507642766815135`, 
    55.65969849992229}, {-19.995250083888997`, -39.84497664047133, 
    50.405269370320156`}}], 
   Polygon3DBox[{{-19.995250083888997`, -39.84497664047133, 
    50.405269370320156`}, {-16.789122913709733`, -27.507642766815135`, 
    55.65969849992229}, {-18.29751771279047, -27.585277092532955`, 
    60.60324466776219}, {-22.514920684419927`, -40.68663119019574, 
    59.78306034513888}}], 
   Polygon3DBox[{{-22.514920684419927`, -40.68663119019574, 
    59.78306034513888}, {-18.29751771279047, -27.585277092532955`, 
    60.60324466776219}, {-19.4610772601696, -26.372272381201114`, 
    65.49401900637262}, {-24.5012180867472, -38.93491227575255, 
    69.06553645911598}}], 
   Polygon3DBox[{{-24.5012180867472, -38.93491227575255, 
    69.06553645911598}, {-19.4610772601696, -26.372272381201114`, 
    65.49401900637262}, {-20.217376124709872`, -23.798159097386815`, 
    70.04371277828672}, {-25.868528962827675`, -34.53121792364353, 
    77.66151446199869}}], 
   Polygon3DBox[{{-25.868528962827675`, -34.53121792364353, 
    77.66151446199869}, {-20.217376124709872`, -23.798159097386815`, 
    70.04371277828672}, {-20.444157626743927`, -19.856601231730707`, 
    73.8006588156186}, {-26.45606677029053, -27.560880757058793`, 
    84.74363928391242}}], 
   Polygon3DBox[{{-26.45606677029053, -27.560880757058793`, 
    84.74363928391242}, {-20.444157626743927`, -19.856601231730707`, 
    73.8006588156186}, {-19.988601911095156`, -14.781671992610395`, 
    76.17814164906467}, {-26.064712535271386`, -18.51219577203264, 
    89.34009808736924}}], 
   Polygon3DBox[{{-26.064712535271386`, -18.51219577203264, 
    89.34009808736924}, {-19.988601911095156`, -14.781671992610395`, 
    76.17814164906467}, {-18.74164576066488, -9.195640133633262, 
    76.65853710508146}, {-24.5289493404347, -8.444582699949738, 
    90.65275796957971}}], 
   Polygon3DBox[{{-24.5289493404347, -8.444582699949738, 
    90.65275796957971}, {-18.74164576066488, -9.195640133633262, 
    76.65853710508146}, {-16.74192365206827, -4.015139012683014, 
    75.13124568411678}, {-21.80790496986072, 1.1586679957733423`, 
    88.49822216787469}}], 
   Polygon3DBox[{{-21.80790496986072, 1.1586679957733423`, 
    88.49822216787469}, {-16.74192365206827, -4.015139012683014, 
    75.13124568411678}, {-14.212183520184741`, -0.028493149492121894`, 
    72.03877072393739}, {-18.034998926552145`, 8.907374453331382, 
    83.52385574064405}}], 
   Polygon3DBox[{{-18.034998926552145`, 8.907374453331382, 
    83.52385574064405}, {-14.212183520184741`, -0.028493149492121894`, 
    72.03877072393739}, {-11.456581255731358`, 2.477194477743287, 
    68.08114955593913}, {-13.474083764474495`, 14.043303711137455`, 
    76.93731530732651}}], 
   Polygon3DBox[{{-13.474083764474495`, 14.043303711137455`, 
    76.93731530732651}, {-11.456581255731358`, 2.477194477743287, 
    68.08114955593913}, {-8.723550844553007, 3.6627885327417307`, 
    63.79758154883519}, {-8.476530165190901, 16.568487975344052`, 
    70.05452591920344}}], 
   Polygon3DBox[{{-8.476530165190901, 16.568487975344052`, 
    70.05452591920344}, {-8.723550844553007, 3.6627885327417307`, 
    63.79758154883519}, {-6.163899175809123, 3.8608456927724473`, 
    59.410633530558286`}, {-4.26254254768623, 17.13399582005562, 
    64.86690247386893}}], 
   Polygon3DBox[{{-4.26254254768623, 17.13399582005562, 
    64.86690247386893}, {-6.163899175809123, 3.8608456927724473`, 
    59.410633530558286`}, {-3.8720261960860864`, 3.4038538502118607`, 
    54.87899113872163}, {-0.7978157825770742, 16.978105885709063`, 
    61.14566535413369}}], 
   Polygon3DBox[{{-0.7978157825770742, 16.978105885709063`, 
    61.14566535413369}, {-3.8720261960860864`, 3.4038538502118607`, 
    54.87899113872163}, {-1.9422854132724299`, 2.61731411296286, 
    49.97591338537734}, {2.0752370954063135`, 16.693156535109072`, 
    58.51470629453725}}], 
   Polygon3DBox[{{2.0752370954063135`, 16.693156535109072`, 
    58.51470629453725}, {-1.9422854132724299`, 2.61731411296286, 
    49.97591338537734}, {-0.5201223435587123, 1.9329695996471226`, 
    44.564433345582586`}, {4.538514964613681, 16.545192320750704`, 
    56.695260932242995`}}]}]], "Output",
 CellChangeTimes->{3.483842291484375*^9}]
}, Open  ]],

Cell["\<\
 So, these three strips are what the incoming strip splits (folds) up into.  \
As part of the exercise, you should try to show all four parts together, as a \
visual summary of the topology of the Lorenz attractor. \
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{3.42092348375*^9},
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conclusions", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", with its 3D rendering of lines and polygons,  we arrive at the following \
picture of the Lorenz attractor: \[LineSeparator]\n",
 StyleBox["\[FilledSmallCircle]  ",
  FontFamily->"Symbol"],
 StyleBox["All points above the leaf planes are rapidly attracted to the \
planes.\n\[FilledSmallCircle]  Each plane is generated by a strip that \
matches the spiral path. \n\[FilledSmallCircle]  If the strip is chosen  to \
fit between the outer edge and the dividing line where the path makes one \
more turn then, as it falls off one leaf, it \"covers\" the other leaf.\n\
\[FilledSmallCircle]  The strip is effectively \"split\" into a number (in \
this case four) of strips on the new leaf, where the outermost one makes only \
half a turn around, while the other strips make succesively more trips around \
the leaf before falling off the outer edge.\n\[FilledSmallCircle]  As a strip \
travels around the leaf, it is attracted exponentially onto the surface of \
the leaf, and hence arrives at the outer edge ",
  FontFamily->"Arial",
  FontSize->12],
 StyleBox["under",
  FontFamily->"Arial",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox["  each of the strips that took fewer  turns around the spiral.\n\
\[FilledSmallCircle]  Each time a strip is processed through one of the \
leaves, it is thus split into a number of (here four) layers before it falls \
over the edge and onto the next leaf. \n\[FilledSmallCircle]  After one \
passage over both leaves, the strip has been split N^2 times.\n\
\[FilledSmallCircle]  Thus each surface is covered by infinitely many copies \
of itself.",
  FontFamily->"Arial",
  FontSize->12],
 StyleBox["\n",
  FontFamily->"Times"],
 "\n"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.420923581890625*^9, 3.42092359034375*^9}, {
   3.42092374725*^9, 3.420923751125*^9}, 3.420923861515625*^9, {
   3.420923937734375*^9, 3.42092396921875*^9}, {3.483842400625*^9, 
   3.48384243028125*^9}, {3.483842461140625*^9, 3.4838424926875*^9}},
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowToolbars->"EditBar",
EvaluationCompletionAction->"ShowTiming",
CellGrouping->Automatic,
WindowSize->{958, 674},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingStartingPageNumber->121,
PrintingPageRange->{1, 9999},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"]}, {
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"FacingPages"->True,
"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.563, 842.375}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowSelection->True,
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 107, 2, 29, "Subtitle",
 Evaluatable->False],
Cell[677, 26, 101, 3, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[803, 33, 99, 3, 73, "Section",
 Evaluatable->False,
 PageBreakAbove->True],
Cell[905, 38, 95, 2, 29, "Text",
 Evaluatable->False],
Cell[1003, 42, 463, 17, 81, "Input"],
Cell[1469, 61, 165, 3, 29, "Text",
 Evaluatable->False],
Cell[1637, 66, 553, 19, 40, "Input",
 InitializationCell->True],
Cell[2193, 87, 180, 3, 29, "Text",
 Evaluatable->False],
Cell[2376, 92, 287, 8, 56, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[2700, 105, 76, 2, 73, "Section",
 Evaluatable->False],
Cell[2779, 109, 200, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[3004, 118, 301, 11, 61, "Input"],
Cell[3308, 131, 865, 29, 46, "Output"]
}, Open  ]],
Cell[4188, 163, 239, 6, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4452, 173, 123, 4, 40, "Input",
 PageBreakAbove->False],
Cell[4578, 179, 567, 20, 46, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5194, 205, 118, 2, 73, "Section",
 Evaluatable->False],
Cell[5315, 209, 119, 3, 29, "Text",
 Evaluatable->False,
 PageBreakBelow->False],
Cell[CellGroupData[{
Cell[5459, 216, 392, 13, 40, "Input"],
Cell[5854, 231, 486, 16, 56, "Output"]
}, Open  ]],
Cell[6355, 250, 231, 6, 29, "Text",
 Evaluatable->False,
 PageBreakAbove->False],
Cell[CellGroupData[{
Cell[6611, 260, 300, 9, 40, "Input"],
Cell[6914, 271, 1598, 40, 59, "Output"]
}, Open  ]],
Cell[8527, 314, 190, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[8742, 322, 300, 9, 40, "Input"],
Cell[9045, 333, 1573, 37, 59, "Output"]
}, Open  ]],
Cell[10633, 373, 227, 6, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[10885, 383, 157, 5, 40, "Input"],
Cell[11045, 390, 232, 4, 39, "Output"]
}, Open  ]],
Cell[11292, 397, 199, 6, 29, "Text",
 Evaluatable->False,
 PageBreakBelow->False],
Cell[CellGroupData[{
Cell[11516, 407, 490, 14, 101, "Input"],
Cell[12009, 423, 137, 2, 39, "Output"]
}, Open  ]],
Cell[12161, 428, 197, 6, 29, "Text",
 Evaluatable->False,
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[12383, 438, 112, 3, 40, "Input",
 PageBreakAbove->False],
Cell[12498, 443, 155, 3, 39, "Output"]
}, Open  ]],
Cell[12668, 449, 190, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[12883, 458, 277, 8, 58, "Input"],
Cell[13163, 468, 138, 2, 39, "Output"]
}, Open  ]],
Cell[13316, 473, 247, 6, 29, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[13600, 484, 106, 2, 73, "Section",
 Evaluatable->False],
Cell[13709, 488, 201, 5, 29, "Text",
 Evaluatable->False],
Cell[13913, 495, 2626, 77, 125, "Input",
 InitializationCell->True],
Cell[16542, 574, 132, 4, 29, "Text",
 Evaluatable->False],
Cell[16677, 580, 138, 4, 40, "Input",
 PageBreakAbove->False,
 InitializationCell->True],
Cell[16818, 586, 155, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[16998, 595, 173, 5, 40, "Input",
 PageBreakAbove->False,
 InitializationCell->True],
Cell[17174, 602, 226, 7, 46, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17449, 615, 108, 3, 73, "Section",
 Evaluatable->False,
 PageBreakAbove->True],
Cell[17560, 620, 237, 6, 29, "Text",
 Evaluatable->False],
Cell[17800, 628, 170, 5, 40, "Input",
 InitializationCell->True],
Cell[17973, 635, 430, 12, 47, "Text",
 Evaluatable->False],
Cell[18406, 649, 766, 23, 81, "Input",
 PageBreakAbove->False,
 InitializationCell->True],
Cell[19175, 674, 329, 10, 29, "Text",
 Evaluatable->False,
 PageBreakWithin->False],
Cell[19507, 686, 1384, 42, 81, "Input",
 PageBreakAbove->False,
 InitializationCell->True],
Cell[20894, 730, 205, 5, 29, "Text",
 Evaluatable->False],
Cell[21102, 737, 823, 25, 54, "Input",
 PageBreakAbove->False,
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[21962, 767, 108, 2, 73, "Section",
 Evaluatable->False],
Cell[22073, 771, 253, 7, 29, "Text",
 Evaluatable->False,
 PageBreakAbove->False],
Cell[CellGroupData[{
Cell[22351, 782, 2982, 87, 101, "Input",
 PageBreakAbove->False],
Cell[25336, 871, 13852, 240, 394, "Output"]
}, Open  ]],
Cell[39203, 1114, 153, 5, 70, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[39393, 1124, 87, 2, 70, "Section",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[39505, 1130, 109, 3, 70, "Subsubsection",
 Evaluatable->False,
 PageBreakAbove->False],
Cell[39617, 1135, 171, 5, 70, "Text",
 Evaluatable->False],
Cell[39791, 1142, 1423, 42, 70, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[41251, 1189, 106, 2, 70, "Subsubsection",
 Evaluatable->False],
Cell[41360, 1193, 1954, 57, 70, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[43351, 1255, 122, 3, 70, "Subsubsection",
 Evaluatable->False,
 PageBreakAbove->True],
Cell[43476, 1260, 250, 6, 70, "Text",
 Evaluatable->False],
Cell[43729, 1268, 3437, 96, 70, "Input",
 InitializationCell->True],
Cell[47169, 1366, 177, 4, 70, "Text"],
Cell[CellGroupData[{
Cell[47371, 1374, 277, 8, 70, "Input"],
Cell[47651, 1384, 1782, 31, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[49494, 1422, 99, 2, 70, "Section",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[49618, 1428, 97, 2, 70, "Subsubsection",
 Evaluatable->False],
Cell[49718, 1432, 195, 5, 70, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[49938, 1441, 487, 15, 70, "Input"],
Cell[50428, 1458, 15804, 261, 70, "Output"]
}, Open  ]],
Cell[66247, 1722, 154, 5, 70, "Text",
 Evaluatable->False],
Cell[66404, 1729, 275, 6, 70, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[66716, 1740, 115, 3, 70, "Subsubsection",
 Evaluatable->False,
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[66856, 1747, 142, 4, 70, "Input",
 PageBreakAbove->False],
Cell[67001, 1753, 465, 11, 70, "Output"]
}, Open  ]],
Cell[67481, 1767, 197, 5, 70, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[67703, 1776, 491, 16, 70, "Input",
 PageBreakAbove->False],
Cell[68197, 1794, 2734, 47, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[70992, 1848, 89, 2, 70, "Section",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[71106, 1854, 98, 2, 70, "Subsubsection",
 Evaluatable->False],
Cell[71207, 1858, 243, 6, 70, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[71475, 1868, 376, 12, 70, "Input",
 PageBreakAbove->False],
Cell[71854, 1882, 2726, 47, 70, "Output"]
}, Open  ]],
Cell[74595, 1932, 301, 7, 70, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[74921, 1943, 477, 15, 70, "Input",
 PageBreakAbove->False],
Cell[75401, 1960, 2636, 45, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[78086, 2011, 89, 2, 70, "Subsubsection",
 Evaluatable->False],
Cell[78178, 2015, 197, 5, 70, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[78400, 2024, 663, 21, 70, "Input",
 PageBreakAbove->False],
Cell[79066, 2047, 894, 17, 70, "Output"]
}, Open  ]],
Cell[79975, 2067, 208, 5, 70, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[80208, 2076, 277, 8, 70, "Input"],
Cell[80488, 2086, 88, 1, 70, "Output"]
}, Open  ]],
Cell[80591, 2090, 143, 4, 70, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[80759, 2098, 783, 25, 70, "Input",
 PageBreakAbove->False],
Cell[81545, 2125, 5800, 97, 70, "Output"]
}, Open  ]],
Cell[87360, 2225, 262, 6, 70, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[87659, 2236, 132, 3, 70, "Subsubsection",
 Evaluatable->False],
Cell[87794, 2241, 358, 8, 70, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[88177, 2253, 1148, 34, 70, "Input",
 PageBreakAbove->False],
Cell[89328, 2289, 19153, 320, 70, "Output"]
}, Open  ]],
Cell[108496, 2612, 234, 6, 70, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[108755, 2622, 159, 4, 70, "Input"],
Cell[108917, 2628, 114136, 1899, 70, "Output"]
}, Open  ]],
Cell[223068, 4530, 174, 5, 70, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[223267, 4539, 794, 23, 70, "Input",
 PageBreakAbove->False],
Cell[224064, 4564, 4935, 83, 70, "Output"]
}, Open  ]],
Cell[229014, 4650, 151, 3, 70, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[229190, 4657, 239, 7, 70, "Input"],
Cell[229432, 4666, 2439, 42, 70, "Output"]
}, Open  ]],
Cell[231886, 4711, 439, 9, 70, "Text",
 Evaluatable->False],
Cell[232328, 4722, 182, 4, 70, "Text",
 Evaluatable->False,
 PageBreakBelow->False],
Cell[CellGroupData[{
Cell[232535, 4730, 1247, 39, 70, "Input"],
Cell[CellGroupData[{
Cell[233807, 4773, 2054, 36, 70, "Print"],
Cell[235864, 4811, 1419, 25, 70, "Print"],
Cell[237286, 4838, 801, 15, 70, "Print"]
}, Open  ]]
}, Open  ]],
Cell[238114, 4857, 254, 7, 70, "Text",
 Evaluatable->False,
 PageBreakAbove->True],
Cell[238371, 4866, 1867, 55, 70, "Input",
 PageBreakWithin->Automatic],
Cell[CellGroupData[{
Cell[240263, 4925, 218, 6, 70, "Input"],
Cell[240484, 4933, 16207, 277, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[256728, 5215, 218, 6, 70, "Input"],
Cell[256949, 5223, 10304, 177, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[267290, 5405, 214, 6, 70, "Input"],
Cell[267507, 5413, 4454, 77, 70, "Output"]
}, Open  ]],
Cell[271976, 5493, 323, 7, 70, "Text",
 Evaluatable->False]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[272348, 5506, 76, 2, 70, "Section",
 Evaluatable->False],
Cell[272427, 5510, 2085, 43, 70, "Text",
 Evaluatable->False]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
